/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_M3NGLR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_M3NGLR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_M3NGLR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_M3NGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_M3NGLR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_M3NGLR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_M3NGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_M3NGLR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_M3NGLR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_M3NGLR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_M3NGLR::Heavy_WSTD_M3NGLR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_HjFfRX4M);
  numBytes += sLine_init(&sLine_erOim5mk);
  numBytes += sLine_init(&sLine_gUvg6R0R);
  numBytes += sLine_init(&sLine_oKnTNpOI);
  numBytes += sLine_init(&sLine_gyukU4Rh);
  numBytes += sBiquad_init(&sBiquad_s_OPnR55gE);
  numBytes += sLine_init(&sLine_TBOA38JT);
  numBytes += sLine_init(&sLine_fJoztNsE);
  numBytes += sLine_init(&sLine_RcuSswvW);
  numBytes += sLine_init(&sLine_FxeXEShO);
  numBytes += sLine_init(&sLine_MiVFOheF);
  numBytes += sBiquad_init(&sBiquad_s_8vBSWwRl);
  numBytes += sLine_init(&sLine_zt1p5iHv);
  numBytes += sLine_init(&sLine_18VZOHeW);
  numBytes += sLine_init(&sLine_OYGndzVP);
  numBytes += sLine_init(&sLine_G19O8Em8);
  numBytes += sLine_init(&sLine_UdPyVjxh);
  numBytes += sLine_init(&sLine_KakaJMOi);
  numBytes += sBiquad_init(&sBiquad_s_9oXISXIY);
  numBytes += sLine_init(&sLine_s1aud8vu);
  numBytes += sLine_init(&sLine_zMjyTr0u);
  numBytes += sLine_init(&sLine_v1KOckVX);
  numBytes += sLine_init(&sLine_KUugnaus);
  numBytes += sLine_init(&sLine_nSPTYtSm);
  numBytes += sLine_init(&sLine_dbTiADvR);
  numBytes += sBiquad_init(&sBiquad_s_OiDDohUf);
  numBytes += sLine_init(&sLine_6WlMSqI9);
  numBytes += sLine_init(&sLine_In1qSAwl);
  numBytes += sLine_init(&sLine_d6TooCRm);
  numBytes += sLine_init(&sLine_enFHH8Ay);
  numBytes += sLine_init(&sLine_mmsOHDsg);
  numBytes += sBiquad_init(&sBiquad_s_y2ZniFMu);
  numBytes += sLine_init(&sLine_QyaYwI9l);
  numBytes += sLine_init(&sLine_a5QhekHt);
  numBytes += sLine_init(&sLine_VUIuS4Kl);
  numBytes += sLine_init(&sLine_kwZsL6j3);
  numBytes += sLine_init(&sLine_B6RArmUb);
  numBytes += sLine_init(&sLine_x982265M);
  numBytes += sBiquad_init(&sBiquad_s_h1PjSk1K);
  numBytes += sLine_init(&sLine_0O7FLgGr);
  numBytes += sLine_init(&sLine_mNqHcONZ);
  numBytes += sLine_init(&sLine_LeACA5HU);
  numBytes += sLine_init(&sLine_eyT46bQz);
  numBytes += sLine_init(&sLine_HL8pyuNd);
  numBytes += sLine_init(&sLine_U4Bn7H0Q);
  numBytes += sLine_init(&sLine_WXuza0tC);
  numBytes += sLine_init(&sLine_ktSmrdrI);
  numBytes += sLine_init(&sLine_HDXkQlm1);
  numBytes += sLine_init(&sLine_CVghcKNl);
  numBytes += sLine_init(&sLine_bvlrJsRr);
  numBytes += sLine_init(&sLine_7gPIUr73);
  numBytes += sLine_init(&sLine_VnXXFnXr);
  numBytes += sLine_init(&sLine_wfdR3Vg4);
  numBytes += sLine_init(&sLine_jduQ8tSo);
  numBytes += sEnv_init(&sEnv_amdktgx2, 512, 256);
  numBytes += sEnv_init(&sEnv_uvsNytTE, 512, 256);
  numBytes += sLine_init(&sLine_rhrcSe5m);
  numBytes += sLine_init(&sLine_o6KUdQVW);
  numBytes += sLine_init(&sLine_1eiigbFo);
  numBytes += sLine_init(&sLine_8LL4rMpR);
  numBytes += sLine_init(&sLine_wxLaUmLU);
  numBytes += sLine_init(&sLine_xPrjmNv9);
  numBytes += sLine_init(&sLine_c5ICqQdL);
  numBytes += sLine_init(&sLine_cdk1A4sU);
  numBytes += sLine_init(&sLine_4qyWwiDQ);
  numBytes += sLine_init(&sLine_ERkRCuVM);
  numBytes += sLine_init(&sLine_b5GAwSZW);
  numBytes += sLine_init(&sLine_1tS8Hsl8);
  numBytes += sLine_init(&sLine_u3uNDQuc);
  numBytes += sLine_init(&sLine_qypLIBho);
  numBytes += sLine_init(&sLine_UAiVrkEi);
  numBytes += sLine_init(&sLine_ZHXcpn88);
  numBytes += sLine_init(&sLine_lhpJiZEn);
  numBytes += sLine_init(&sLine_9e1fxvuk);
  numBytes += sEnv_init(&sEnv_YDtP158m, 512, 256);
  numBytes += sEnv_init(&sEnv_oG6Qdp2Z, 512, 256);
  numBytes += sLine_init(&sLine_rt3ISCkG);
  numBytes += sLine_init(&sLine_lnuvZCQq);
  numBytes += sLine_init(&sLine_8NW95XIy);
  numBytes += sLine_init(&sLine_M3RnsdTT);
  numBytes += sLine_init(&sLine_RobXwJdN);
  numBytes += sLine_init(&sLine_rjIKolWT);
  numBytes += sLine_init(&sLine_E0V5JFk1);
  numBytes += sLine_init(&sLine_b18mzmUe);
  numBytes += sLine_init(&sLine_1XCzkdz0);
  numBytes += sLine_init(&sLine_20oX5RVM);
  numBytes += sLine_init(&sLine_Mmd2kNS9);
  numBytes += sLine_init(&sLine_BzWpBC0W);
  numBytes += sLine_init(&sLine_H5UbUhca);
  numBytes += sLine_init(&sLine_cnpt15z6);
  numBytes += sLine_init(&sLine_NvDWlxMv);
  numBytes += sLine_init(&sLine_sO3YwkWJ);
  numBytes += sLine_init(&sLine_ApMk57IA);
  numBytes += sLine_init(&sLine_73Y8FIew);
  numBytes += sLine_init(&sLine_A2KmQ5Ep);
  numBytes += sLine_init(&sLine_Hl5iayna);
  numBytes += sEnv_init(&sEnv_RZCH8jAL, 512, 256);
  numBytes += sEnv_init(&sEnv_bj8QzG7b, 512, 256);
  numBytes += sLine_init(&sLine_FA5b1MXg);
  numBytes += sLine_init(&sLine_6r47bCT1);
  numBytes += sLine_init(&sLine_oL5q1K2N);
  numBytes += sLine_init(&sLine_KmK1fSNj);
  numBytes += sLine_init(&sLine_fXGk3TNG);
  numBytes += sLine_init(&sLine_4vtZuQ7f);
  numBytes += sLine_init(&sLine_67M3E6wP);
  numBytes += sLine_init(&sLine_iSIE0oz8);
  numBytes += sLine_init(&sLine_DfYr3m1d);
  numBytes += sLine_init(&sLine_bUZA1afd);
  numBytes += sLine_init(&sLine_0BHFvKMK);
  numBytes += sLine_init(&sLine_LK60hgXP);
  numBytes += sLine_init(&sLine_Qy0ZIMpy);
  numBytes += sLine_init(&sLine_VOURrgbZ);
  numBytes += sLine_init(&sLine_AJnmZVbY);
  numBytes += sLine_init(&sLine_zkX03kpk);
  numBytes += sLine_init(&sLine_6Nf0eLXa);
  numBytes += sLine_init(&sLine_uNZINdA4);
  numBytes += sEnv_init(&sEnv_VWLEd1QS, 512, 256);
  numBytes += sEnv_init(&sEnv_ikRhLRMF, 512, 256);
  numBytes += sLine_init(&sLine_IrBLfNLc);
  numBytes += sLine_init(&sLine_5NCcLyqi);
  numBytes += sLine_init(&sLine_khdOAqc2);
  numBytes += sLine_init(&sLine_HqOCtpVt);
  numBytes += sLine_init(&sLine_n4hu2Je3);
  numBytes += sLine_init(&sLine_NakVpx3o);
  numBytes += sLine_init(&sLine_fBBJoQcB);
  numBytes += sLine_init(&sLine_X8kZHPkM);
  numBytes += sLine_init(&sLine_AiFyovRL);
  numBytes += sLine_init(&sLine_ZOv2MMg6);
  numBytes += sLine_init(&sLine_eXWrgpTt);
  numBytes += sLine_init(&sLine_RcQs6LOx);
  numBytes += sLine_init(&sLine_klQHZ4J5);
  numBytes += sLine_init(&sLine_YK7QtwsW);
  numBytes += sLine_init(&sLine_c1x18Lyx);
  numBytes += sLine_init(&sLine_WsP5El7I);
  numBytes += sLine_init(&sLine_BpqGwC6Q);
  numBytes += sLine_init(&sLine_9h26dRM0);
  numBytes += sLine_init(&sLine_Zfab4kx2);
  numBytes += sLine_init(&sLine_sHQr4Y7K);
  numBytes += sEnv_init(&sEnv_Uja3rtBC, 512, 256);
  numBytes += sEnv_init(&sEnv_9YT4CYSZ, 512, 256);
  numBytes += sLine_init(&sLine_eDdP3Ui4);
  numBytes += sLine_init(&sLine_8JJbkCBp);
  numBytes += sLine_init(&sLine_OpwcPXeP);
  numBytes += sLine_init(&sLine_4TRTDGaC);
  numBytes += sLine_init(&sLine_Fqqz2Xvr);
  numBytes += sLine_init(&sLine_PFVF3uxl);
  numBytes += sLine_init(&sLine_mERTw4es);
  numBytes += sLine_init(&sLine_aW5zsayP);
  numBytes += sLine_init(&sLine_bl4zBN47);
  numBytes += sLine_init(&sLine_K2mW0Yy1);
  numBytes += sLine_init(&sLine_ujwkCfHM);
  numBytes += sLine_init(&sLine_oxW5DE8f);
  numBytes += sLine_init(&sLine_32XgHKmY);
  numBytes += sLine_init(&sLine_Yn97wxJX);
  numBytes += sLine_init(&sLine_D7JQgWmw);
  numBytes += sLine_init(&sLine_E2cG6c6O);
  numBytes += sLine_init(&sLine_W2hipR6s);
  numBytes += sLine_init(&sLine_GO7UIQlw);
  numBytes += sEnv_init(&sEnv_i5GMNo5M, 512, 256);
  numBytes += sEnv_init(&sEnv_nQo2j2mt, 512, 256);
  numBytes += sLine_init(&sLine_LvVDuBiv);
  numBytes += sLine_init(&sLine_X6A4In9K);
  numBytes += sLine_init(&sLine_8Q1IobaF);
  numBytes += sLine_init(&sLine_efGcVWp6);
  numBytes += sLine_init(&sLine_Kj529jJK);
  numBytes += sLine_init(&sLine_cTf1YjyK);
  numBytes += cVar_init_f(&cVar_ql3VXeBD, 0.0f);
  numBytes += cVar_init_f(&cVar_7Jfx6kVS, 0.0f);
  numBytes += cVar_init_f(&cVar_kvRmVjGG, 0.0f);
  numBytes += cVar_init_f(&cVar_32mPIaFF, 0.0f);
  numBytes += cVar_init_f(&cVar_2yCKe9az, 0.0f);
  numBytes += cVar_init_f(&cVar_9j99Ghpc, 1.0f);
  numBytes += cVar_init_f(&cVar_cvHbHbu1, 0.0f);
  numBytes += cVar_init_f(&cVar_o3KKLi0y, 0.0f);
  numBytes += cVar_init_f(&cVar_MTv7inTU, 0.0f);
  numBytes += cVar_init_f(&cVar_Fun23bOA, 0.0f);
  numBytes += cSlice_init(&cSlice_WDsXC5OK, 1, -1);
  numBytes += cVar_init_f(&cVar_liKVdMJ5, 1337.0f);
  numBytes += cVar_init_f(&cVar_ilhCIivW, 0.0f);
  numBytes += cIf_init(&cIf_vgjH628y, false);
  numBytes += cIf_init(&cIf_GL1AMJRJ, false);
  numBytes += cBinop_init(&cBinop_RF61qVnw, 0.0f); // __pow
  numBytes += cIf_init(&cIf_p1HMBAIU, false);
  numBytes += cBinop_init(&cBinop_HsgKnrMy, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_dgGLR5KI, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_0O2EmVWg, 0.0f);
  numBytes += cIf_init(&cIf_qsBlBEuK, false);
  numBytes += cIf_init(&cIf_UKswaPmp, false);
  numBytes += cBinop_init(&cBinop_8u6yub6R, 0.0f); // __pow
  numBytes += cIf_init(&cIf_n33RaFAP, false);
  numBytes += cBinop_init(&cBinop_9GcG7c5r, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_wHEvJvre, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_Wt3XN8n0, 0.0f);
  numBytes += cIf_init(&cIf_wW85KZFh, false);
  numBytes += cIf_init(&cIf_fNT0RIMS, false);
  numBytes += cBinop_init(&cBinop_BiimWRbj, 0.0f); // __pow
  numBytes += cIf_init(&cIf_HlES1E2R, false);
  numBytes += cBinop_init(&cBinop_VIwDE4DO, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_x7ayv0Av, -15.0f); // __eq
  numBytes += cIf_init(&cIf_0Xe0t8Md, false);
  numBytes += cSlice_init(&cSlice_DXMkUsoV, 1, -1);
  numBytes += cVar_init_f(&cVar_PQWoDFsm, 0.0f);
  numBytes += cSlice_init(&cSlice_ubpvKZbI, 1, -1);
  numBytes += cVar_init_f(&cVar_rpFWZSET, 0.0f);
  numBytes += cSlice_init(&cSlice_8Jtws7WA, 1, -1);
  numBytes += cVar_init_f(&cVar_kT3t7Lp8, 0.0f);
  numBytes += cSlice_init(&cSlice_M5GTsrPh, 1, -1);
  numBytes += cVar_init_f(&cVar_bS78F0D1, 0.313f);
  numBytes += cBinop_init(&cBinop_2TmjvFio, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_mQKX6XPx, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_zTGfsGJY, 0.0f);
  numBytes += cVar_init_f(&cVar_RxJjPI2z, 1337.0f);
  numBytes += cVar_init_f(&cVar_Fmqu51TX, 0.3f);
  numBytes += cBinop_init(&cBinop_y5gtpmHR, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Bw5FfohW, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_EV51tdOH, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_yLRzHrmf, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_jNkphpB5, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_8wtWOjFl, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_cWh89vie, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_pa2WIAbt, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_3MvNCtUo, 0.0f);
  numBytes += cVar_init_f(&cVar_y9qLVKml, 1337.0f);
  numBytes += cVar_init_f(&cVar_vUPwZfUl, 0.313f);
  numBytes += cBinop_init(&cBinop_D7ntjWDR, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_zbKvJBzQ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_lzdIj8Az, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_QcrELVKp, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_8GhSIhaV, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_u3VSnF69, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_14cz6r8U, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_DohczLiV, 0.0f);
  numBytes += cVar_init_f(&cVar_N37D4UJl, 1037.0f);
  numBytes += cVar_init_f(&cVar_GTareE6u, 0.4f);
  numBytes += cBinop_init(&cBinop_j1nXY9qV, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_0Ynmkm4x, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_bErAuDLf, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_5o4eG2dK, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_E4xRQesg, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_6VRZi4uQ, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_l1CUhheM, 1, -1);
  numBytes += cVar_init_f(&cVar_ZfFa73wI, 1337.0f);
  numBytes += cVar_init_f(&cVar_0OWC80Ih, 0.0f);
  numBytes += cIf_init(&cIf_ovgx1ZnG, false);
  numBytes += cIf_init(&cIf_kR5ZplcX, false);
  numBytes += cBinop_init(&cBinop_vHR4G2dM, 0.0f); // __pow
  numBytes += cIf_init(&cIf_838UAECk, false);
  numBytes += cBinop_init(&cBinop_iY9QWaFZ, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_AQMdPDA5, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_C4rwO80C, 0.0f);
  numBytes += cIf_init(&cIf_C5YFTRm6, false);
  numBytes += cIf_init(&cIf_SzczcYKY, false);
  numBytes += cBinop_init(&cBinop_O2O2SZm8, 0.0f); // __pow
  numBytes += cIf_init(&cIf_6q7eTYbU, false);
  numBytes += cBinop_init(&cBinop_JhPp6tev, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_VoU17xkD, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_muLLWIrF, 0.0f);
  numBytes += cIf_init(&cIf_aXVTcsCE, false);
  numBytes += cIf_init(&cIf_2sfG8a9S, false);
  numBytes += cBinop_init(&cBinop_yQurWq8l, 0.0f); // __pow
  numBytes += cIf_init(&cIf_SpdYZ3QJ, false);
  numBytes += cBinop_init(&cBinop_I6mN5O1u, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_XZEofKd3, -15.0f); // __eq
  numBytes += cIf_init(&cIf_hNbJcHOs, false);
  numBytes += cSlice_init(&cSlice_XLieBJ9T, 1, -1);
  numBytes += cVar_init_f(&cVar_St2dqy6q, 0.0f);
  numBytes += cSlice_init(&cSlice_JRy7pkkS, 1, -1);
  numBytes += cVar_init_f(&cVar_6Igd03oL, 0.0f);
  numBytes += cSlice_init(&cSlice_A1tPZnus, 1, -1);
  numBytes += cVar_init_f(&cVar_R6hjSGv6, 0.0f);
  numBytes += cSlice_init(&cSlice_aSspGPaE, 1, -1);
  numBytes += cVar_init_f(&cVar_hVLM6RAA, 0.313f);
  numBytes += cBinop_init(&cBinop_nCHeNoEq, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_gH7JcNnV, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_bUAJGZdE, 0.0f);
  numBytes += cVar_init_f(&cVar_upquHCo0, 1337.0f);
  numBytes += cVar_init_f(&cVar_LwcHvIQe, 0.3f);
  numBytes += cBinop_init(&cBinop_Qmn1gKH4, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_naic3jgd, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_lxRJwcq7, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_MxrHFDrm, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_SW3xK0YI, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_oRcytKaD, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_SdtLZivf, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_zOMfdtke, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_qkHmX6zU, 0.0f);
  numBytes += cVar_init_f(&cVar_yQDk3Mz6, 1337.0f);
  numBytes += cVar_init_f(&cVar_zrTWzWvA, 0.313f);
  numBytes += cBinop_init(&cBinop_fQU9GOUK, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_lXf5AGCg, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vm4zM030, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Ez5vnkPF, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_q18oW5sx, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_s6yEP2aS, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_1OH8vj4b, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_0xFSlKjP, 0.0f);
  numBytes += cVar_init_f(&cVar_Zb9knsvJ, 1037.0f);
  numBytes += cVar_init_f(&cVar_wGKaxe2F, 0.4f);
  numBytes += cBinop_init(&cBinop_hEfTzeR8, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_1sf8dAMy, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_QCTJwJrK, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_IMv9rAV6, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_LFCX6kJU, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_dNMFUjHu, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_kKwjc5WH, 5705.6f);
  numBytes += cVar_init_f(&cVar_3jFB9ur3, 313.3f);
  numBytes += cBinop_init(&cBinop_0vfAtWXN, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_U1td8e3z, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_AiyFooXu, 0.0f); // __div
  numBytes += cSlice_init(&cSlice_APub1j2r, 1, -1);
  numBytes += cVar_init_f(&cVar_Guyrg9pv, 0.5f);
  numBytes += cVar_init_f(&cVar_dyWy1nMu, 0.0f);
  numBytes += cVar_init_f(&cVar_6biNPmA9, 0.0f);
  numBytes += cIf_init(&cIf_u6uWRwKC, false);
  numBytes += cIf_init(&cIf_m6FNgjh8, false);
  numBytes += cDelay_init(this, &cDelay_wrgnocmm, 10.0f);
  numBytes += cIf_init(&cIf_UHmS9Sef, false);
  numBytes += cIf_init(&cIf_gjWHdzJV, false);
  numBytes += cDelay_init(this, &cDelay_sDC3PHWM, 10.0f);
  numBytes += cIf_init(&cIf_Cod5RA1t, false);
  numBytes += cIf_init(&cIf_dyNcG3DC, false);
  numBytes += cDelay_init(this, &cDelay_2ohdcLgc, 10.0f);
  numBytes += cIf_init(&cIf_qMrS8954, false);
  numBytes += cIf_init(&cIf_l0DxMTtz, false);
  numBytes += cDelay_init(this, &cDelay_NEEYhMc9, 10.0f);
  numBytes += cIf_init(&cIf_nrijqJwb, false);
  numBytes += cIf_init(&cIf_POmYch8h, false);
  numBytes += cDelay_init(this, &cDelay_M9QtVVkN, 10.0f);
  numBytes += cIf_init(&cIf_gmctIiKB, false);
  numBytes += cIf_init(&cIf_6mqYph8h, false);
  numBytes += cDelay_init(this, &cDelay_QNrLEQxH, 10.0f);
  numBytes += cIf_init(&cIf_wj0Yt8eW, false);
  numBytes += cIf_init(&cIf_oCMLkrrK, false);
  numBytes += cDelay_init(this, &cDelay_FEnr2JPU, 10.0f);
  numBytes += cIf_init(&cIf_faIyXzZO, false);
  numBytes += cIf_init(&cIf_q1DdfFmE, false);
  numBytes += cDelay_init(this, &cDelay_1IWWOSoF, 10.0f);
  numBytes += cIf_init(&cIf_fZwZ39dG, false);
  numBytes += cIf_init(&cIf_YzFq7Hpo, false);
  numBytes += cDelay_init(this, &cDelay_hXSnrIZH, 10.0f);
  numBytes += cIf_init(&cIf_VHn4yG94, false);
  numBytes += cIf_init(&cIf_H6dA0vAQ, false);
  numBytes += cDelay_init(this, &cDelay_53myv8jy, 10.0f);
  numBytes += cIf_init(&cIf_UPDRtnBT, false);
  numBytes += cIf_init(&cIf_uPYbni7X, false);
  numBytes += cDelay_init(this, &cDelay_xfjBTlgJ, 10.0f);
  numBytes += cIf_init(&cIf_tKvUZpbX, false);
  numBytes += cIf_init(&cIf_mne4RsAA, false);
  numBytes += cDelay_init(this, &cDelay_OfGfnKdt, 10.0f);
  numBytes += sVarf_init(&sVarf_tEVugyOd, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_QSj9xJUH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_mb8GlB6H, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ZCenT6BT, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_MUGqaw7Z, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_EjwrN4VQ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_eY9U4W5M, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_zdSwyD4X, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_dCQwsTkt, 0.0f);
  numBytes += cSlice_init(&cSlice_1Q5IYjeC, 1, -1);
  numBytes += cVar_init_f(&cVar_AHwUWgMU, 1.0f);
  numBytes += cSlice_init(&cSlice_k9cjxd3G, 1, -1);
  numBytes += cVar_init_f(&cVar_i9EJm2mP, 0.0f);
  numBytes += cSlice_init(&cSlice_x6mM31z8, 1, -1);
  numBytes += cVar_init_f(&cVar_cLWTceW3, 512.0f);
  numBytes += cSlice_init(&cSlice_OvjrPFHz, 1, -1);
  numBytes += cVar_init_f(&cVar_3TDJBqy8, 1.0f);
  numBytes += cSlice_init(&cSlice_nX0XRTpI, 1, -1);
  numBytes += cVar_init_f(&cVar_BN7QuS2U, 1.0f);
  numBytes += cDelay_init(this, &cDelay_sO33tgWy, 20.0f);
  numBytes += cVar_init_f(&cVar_0RkJUlb1, 0.0f);
  numBytes += cIf_init(&cIf_tGjep0Qc, false);
  numBytes += cIf_init(&cIf_5tQuanjA, false);
  numBytes += cBinop_init(&cBinop_7e93Fsdw, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_JaD6ipX2, 1, -1);
  numBytes += cVar_init_f(&cVar_ICVtV6kh, 0.0f);
  numBytes += sVarf_init(&sVarf_6j3EdCKl, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_um2c0TaC, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_62tEhfAI, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_j6micVRX, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_DchI4b8Q, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_kIa2IZfR, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_fQwSNugO, 0.0f);
  numBytes += cVar_init_f(&cVar_uoKQMV4x, 0.0f);
  numBytes += cIf_init(&cIf_5Qfw6Woy, false);
  numBytes += cIf_init(&cIf_1g4FBURK, false);
  numBytes += cDelay_init(this, &cDelay_x7gbZr11, 10.0f);
  numBytes += cIf_init(&cIf_crmrXsZp, false);
  numBytes += cIf_init(&cIf_rMdxWSOp, false);
  numBytes += cDelay_init(this, &cDelay_NbGicS6g, 10.0f);
  numBytes += cIf_init(&cIf_0AGlclli, false);
  numBytes += cIf_init(&cIf_0BsSrqTs, false);
  numBytes += cDelay_init(this, &cDelay_xrGwNKJR, 10.0f);
  numBytes += cIf_init(&cIf_tuUJ1Qfn, false);
  numBytes += cIf_init(&cIf_YkiEEsiE, false);
  numBytes += cDelay_init(this, &cDelay_62725Ohe, 10.0f);
  numBytes += cIf_init(&cIf_Tf76S2t7, false);
  numBytes += cIf_init(&cIf_y6XwiCvj, false);
  numBytes += cDelay_init(this, &cDelay_y13yNyj5, 10.0f);
  numBytes += cIf_init(&cIf_auCLLwFR, false);
  numBytes += cIf_init(&cIf_XqEkOmul, false);
  numBytes += cDelay_init(this, &cDelay_CNKBWhjh, 10.0f);
  numBytes += cIf_init(&cIf_6KPJiawV, false);
  numBytes += cIf_init(&cIf_SPJ9SuWr, false);
  numBytes += cDelay_init(this, &cDelay_knBkuHhf, 10.0f);
  numBytes += cIf_init(&cIf_PDqonvx2, false);
  numBytes += cIf_init(&cIf_4i56jT0C, false);
  numBytes += cDelay_init(this, &cDelay_et17YxIc, 10.0f);
  numBytes += cIf_init(&cIf_eGdx1dBG, false);
  numBytes += cIf_init(&cIf_Wto5V93X, false);
  numBytes += cDelay_init(this, &cDelay_uKYGz7Wu, 10.0f);
  numBytes += cIf_init(&cIf_SkO5LlSu, false);
  numBytes += cIf_init(&cIf_7jM8u9Zd, false);
  numBytes += cDelay_init(this, &cDelay_fpEaHDwp, 10.0f);
  numBytes += cIf_init(&cIf_1DLelIbE, false);
  numBytes += cIf_init(&cIf_lVauBXJB, false);
  numBytes += cDelay_init(this, &cDelay_sHZjJG7u, 10.0f);
  numBytes += cIf_init(&cIf_aapIS6oJ, false);
  numBytes += cIf_init(&cIf_bu6oDlXV, false);
  numBytes += cDelay_init(this, &cDelay_YPSYQtvz, 10.0f);
  numBytes += sVarf_init(&sVarf_OjU9AZkw, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_mHXLDHqS, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ZVAdvZUu, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_FrzqzW66, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_gvfn8o4d, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_SlAcvj4A, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_9T8f2Sbr, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_BBlBgvq9, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_pffCTxAk, 0.0f);
  numBytes += cSlice_init(&cSlice_SGj21zYu, 1, -1);
  numBytes += cVar_init_f(&cVar_65a1NuXo, 1.0f);
  numBytes += cSlice_init(&cSlice_gSmONRbX, 1, -1);
  numBytes += cVar_init_f(&cVar_CkEzV85r, 0.0f);
  numBytes += cSlice_init(&cSlice_eDdCcLZn, 1, -1);
  numBytes += cVar_init_f(&cVar_4NR9La5c, 512.0f);
  numBytes += cSlice_init(&cSlice_sHENvmDp, 1, -1);
  numBytes += cVar_init_f(&cVar_RFyIMaCL, 1.0f);
  numBytes += cSlice_init(&cSlice_Z9RRL9Kw, 1, -1);
  numBytes += cVar_init_f(&cVar_8njYz1CI, 1.0f);
  numBytes += cDelay_init(this, &cDelay_p0evDe1O, 20.0f);
  numBytes += cVar_init_f(&cVar_RfW5Y5EO, 0.0f);
  numBytes += cIf_init(&cIf_olSPltjc, false);
  numBytes += cIf_init(&cIf_CW7AwfVT, false);
  numBytes += cBinop_init(&cBinop_vbXOSYRH, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_ffPq6yJf, 1, -1);
  numBytes += cVar_init_f(&cVar_0xBlM5zL, 0.0f);
  numBytes += sVarf_init(&sVarf_SM8bNeGB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Wi6MaFz3, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_7zvc7LdT, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_tWZyaVxh, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_RHsmceRG, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_awUk6R91, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_WYqbcQYo, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_IC61yVjh, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_lg6hUpyh, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_122RJAsU, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_FlhZNHv1, 0.0f);
  numBytes += cVar_init_f(&cVar_F0wdYKvN, 0.0f);
  numBytes += cVar_init_f(&cVar_fWpGrJQV, 0.0f);
  numBytes += cVar_init_f(&cVar_3wF0Pmdv, 0.0f);
  numBytes += cVar_init_f(&cVar_VzKBosDs, 0.0f);
  numBytes += cVar_init_f(&cVar_FPrOgSj7, 1.0f);
  numBytes += cSlice_init(&cSlice_Jimm3cYP, 1, -1);
  numBytes += cVar_init_f(&cVar_MUEpMTPQ, 0.5f);
  numBytes += cVar_init_f(&cVar_1Wj7EdcT, 0.0f);
  numBytes += cVar_init_f(&cVar_ayDIsEJV, 0.0f);
  numBytes += cIf_init(&cIf_5EP1CrzT, false);
  numBytes += cIf_init(&cIf_G8xOSVE4, false);
  numBytes += cDelay_init(this, &cDelay_yiDTzD2V, 10.0f);
  numBytes += cIf_init(&cIf_oC0fnHca, false);
  numBytes += cIf_init(&cIf_JzFmPZbb, false);
  numBytes += cDelay_init(this, &cDelay_YY2CBMq5, 10.0f);
  numBytes += cIf_init(&cIf_GIPnlPE8, false);
  numBytes += cIf_init(&cIf_fcJjJuwd, false);
  numBytes += cDelay_init(this, &cDelay_NmlQmLGc, 10.0f);
  numBytes += cIf_init(&cIf_KYWOZfba, false);
  numBytes += cIf_init(&cIf_i8uhUsQD, false);
  numBytes += cDelay_init(this, &cDelay_vVJWZksE, 10.0f);
  numBytes += cIf_init(&cIf_pjAyjp2f, false);
  numBytes += cIf_init(&cIf_WzEeb3CZ, false);
  numBytes += cDelay_init(this, &cDelay_7ApLfyjd, 10.0f);
  numBytes += cIf_init(&cIf_fmIDFpq4, false);
  numBytes += cIf_init(&cIf_IZqO09o3, false);
  numBytes += cDelay_init(this, &cDelay_VFQpfeXi, 10.0f);
  numBytes += cIf_init(&cIf_3iEv0HAs, false);
  numBytes += cIf_init(&cIf_GcmfV9kC, false);
  numBytes += cDelay_init(this, &cDelay_Qt91ZizM, 10.0f);
  numBytes += cIf_init(&cIf_jOXpOkD3, false);
  numBytes += cIf_init(&cIf_hIntLnWl, false);
  numBytes += cDelay_init(this, &cDelay_7FkR9LyA, 10.0f);
  numBytes += cIf_init(&cIf_TKovYxTf, false);
  numBytes += cIf_init(&cIf_kNuIQ7BN, false);
  numBytes += cDelay_init(this, &cDelay_UWEK8pzW, 10.0f);
  numBytes += cIf_init(&cIf_BEMqDXwr, false);
  numBytes += cIf_init(&cIf_xzOTHW0q, false);
  numBytes += cDelay_init(this, &cDelay_ZdxCQN7x, 10.0f);
  numBytes += cIf_init(&cIf_CSVET7S0, false);
  numBytes += cIf_init(&cIf_5yAfLWTf, false);
  numBytes += cDelay_init(this, &cDelay_tBiSGde2, 10.0f);
  numBytes += cIf_init(&cIf_BLqVeYnv, false);
  numBytes += cIf_init(&cIf_Iu8HWRkb, false);
  numBytes += cDelay_init(this, &cDelay_yXVPAevL, 10.0f);
  numBytes += sVarf_init(&sVarf_sVgz0dqs, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_QHGg9z2i, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_N1hKjL6g, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Bo0jHK22, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Nw7Nec79, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fJijlF2g, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Q1gUamxc, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_kCEgrUQU, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_orhaUeuv, 0.0f);
  numBytes += cSlice_init(&cSlice_Ja6VPpgo, 1, -1);
  numBytes += cVar_init_f(&cVar_sGAr1xaR, 1.0f);
  numBytes += cSlice_init(&cSlice_bituh0Yt, 1, -1);
  numBytes += cVar_init_f(&cVar_ransgAHx, 0.0f);
  numBytes += cSlice_init(&cSlice_A5xbB2yb, 1, -1);
  numBytes += cVar_init_f(&cVar_8NbY07DF, 512.0f);
  numBytes += cSlice_init(&cSlice_wFlNrQS9, 1, -1);
  numBytes += cVar_init_f(&cVar_3j0McVlx, 1.0f);
  numBytes += cSlice_init(&cSlice_XawAKIf7, 1, -1);
  numBytes += cVar_init_f(&cVar_RY8HOqIe, 1.0f);
  numBytes += cDelay_init(this, &cDelay_tbIFMRUJ, 20.0f);
  numBytes += cVar_init_f(&cVar_vFcAfHS0, 0.0f);
  numBytes += cIf_init(&cIf_gUQTfA6O, false);
  numBytes += cIf_init(&cIf_zj24EOUj, false);
  numBytes += cBinop_init(&cBinop_fFM9Qydn, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_XzUn4uh8, 1, -1);
  numBytes += cVar_init_f(&cVar_o1djFV8E, 0.0f);
  numBytes += sVarf_init(&sVarf_Y8aU4Klg, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_6ZoLpx1M, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_3n2lZGHB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Ve5sCf1k, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_CgrAanzg, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Oaw4bgwk, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_VoOOqu1O, 0.0f);
  numBytes += cVar_init_f(&cVar_UlM7lBhj, 0.0f);
  numBytes += cIf_init(&cIf_BhatrJ5W, false);
  numBytes += cIf_init(&cIf_1fZPAyIu, false);
  numBytes += cDelay_init(this, &cDelay_OUPGhjE0, 10.0f);
  numBytes += cIf_init(&cIf_qAI0UIw2, false);
  numBytes += cIf_init(&cIf_oRf3Hijj, false);
  numBytes += cDelay_init(this, &cDelay_HYf3VKyy, 10.0f);
  numBytes += cIf_init(&cIf_2cnZQHiB, false);
  numBytes += cIf_init(&cIf_j1yf3oul, false);
  numBytes += cDelay_init(this, &cDelay_fhj7uDuV, 10.0f);
  numBytes += cIf_init(&cIf_SwlAuWHG, false);
  numBytes += cIf_init(&cIf_FmjnvTlM, false);
  numBytes += cDelay_init(this, &cDelay_kzM4lGxX, 10.0f);
  numBytes += cIf_init(&cIf_tb366rz2, false);
  numBytes += cIf_init(&cIf_ds9cliEm, false);
  numBytes += cDelay_init(this, &cDelay_HE44uwFV, 10.0f);
  numBytes += cIf_init(&cIf_0XK92Nu3, false);
  numBytes += cIf_init(&cIf_JoHgxUA4, false);
  numBytes += cDelay_init(this, &cDelay_n07GgZsM, 10.0f);
  numBytes += cIf_init(&cIf_T8Ta5Gfs, false);
  numBytes += cIf_init(&cIf_NZzBCpRp, false);
  numBytes += cDelay_init(this, &cDelay_lWquL44y, 10.0f);
  numBytes += cIf_init(&cIf_FXBnVKsU, false);
  numBytes += cIf_init(&cIf_fCGMocZV, false);
  numBytes += cDelay_init(this, &cDelay_MiEr5tYy, 10.0f);
  numBytes += cIf_init(&cIf_ItolwcWJ, false);
  numBytes += cIf_init(&cIf_3aU4lxpF, false);
  numBytes += cDelay_init(this, &cDelay_cqi8ktGS, 10.0f);
  numBytes += cIf_init(&cIf_dHbOdBo0, false);
  numBytes += cIf_init(&cIf_IdiVkzoi, false);
  numBytes += cDelay_init(this, &cDelay_ZHUdJQtC, 10.0f);
  numBytes += cIf_init(&cIf_YDbYPeGt, false);
  numBytes += cIf_init(&cIf_wDghrXU7, false);
  numBytes += cDelay_init(this, &cDelay_rIT18sbD, 10.0f);
  numBytes += cIf_init(&cIf_kGwYV8A1, false);
  numBytes += cIf_init(&cIf_38MOS45M, false);
  numBytes += cDelay_init(this, &cDelay_4ZI4BuNw, 10.0f);
  numBytes += sVarf_init(&sVarf_XUBg8UGC, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_txtrwkDv, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_610hNP6S, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_jNhb9iWN, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ljvrZE1W, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_kmDfT0Gg, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_q5oyUhUM, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_TtzSUtDm, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_KeGyhv4R, 0.0f);
  numBytes += cSlice_init(&cSlice_sLQiJSw9, 1, -1);
  numBytes += cVar_init_f(&cVar_MkzEypdd, 1.0f);
  numBytes += cSlice_init(&cSlice_QS2hFI4z, 1, -1);
  numBytes += cVar_init_f(&cVar_igJnpcI1, 0.0f);
  numBytes += cSlice_init(&cSlice_mpXHmoCx, 1, -1);
  numBytes += cVar_init_f(&cVar_Op1P6H2G, 512.0f);
  numBytes += cSlice_init(&cSlice_1pynreZF, 1, -1);
  numBytes += cVar_init_f(&cVar_sISJbFDo, 1.0f);
  numBytes += cSlice_init(&cSlice_AnrJa0WR, 1, -1);
  numBytes += cVar_init_f(&cVar_daVytTZQ, 1.0f);
  numBytes += cDelay_init(this, &cDelay_2ZvFh2Sn, 20.0f);
  numBytes += cVar_init_f(&cVar_I0yNsIkB, 0.0f);
  numBytes += cIf_init(&cIf_sxQl0krv, false);
  numBytes += cIf_init(&cIf_97a3pK0e, false);
  numBytes += cBinop_init(&cBinop_lLHcXJZJ, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_R0eJWsbv, 1, -1);
  numBytes += cVar_init_f(&cVar_ocYHFT03, 0.0f);
  numBytes += sVarf_init(&sVarf_sRgFkv5T, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_XNaw3i3M, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_gv5uLZsn, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_EDRxtw3a, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_jInsfRIg, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_mN7fyC4T, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_IgO6Posg, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_YWbRSXFN, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_r2IS216a, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_UXbVcAZ7, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_Y8115dMv, 0.0f);
  numBytes += cVar_init_f(&cVar_XrOkVY1P, 0.0f);
  numBytes += cVar_init_f(&cVar_YaEk4EjA, 0.0f);
  numBytes += cVar_init_f(&cVar_2lkPAudV, 0.0f);
  numBytes += cVar_init_f(&cVar_beHC6D9R, 0.0f);
  numBytes += cVar_init_f(&cVar_pGmUEVAf, 1.0f);
  numBytes += cSlice_init(&cSlice_eKcMhOwR, 1, -1);
  numBytes += cVar_init_f(&cVar_eT6dLPOC, 0.5f);
  numBytes += cVar_init_f(&cVar_RwgEjkOv, 0.0f);
  numBytes += cVar_init_f(&cVar_ajYI5RK4, 0.0f);
  numBytes += cIf_init(&cIf_NR2cbYZ7, false);
  numBytes += cIf_init(&cIf_9yAG4yua, false);
  numBytes += cDelay_init(this, &cDelay_RvQx5Z9i, 10.0f);
  numBytes += cIf_init(&cIf_6f39tevr, false);
  numBytes += cIf_init(&cIf_QWp2Dq00, false);
  numBytes += cDelay_init(this, &cDelay_4HOXbJnU, 10.0f);
  numBytes += cIf_init(&cIf_PQUIL9sS, false);
  numBytes += cIf_init(&cIf_dbdUW3m4, false);
  numBytes += cDelay_init(this, &cDelay_TSjFNM6w, 10.0f);
  numBytes += cIf_init(&cIf_pEIMJMET, false);
  numBytes += cIf_init(&cIf_U0Cogc4a, false);
  numBytes += cDelay_init(this, &cDelay_utSFqSBi, 10.0f);
  numBytes += cIf_init(&cIf_NAuzZmt3, false);
  numBytes += cIf_init(&cIf_liWrHxd4, false);
  numBytes += cDelay_init(this, &cDelay_CVxa70na, 10.0f);
  numBytes += cIf_init(&cIf_Xqliy8Ll, false);
  numBytes += cIf_init(&cIf_S5lX1dwa, false);
  numBytes += cDelay_init(this, &cDelay_2NskvG2v, 10.0f);
  numBytes += cIf_init(&cIf_MLCPPt8O, false);
  numBytes += cIf_init(&cIf_q3hcNOt2, false);
  numBytes += cDelay_init(this, &cDelay_7gKPV5xQ, 10.0f);
  numBytes += cIf_init(&cIf_WsOktgOY, false);
  numBytes += cIf_init(&cIf_KCtjIWXC, false);
  numBytes += cDelay_init(this, &cDelay_F2tyJVt6, 10.0f);
  numBytes += cIf_init(&cIf_70c17vUD, false);
  numBytes += cIf_init(&cIf_0wQR5gds, false);
  numBytes += cDelay_init(this, &cDelay_KYtpbQhW, 10.0f);
  numBytes += cIf_init(&cIf_f8066dYg, false);
  numBytes += cIf_init(&cIf_3oNUCkoH, false);
  numBytes += cDelay_init(this, &cDelay_rMM92iq4, 10.0f);
  numBytes += cIf_init(&cIf_ghBxKIbX, false);
  numBytes += cIf_init(&cIf_q45HAmwB, false);
  numBytes += cDelay_init(this, &cDelay_vkKikaUA, 10.0f);
  numBytes += cIf_init(&cIf_kt2Xobqv, false);
  numBytes += cIf_init(&cIf_f6u75NcD, false);
  numBytes += cDelay_init(this, &cDelay_tq40xhYQ, 10.0f);
  numBytes += sVarf_init(&sVarf_PMCgu5ce, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_U1JapjJP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_aK5PlBhK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_vhkGoaze, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_HfsC0abw, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_GBWBaTc5, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Hd4EWwIW, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_xpoHSZKi, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_NTFz56sC, 0.0f);
  numBytes += cSlice_init(&cSlice_BZHNWR8m, 1, -1);
  numBytes += cVar_init_f(&cVar_GcjXpOrx, 1.0f);
  numBytes += cSlice_init(&cSlice_ctF1Kf0M, 1, -1);
  numBytes += cVar_init_f(&cVar_3bIYDQfC, 0.0f);
  numBytes += cSlice_init(&cSlice_AVGc02Gd, 1, -1);
  numBytes += cVar_init_f(&cVar_v5k5IrVW, 512.0f);
  numBytes += cSlice_init(&cSlice_8t5jz6DQ, 1, -1);
  numBytes += cVar_init_f(&cVar_iHZgW33S, 1.0f);
  numBytes += cSlice_init(&cSlice_pKha3PPk, 1, -1);
  numBytes += cVar_init_f(&cVar_Gqa0s6mI, 1.0f);
  numBytes += cDelay_init(this, &cDelay_pSK3syJj, 20.0f);
  numBytes += cVar_init_f(&cVar_pjkvrD6N, 0.0f);
  numBytes += cIf_init(&cIf_Z5Aga7Nl, false);
  numBytes += cIf_init(&cIf_jaJHSg3l, false);
  numBytes += cBinop_init(&cBinop_PO1rQzh3, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_Xa07SF7e, 1, -1);
  numBytes += cVar_init_f(&cVar_qcj7rJBd, 0.0f);
  numBytes += sVarf_init(&sVarf_GLAjq61z, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_GvpSjrlB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Sh3y841K, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_YsPRFXyA, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_bjYu5KBS, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_zdpvex1N, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_W06qEWHs, 0.0f);
  numBytes += cVar_init_f(&cVar_78HjdcfH, 0.0f);
  numBytes += cIf_init(&cIf_x3K0gJuT, false);
  numBytes += cIf_init(&cIf_leXefD4D, false);
  numBytes += cDelay_init(this, &cDelay_DfEZuY0o, 10.0f);
  numBytes += cIf_init(&cIf_Azx682HF, false);
  numBytes += cIf_init(&cIf_H87SGFLU, false);
  numBytes += cDelay_init(this, &cDelay_ehQL40Tz, 10.0f);
  numBytes += cIf_init(&cIf_ZObCGtak, false);
  numBytes += cIf_init(&cIf_eNx09xwL, false);
  numBytes += cDelay_init(this, &cDelay_wtowDd5K, 10.0f);
  numBytes += cIf_init(&cIf_vf9rYztg, false);
  numBytes += cIf_init(&cIf_J0Exyu4m, false);
  numBytes += cDelay_init(this, &cDelay_oyUKfyTW, 10.0f);
  numBytes += cIf_init(&cIf_5EgSCZaM, false);
  numBytes += cIf_init(&cIf_VySf7gpL, false);
  numBytes += cDelay_init(this, &cDelay_5IbMyO8v, 10.0f);
  numBytes += cIf_init(&cIf_e9cNXnFj, false);
  numBytes += cIf_init(&cIf_euRv9WTZ, false);
  numBytes += cDelay_init(this, &cDelay_7tzs8NNY, 10.0f);
  numBytes += cIf_init(&cIf_4BXif1Xo, false);
  numBytes += cIf_init(&cIf_sCqhh2Ak, false);
  numBytes += cDelay_init(this, &cDelay_ZrFRQUAW, 10.0f);
  numBytes += cIf_init(&cIf_73ZfUKSo, false);
  numBytes += cIf_init(&cIf_29HigVO9, false);
  numBytes += cDelay_init(this, &cDelay_21HEftWd, 10.0f);
  numBytes += cIf_init(&cIf_bZUD0Rt0, false);
  numBytes += cIf_init(&cIf_AgsfungG, false);
  numBytes += cDelay_init(this, &cDelay_NeTSitak, 10.0f);
  numBytes += cIf_init(&cIf_NkAsNV0I, false);
  numBytes += cIf_init(&cIf_7wH3u2lh, false);
  numBytes += cDelay_init(this, &cDelay_4cXzBp5w, 10.0f);
  numBytes += cIf_init(&cIf_2U6bJr6A, false);
  numBytes += cIf_init(&cIf_T2LcHl9J, false);
  numBytes += cDelay_init(this, &cDelay_9qDz9vwx, 10.0f);
  numBytes += cIf_init(&cIf_WA0QixJw, false);
  numBytes += cIf_init(&cIf_KBImS6Gf, false);
  numBytes += cDelay_init(this, &cDelay_E0A3G2nT, 10.0f);
  numBytes += sVarf_init(&sVarf_HbabM7Af, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5uVw0TNf, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_xnUqLccN, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rW2mxb9u, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5c94DJOJ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_yUpclSml, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_feALdfBV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_jIMaE2Fs, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_3ZTpcMVi, 0.0f);
  numBytes += cSlice_init(&cSlice_OSOkkV3n, 1, -1);
  numBytes += cVar_init_f(&cVar_IAXDoqcv, 1.0f);
  numBytes += cSlice_init(&cSlice_otad7vWp, 1, -1);
  numBytes += cVar_init_f(&cVar_qYw5Nnzz, 0.0f);
  numBytes += cSlice_init(&cSlice_S3sZAdoT, 1, -1);
  numBytes += cVar_init_f(&cVar_JRyrMC2q, 512.0f);
  numBytes += cSlice_init(&cSlice_OMqpihDO, 1, -1);
  numBytes += cVar_init_f(&cVar_Jy9Wtnoi, 1.0f);
  numBytes += cSlice_init(&cSlice_pHMFf44b, 1, -1);
  numBytes += cVar_init_f(&cVar_YWtgzD15, 1.0f);
  numBytes += cDelay_init(this, &cDelay_laObv0Vi, 20.0f);
  numBytes += cVar_init_f(&cVar_9E5Q3hCP, 0.0f);
  numBytes += cIf_init(&cIf_WK2JpHLc, false);
  numBytes += cIf_init(&cIf_5lbbQkPA, false);
  numBytes += cBinop_init(&cBinop_2G1Oa2WT, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_dLAolreu, 1, -1);
  numBytes += cVar_init_f(&cVar_QwkJng3y, 0.0f);
  numBytes += sVarf_init(&sVarf_lixSEiRi, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_6DZSm15z, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_QPQhhNij, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_w0R4Pmyp, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_bUezrHWW, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Dn1h6csY, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Kco0lFdi, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qKPFqEFq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_SxYkAiug, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_LaogSr1T, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_TQynuUxf, 0.0f);
  numBytes += cVar_init_f(&cVar_ag59sBKb, 0.0f);
  numBytes += cVar_init_f(&cVar_YdPIfgoO, 0.0f);
  numBytes += sVarf_init(&sVarf_Pvzq1i7E, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_UVlLWLd2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_e4IAnbz8, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_iElnrNAd, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_GQBvnmii, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_yc0JGL44, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_jgPfvMcf, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_PMXLHMjj, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_G1AyLc84, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_xP8AqX87, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_uXvfj1A6, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_cz82yjW2, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_M3NGLR::~Heavy_WSTD_M3NGLR() {
  sEnv_free(&sEnv_amdktgx2);
  sEnv_free(&sEnv_uvsNytTE);
  sEnv_free(&sEnv_YDtP158m);
  sEnv_free(&sEnv_oG6Qdp2Z);
  sEnv_free(&sEnv_RZCH8jAL);
  sEnv_free(&sEnv_bj8QzG7b);
  sEnv_free(&sEnv_VWLEd1QS);
  sEnv_free(&sEnv_ikRhLRMF);
  sEnv_free(&sEnv_Uja3rtBC);
  sEnv_free(&sEnv_9YT4CYSZ);
  sEnv_free(&sEnv_i5GMNo5M);
  sEnv_free(&sEnv_nQo2j2mt);
}

HvTable *Heavy_WSTD_M3NGLR::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_M3NGLR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QNgpaDoJ_sendMessage);
      break;
    }
    case 0xCFF7A234: { // High_Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_50t1Xz8i_sendMessage);
      break;
    }
    case 0x12EF45B9: { // High_Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_n2Mrx2Kq_sendMessage);
      break;
    }
    case 0xC05E9A15: { // High_Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xXRoyqup_sendMessage);
      break;
    }
    case 0x8E596A67: { // High_Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ByB7zVJ6_sendMessage);
      break;
    }
    case 0xAC5FA57F: { // High_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rusBlF5D_sendMessage);
      break;
    }
    case 0x585E4A54: { // High_Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NbQAwzCd_sendMessage);
      break;
    }
    case 0x14A9747F: { // High_Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8WJjmUQF_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Fap6GwVD_sendMessage);
      break;
    }
    case 0xEBDB0C5E: { // Low_Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HadPXkV1_sendMessage);
      break;
    }
    case 0xF974E926: { // Low_Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2bDh0MPN_sendMessage);
      break;
    }
    case 0xBB56D13C: { // Low_Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Ol9S7Dos_sendMessage);
      break;
    }
    case 0xB4EFBAC1: { // Low_Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SYW6z7VX_sendMessage);
      break;
    }
    case 0x91FEF7A: { // Low_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Zrp8JO95_sendMessage);
      break;
    }
    case 0x1665AEE9: { // Low_Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SjaYnRHq_sendMessage);
      break;
    }
    case 0x860CA1D9: { // Low_Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LBuDmBGb_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_doCU1GYt_sendMessage);
      break;
    }
    case 0xEA9DEF12: { // Mid_Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PYPmgIOS_sendMessage);
      break;
    }
    case 0xDBF6FE0A: { // Mid_Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_q3LzBSCI_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_P82mhwD7_sendMessage);
      break;
    }
    case 0x23F5E910: { // Mid_Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LUvkT0de_sendMessage);
      break;
    }
    case 0x33C126B6: { // Mid_Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QR96lDdv_sendMessage);
      break;
    }
    case 0x676FE235: { // Mid_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dUn7liFH_sendMessage);
      break;
    }
    case 0x64B1268F: { // Mid_Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Zv4VVjXc_sendMessage);
      break;
    }
    case 0xA91022F8: { // Mid_Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nkm9FP5Q_sendMessage);
      break;
    }
    case 0x1AFCE6EB: { // 1025-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AO0uA7EH_sendMessage);
      break;
    }
    case 0xD8B5B1DB: { // 1025-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_b6x7AZCZ_sendMessage);
      break;
    }
    case 0x3794F656: { // 1025-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Bb8sFIG7_sendMessage);
      break;
    }
    case 0x94AE0ED9: { // 1025-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2FMrOZW0_sendMessage);
      break;
    }
    case 0xCC4DB41E: { // 1025-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dSid2viX_sendMessage);
      break;
    }
    case 0xAFE114F6: { // 1084-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ATxnuyN3_sendMessage);
      break;
    }
    case 0x98647BAD: { // 1084-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AznsxMEA_sendMessage);
      break;
    }
    case 0xA4661944: { // 1084-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vYApon8e_sendMessage);
      break;
    }
    case 0x505CED7B: { // 1125-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_T6xaByfw_sendMessage);
      break;
    }
    case 0x82611A6: { // 1125-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4OzZx5km_sendMessage);
      break;
    }
    case 0x1B990984: { // 1125-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_U8o876ZB_sendMessage);
      break;
    }
    case 0x5F0AFAC5: { // 1166-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_h5yQydY7_sendMessage);
      break;
    }
    case 0x25349984: { // 1166-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qCZ3LnLw_sendMessage);
      break;
    }
    case 0x8258EF5C: { // 1166-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MbShK3Jg_sendMessage);
      break;
    }
    case 0xBC1DF870: { // 1181-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yKCKSDcS_sendMessage);
      break;
    }
    case 0x9A5A2ED: { // 1181-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_IflMUPkz_sendMessage);
      break;
    }
    case 0x6714DCEB: { // 1181-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_f1GQgFBT_sendMessage);
      break;
    }
    case 0xE583CFFE: { // 1181-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OrBgqcBI_sendMessage);
      break;
    }
    case 0xA6D36AFA: { // 1181-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gvcO9erG_sendMessage);
      break;
    }
    case 0x2AD225: { // 1240-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JWz9yoNO_sendMessage);
      break;
    }
    case 0x7DD55B03: { // 1240-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UhSfu2si_sendMessage);
      break;
    }
    case 0xCF4D157B: { // 1240-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vhWqxrK7_sendMessage);
      break;
    }
    case 0x4DF9D195: { // 1281-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rWlf5vQr_sendMessage);
      break;
    }
    case 0x58CB5D1B: { // 1281-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6KdsW7Jr_sendMessage);
      break;
    }
    case 0xE926ADAA: { // 1281-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vIECjzOA_sendMessage);
      break;
    }
    case 0x839669AF: { // 1322-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7AJY4W4C_sendMessage);
      break;
    }
    case 0x89AA8991: { // 1322-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6sFcpR4Y_sendMessage);
      break;
    }
    case 0xC43C6A92: { // 1322-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gnLtuPT4_sendMessage);
      break;
    }
    case 0x44C46A9A: { // 1345-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RoY7vguA_sendMessage);
      break;
    }
    case 0x5B005CAA: { // 1352-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4KqSILvi_sendMessage);
      break;
    }
    case 0xBBD23460: { // 1352-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PUNdC6Uf_sendMessage);
      break;
    }
    case 0x23884B06: { // 1352-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ib5oMwEu_sendMessage);
      break;
    }
    case 0x91BE5650: { // 1352-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZlS4WCJh_sendMessage);
      break;
    }
    case 0x51E8B18D: { // 1352-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DsaQeoGc_sendMessage);
      break;
    }
    case 0x2CAD1402: { // 1352-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7qdUOggm_sendMessage);
      break;
    }
    case 0x8CE949DD: { // 1470-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fudxfYZI_sendMessage);
      break;
    }
    case 0x1A98A8C5: { // 1470-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ij3cSz4B_sendMessage);
      break;
    }
    case 0x4211FC92: { // 1470-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_oKGQeHE7_sendMessage);
      break;
    }
    case 0x86F6710B: { // 1470-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_US12jSWc_sendMessage);
      break;
    }
    case 0x102FAA7E: { // 1470-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6kiHIAtu_sendMessage);
      break;
    }
    case 0x1A325FAC: { // 1470-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RfK2KCgj_sendMessage);
      break;
    }
    case 0x5FF45DD7: { // 1602-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eWAGIg2L_sendMessage);
      break;
    }
    case 0xA63D49D8: { // 1609-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NEXuz19N_sendMessage);
      break;
    }
    case 0xFB1C4FF4: { // 1609-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3G5jmUUB_sendMessage);
      break;
    }
    case 0x2D7D2212: { // 1609-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_F4QLsFC2_sendMessage);
      break;
    }
    case 0xB4610071: { // 1609-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pRGGr1jS_sendMessage);
      break;
    }
    case 0x47BBE59E: { // 1609-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GwBr1cEL_sendMessage);
      break;
    }
    case 0xD51403EB: { // 1609-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2nhWJ6cV_sendMessage);
      break;
    }
    case 0x559ECA90: { // 1727-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CunywCnR_sendMessage);
      break;
    }
    case 0xB4F19FB9: { // 1727-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_t44ahREf_sendMessage);
      break;
    }
    case 0x7CE4DF88: { // 1727-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AxH5hjcr_sendMessage);
      break;
    }
    case 0x9FD7A64D: { // 1727-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zgvPvukY_sendMessage);
      break;
    }
    case 0x52C25AFE: { // 1727-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_aUNCouzS_sendMessage);
      break;
    }
    case 0x801C27A5: { // 1727-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HNXbsGFM_sendMessage);
      break;
    }
    case 0xE5875B65: { // 1859-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zizwtY1l_sendMessage);
      break;
    }
    case 0x40898D28: { // 1866-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TJ2oI67R_sendMessage);
      break;
    }
    case 0x9D616407: { // 1866-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Qiq47Gw9_sendMessage);
      break;
    }
    case 0xE8DBDB0: { // 1866-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gqctyWap_sendMessage);
      break;
    }
    case 0xD770731A: { // 1866-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Cyp69SMj_sendMessage);
      break;
    }
    case 0x124CD18B: { // 1866-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YiEHmaPo_sendMessage);
      break;
    }
    case 0x4017FCCD: { // 1866-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LT9lWEcg_sendMessage);
      break;
    }
    case 0x1B1DD5FB: { // 1984-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_08skz0q5_sendMessage);
      break;
    }
    case 0xA478FA4C: { // 1984-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DPFxHZcx_sendMessage);
      break;
    }
    case 0x97EB3671: { // 1984-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4wjopuE6_sendMessage);
      break;
    }
    case 0xF3FECDEE: { // 1984-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3HF70q1F_sendMessage);
      break;
    }
    case 0x9558C335: { // 1984-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OGlqaYd9_sendMessage);
      break;
    }
    case 0x4131288C: { // 1984-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xcYFfEzd_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_U6hWXIBI_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_M3NGLR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "High_Crshr";
        info->hash = 0xCFF7A234;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 2: {
        info->name = "High_Fldr";
        info->hash = 0x12EF45B9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 3: {
        info->name = "High_Gain";
        info->hash = 0xC05E9A15;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -25.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 4: {
        info->name = "High_Lmtr";
        info->hash = 0x8E596A67;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 5: {
        info->name = "High_Mix";
        info->hash = 0xAC5FA57F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 6: {
        info->name = "High_Smthr";
        info->hash = 0x585E4A54;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 7: {
        info->name = "High_Sqnc";
        info->hash = 0x14A9747F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 8: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 9: {
        info->name = "Low_Crshr";
        info->hash = 0xEBDB0C5E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 10: {
        info->name = "Low_Fldr";
        info->hash = 0xF974E926;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 11: {
        info->name = "Low_Gain";
        info->hash = 0xBB56D13C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -25.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Low_Lmtr";
        info->hash = 0xB4EFBAC1;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 13: {
        info->name = "Low_Mix";
        info->hash = 0x91FEF7A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 14: {
        info->name = "Low_Smthr";
        info->hash = 0x1665AEE9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 15: {
        info->name = "Low_Sqnc";
        info->hash = 0x860CA1D9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 16: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 17: {
        info->name = "Mid_Crshr";
        info->hash = 0xEA9DEF12;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 18: {
        info->name = "Mid_Fldr";
        info->hash = 0xDBF6FE0A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 19: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      case 20: {
        info->name = "Mid_Gain";
        info->hash = 0x23F5E910;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -25.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 21: {
        info->name = "Mid_Lmtr";
        info->hash = 0x33C126B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 22: {
        info->name = "Mid_Mix";
        info->hash = 0x676FE235;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 23: {
        info->name = "Mid_Smthr";
        info->hash = 0x64B1268F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 24: {
        info->name = "Mid_Sqnc";
        info->hash = 0xA91022F8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 25;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_M3NGLR::cVar_ql3VXeBD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GnRSOKup_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_7Jfx6kVS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FKldWI31_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_kvRmVjGG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yeZDHQg2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_32mPIaFF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_l35gwMw4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_2yCKe9az_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NB0bcgZZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_9j99Ghpc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Y5Vve4FR_sendMessage);
  cMsg_2ZcH2wq8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_Y5Vve4FR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9j99Ghpc, 1, m, &cVar_9j99Ghpc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_To6n0WAG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JBDmgtKp_sendMessage(_c, 0, m);
  cMsg_Zk2bCPAB_sendMessage(_c, 0, m);
  cMsg_y7qpGvyZ_sendMessage(_c, 0, m);
  cMsg_SK3R5y5E_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_cvHbHbu1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kJ7z6DUa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_o3KKLi0y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yF9xfJKZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_MTv7inTU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Bib9oW1x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_Fun23bOA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4nEeDL2m_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_us5BwXRI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Pa3Tto5p_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eP2TJVJp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_KhWENbIg_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_WDsXC5OK, 0, m, &cSlice_WDsXC5OK_sendMessage);
      break;
    }
    default: {
      cSwitchcase_1THpvIR7_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_WDsXC5OK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_RdeP85rc_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_RdeP85rc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_liKVdMJ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_RdeP85rc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_RdeP85rc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Bb8sFIG7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_ilhCIivW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_PGZpS5Nm_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_vgjH628y, 0, m, &cIf_vgjH628y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_vgjH628y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_hX1l2IVb_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_GL1AMJRJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_JHeXKdI1_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_oTp6Eqv2_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_liI9OMJL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_RF61qVnw, HV_BINOP_POW, 0, m, &cBinop_RF61qVnw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_RF61qVnw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_p1HMBAIU, 0, m, &cIf_p1HMBAIU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5dpzKgPd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_NPxLX31C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fLwOfCyZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_WcrQOLg2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_50MC5Kxz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GL1AMJRJ, 0, m, &cIf_GL1AMJRJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_WcrQOLg2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GL1AMJRJ, 1, m, &cIf_GL1AMJRJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_oTp6Eqv2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_5dpzKgPd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JHeXKdI1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_p1HMBAIU, 0, m, &cIf_p1HMBAIU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NPxLX31C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RF61qVnw, HV_BINOP_POW, 1, m, &cBinop_RF61qVnw_sendMessage);
  cMsg_liI9OMJL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_p1HMBAIU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_4V61DIMi_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_PGZpS5Nm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vgjH628y, 1, m, &cIf_vgjH628y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hX1l2IVb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CZ9pnw0y_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_K7fLyQ6g_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hvS4MyIS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fLwOfCyZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_50MC5Kxz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HsgKnrMy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_p1HMBAIU, 1, m, &cIf_p1HMBAIU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_dgGLR5KI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9nfvnlgT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_9nfvnlgT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_4V61DIMi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_SVOyaa03_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_hvS4MyIS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CZ9pnw0y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dgGLR5KI, HV_BINOP_EQ, 1, m, &cBinop_dgGLR5KI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_K7fLyQ6g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HsgKnrMy, HV_BINOP_GREATER_THAN, 1, m, &cBinop_HsgKnrMy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ExSIrTpz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SVOyaa03_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_Dxd8ROY3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dgGLR5KI, HV_BINOP_EQ, 0, m, &cBinop_dgGLR5KI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lOFp85pm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ilhCIivW, 0, m, &cVar_ilhCIivW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YzUVVxuO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HsgKnrMy, HV_BINOP_GREATER_THAN, 0, m, &cBinop_HsgKnrMy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_0O2EmVWg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_G7HsMAfD_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_qsBlBEuK, 0, m, &cIf_qsBlBEuK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_qsBlBEuK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_n4Kv73db_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_UKswaPmp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_3bD1CYCj_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_yUhbYks1_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_hxhax6DE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_8u6yub6R, HV_BINOP_POW, 0, m, &cBinop_8u6yub6R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8u6yub6R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_n33RaFAP, 0, m, &cIf_n33RaFAP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rVZhxrl1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_GTdJWgXe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_w16kNloL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UKswaPmp, 0, m, &cIf_UKswaPmp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_swKspCRZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_8gs5lTEn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8gs5lTEn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UKswaPmp, 1, m, &cIf_UKswaPmp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yUhbYks1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_rVZhxrl1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3bD1CYCj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_n33RaFAP, 0, m, &cIf_n33RaFAP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GTdJWgXe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8u6yub6R, HV_BINOP_POW, 1, m, &cBinop_8u6yub6R_sendMessage);
  cMsg_hxhax6DE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_n33RaFAP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SN6yMfeO_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Sk2CETvL_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_G7HsMAfD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qsBlBEuK, 1, m, &cIf_qsBlBEuK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_n4Kv73db_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_q6k51MMU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_72wF4RDB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_TFutrl2h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_swKspCRZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_w16kNloL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9GcG7c5r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_n33RaFAP, 1, m, &cIf_n33RaFAP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wHEvJvre_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vip0j28e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_vip0j28e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SN6yMfeO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Sk2CETvL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7tn15gxd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_TFutrl2h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_q6k51MMU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wHEvJvre, HV_BINOP_EQ, 1, m, &cBinop_wHEvJvre_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_72wF4RDB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9GcG7c5r, HV_BINOP_GREATER_THAN, 1, m, &cBinop_9GcG7c5r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NtsdZEI9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0O2EmVWg, 0, m, &cVar_0O2EmVWg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BMPIKoye_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wHEvJvre, HV_BINOP_EQ, 0, m, &cBinop_wHEvJvre_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YAKJ6V8W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9GcG7c5r, HV_BINOP_GREATER_THAN, 0, m, &cBinop_9GcG7c5r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DKBj3IQA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7tn15gxd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_Wt3XN8n0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_MJxQyu4L_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_wW85KZFh, 0, m, &cIf_wW85KZFh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_wW85KZFh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_41Jr6haK_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_fNT0RIMS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_PCxLa8bn_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_mzQa9Wpf_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_461zXvgl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_BiimWRbj, HV_BINOP_POW, 0, m, &cBinop_BiimWRbj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_BiimWRbj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HlES1E2R, 0, m, &cIf_HlES1E2R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_d7lrJQm7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_ev82IhOl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DhdhgCS6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fNT0RIMS, 0, m, &cIf_fNT0RIMS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Sr29ien5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_P4gpRFPr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_P4gpRFPr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fNT0RIMS, 1, m, &cIf_fNT0RIMS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mzQa9Wpf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_d7lrJQm7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PCxLa8bn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_HlES1E2R, 0, m, &cIf_HlES1E2R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ev82IhOl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BiimWRbj, HV_BINOP_POW, 1, m, &cBinop_BiimWRbj_sendMessage);
  cMsg_461zXvgl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_HlES1E2R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_CbFYqD6F_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_MJxQyu4L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wW85KZFh, 1, m, &cIf_wW85KZFh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_41Jr6haK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_94C9xG4E_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_agXtg9Pn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_S558uAZc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Sr29ien5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DhdhgCS6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VIwDE4DO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HlES1E2R, 1, m, &cIf_HlES1E2R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_x7ayv0Av_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2qbcf7y6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_2qbcf7y6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_CbFYqD6F_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_3WiuThjt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_S558uAZc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_agXtg9Pn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VIwDE4DO, HV_BINOP_GREATER_THAN, 1, m, &cBinop_VIwDE4DO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_94C9xG4E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_x7ayv0Av, HV_BINOP_EQ, 1, m, &cBinop_x7ayv0Av_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YdVx4wgh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3WiuThjt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_yXjCeI3a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_x7ayv0Av, HV_BINOP_EQ, 0, m, &cBinop_x7ayv0Av_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZLqamN98_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VIwDE4DO, HV_BINOP_GREATER_THAN, 0, m, &cBinop_VIwDE4DO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WXedu33J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Wt3XN8n0, 0, m, &cVar_Wt3XN8n0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_0Xe0t8Md_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_QnFa06Dw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_6RKw33lT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_DXMkUsoV, 0, m, &cSlice_DXMkUsoV_sendMessage);
      break;
    }
    default: {
      cSwitchcase_JV5wiF8Q_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_DXMkUsoV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_TPpJbbIA_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_TPpJbbIA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_PQWoDFsm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_TPpJbbIA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_TPpJbbIA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_AO0uA7EH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_JV5wiF8Q_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ubpvKZbI, 0, m, &cSlice_ubpvKZbI_sendMessage);
      break;
    }
    default: {
      cSwitchcase_KhWENbIg_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_ubpvKZbI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_lFSCuXzV_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_lFSCuXzV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_rpFWZSET_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_lFSCuXzV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_lFSCuXzV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_dSid2viX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_1THpvIR7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_8Jtws7WA, 0, m, &cSlice_8Jtws7WA_sendMessage);
      break;
    }
    default: {
      cSwitchcase_SOVGYyhA_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_8Jtws7WA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_tAgkGpu4_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_tAgkGpu4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_kT3t7Lp8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_tAgkGpu4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_tAgkGpu4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_b6x7AZCZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_SOVGYyhA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_M5GTsrPh, 0, m, &cSlice_M5GTsrPh_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_M5GTsrPh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_sTqC42hw_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_sTqC42hw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_bS78F0D1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_sTqC42hw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_sTqC42hw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_2FMrOZW0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_j8JFRl8H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HjFfRX4M, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_1RBM2Fua_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_erOim5mk, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_jB283HTb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gUvg6R0R, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_b5SVdzlB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oKnTNpOI, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_yzyd8fXq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gyukU4Rh, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_WsKrn2hM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_5jdizEDi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_5jdizEDi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2TmjvFio, HV_BINOP_DIVIDE, 1, m, &cBinop_2TmjvFio_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Xlg7cCZh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_aeBfqWol_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_vGLzFggX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ce0jtsZB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_aeBfqWol_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vGLzFggX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2TmjvFio, HV_BINOP_DIVIDE, 0, m, &cBinop_2TmjvFio_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Xlg7cCZh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ce0jtsZB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_2TmjvFio_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mQKX6XPx, HV_BINOP_MULTIPLY, 1, m, &cBinop_mQKX6XPx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mQKX6XPx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KV2HY9gc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_14ppWCy9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_nZ1bFi1l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_1Je7fjyg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_BAcDWdht_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_sIhAvWBz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_bKTULUwq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_8bR5ThEr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8bR5ThEr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mQKX6XPx, HV_BINOP_MULTIPLY, 0, m, &cBinop_mQKX6XPx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UKxOLx98_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_PdcPGAWi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PdcPGAWi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QkhJUBES_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_Kk78ZmhZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zTGfsGJY, 1, m, &cVar_zTGfsGJY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_zTGfsGJY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PAAMekwz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_tGf8vIZ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Bw5FfohW, HV_BINOP_MULTIPLY, 1, m, &cBinop_Bw5FfohW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xCWTkSJw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_tGf8vIZ4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_RRWpvt8K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_8IkvdGgD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8IkvdGgD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EV51tdOH, HV_BINOP_MULTIPLY, 1, m, &cBinop_EV51tdOH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8y8lj7in_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yLRzHrmf, HV_BINOP_MULTIPLY, 1, m, &cBinop_yLRzHrmf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pCbbjBCn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_8y8lj7in_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_soTwuT0r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jNkphpB5, HV_BINOP_MULTIPLY, 1, m, &cBinop_jNkphpB5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YyPgO0hE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Lg4jluNi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Lg4jluNi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8wtWOjFl, HV_BINOP_MULTIPLY, 1, m, &cBinop_8wtWOjFl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_RxJjPI2z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_14sfuLyF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_bKTULUwq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sytcwMAC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_Fmqu51TX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_UKxOLx98_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KV2HY9gc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_nZ1bFi1l_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_14ppWCy9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_BAcDWdht_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_1Je7fjyg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_vYApon8e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_sIhAvWBz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_AznsxMEA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_EEhWOQwP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ATxnuyN3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_QkhJUBES_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_yP1QvEnE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yP1QvEnE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_y5gtpmHR, HV_BINOP_MULTIPLY, 1, m, &cBinop_y5gtpmHR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_y5gtpmHR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_GcNHjKNS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GcNHjKNS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_EEhWOQwP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_PAAMekwz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_9N9MsKGh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9N9MsKGh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_W6VwygLs_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SVcSAdmV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MXRaKrdH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8M4oxbHu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZlreEdjn_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YZz2Q3yt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Bw5FfohW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_j8JFRl8H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_EV51tdOH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1RBM2Fua_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_yLRzHrmf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jB283HTb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_jNkphpB5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_b5SVdzlB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_8wtWOjFl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yzyd8fXq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_2nlmsEN7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RxJjPI2z, 0, m, &cVar_RxJjPI2z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nGvTNfFo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Fmqu51TX, 1, m, &cVar_Fmqu51TX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8M4oxbHu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yLRzHrmf, HV_BINOP_MULTIPLY, 0, m, &cBinop_yLRzHrmf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MXRaKrdH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jNkphpB5, HV_BINOP_MULTIPLY, 0, m, &cBinop_jNkphpB5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZlreEdjn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EV51tdOH, HV_BINOP_MULTIPLY, 0, m, &cBinop_EV51tdOH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SVcSAdmV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8wtWOjFl, HV_BINOP_MULTIPLY, 0, m, &cBinop_8wtWOjFl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_W6VwygLs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_YZz2Q3yt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Bw5FfohW, HV_BINOP_MULTIPLY, 0, m, &cBinop_Bw5FfohW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sytcwMAC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zTGfsGJY, 0, m, &cVar_zTGfsGJY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_14sfuLyF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Fmqu51TX, 0, m, &cVar_Fmqu51TX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rRkgAid3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fJoztNsE, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_yEilgHju_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RcuSswvW, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_QRKE9NlX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FxeXEShO, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_SmGALgct_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MiVFOheF, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Qv7A7StH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_jfRghso8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_jfRghso8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cWh89vie, HV_BINOP_DIVIDE, 1, m, &cBinop_cWh89vie_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GjFAexTS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_jvk1xEIA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_vLCp4JBH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HPfxdd1Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_jvk1xEIA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vLCp4JBH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cWh89vie, HV_BINOP_DIVIDE, 0, m, &cBinop_cWh89vie_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GjFAexTS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HPfxdd1Z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_cWh89vie_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pa2WIAbt, HV_BINOP_MULTIPLY, 1, m, &cBinop_pa2WIAbt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pa2WIAbt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sGRkCLn6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2EPY0lZc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_PSkcyD6p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_3GCDqf6Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_Xw36Ly8C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_cTgHQflF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_wrEDKJ4n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_1r1yv1eK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1r1yv1eK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pa2WIAbt, HV_BINOP_MULTIPLY, 0, m, &cBinop_pa2WIAbt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_SSOnLJmk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_qdBFvOpP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qdBFvOpP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tdqfVwnM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_vuAcTzs4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lzdIj8Az, HV_BINOP_MULTIPLY, 1, m, &cBinop_lzdIj8Az_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gZ34L8yw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3MvNCtUo, 1, m, &cVar_3MvNCtUo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MWbwCWgt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QcrELVKp, HV_BINOP_MULTIPLY, 1, m, &cBinop_QcrELVKp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_d3idHCjF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_wptFkydp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wptFkydp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8GhSIhaV, HV_BINOP_MULTIPLY, 1, m, &cBinop_8GhSIhaV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_3MvNCtUo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BRyFTDDk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_y9qLVKml_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aBZ6SJki_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_wrEDKJ4n_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eeIstNca_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_vUPwZfUl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_SSOnLJmk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sGRkCLn6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_PSkcyD6p_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2EPY0lZc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_Xw36Ly8C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_3GCDqf6Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_U8o876ZB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_cTgHQflF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_4OzZx5km_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_e62NWFA1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_T6xaByfw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_tdqfVwnM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ZZfTQvbG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZZfTQvbG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_D7ntjWDR, HV_BINOP_MULTIPLY, 1, m, &cBinop_D7ntjWDR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_D7ntjWDR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_qHAqBia7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qHAqBia7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_e62NWFA1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_BRyFTDDk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_6edWz0ek_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6edWz0ek_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_k4CCyMpa_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_007tDNPW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nfw6wfr7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tF45zr7t_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zbKvJBzQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rRkgAid3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_lzdIj8Az_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yEilgHju_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_QcrELVKp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QRKE9NlX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_8GhSIhaV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SmGALgct_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_lYXiZWNr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_y9qLVKml, 0, m, &cVar_y9qLVKml_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Bi6iiFjY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vUPwZfUl, 1, m, &cVar_vUPwZfUl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eeIstNca_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3MvNCtUo, 0, m, &cVar_3MvNCtUo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aBZ6SJki_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vUPwZfUl, 0, m, &cVar_vUPwZfUl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nfw6wfr7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lzdIj8Az, HV_BINOP_MULTIPLY, 0, m, &cBinop_lzdIj8Az_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_007tDNPW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QcrELVKp, HV_BINOP_MULTIPLY, 0, m, &cBinop_QcrELVKp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_k4CCyMpa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8GhSIhaV, HV_BINOP_MULTIPLY, 0, m, &cBinop_8GhSIhaV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tF45zr7t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zbKvJBzQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_zbKvJBzQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Az8HbQZE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_18VZOHeW, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_fL5PJK1i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OYGndzVP, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_YCdX5bmd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_G19O8Em8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_OZPn0Yz7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UdPyVjxh, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_wRB1xdIv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KakaJMOi, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_2jHbEu4K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_lm3vVndU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_lm3vVndU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_u3VSnF69, HV_BINOP_DIVIDE, 1, m, &cBinop_u3VSnF69_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DqltwkTB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_XeYpLKkx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_lfkb3u0o_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NsfYPlLH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_XeYpLKkx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_lfkb3u0o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_u3VSnF69, HV_BINOP_DIVIDE, 0, m, &cBinop_u3VSnF69_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DqltwkTB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NsfYPlLH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_u3VSnF69_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_14cz6r8U, HV_BINOP_MULTIPLY, 1, m, &cBinop_14cz6r8U_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_14cz6r8U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Eoy6qyiE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_e3GAsfVO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_oCoA0Eh5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_zpDi2o4Q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_bD80mJoA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_93CoqPn8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_KccM0ij1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_73d6uWOz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_73d6uWOz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_14cz6r8U, HV_BINOP_MULTIPLY, 0, m, &cBinop_14cz6r8U_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_uVhxgGlP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_V19Z3Dof_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_V19Z3Dof_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cJ4NbxGy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_7nlfJ4Uy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0Ynmkm4x, HV_BINOP_MULTIPLY, 1, m, &cBinop_0Ynmkm4x_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_InC23i0r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_kBLgEsih_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kBLgEsih_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_7nlfJ4Uy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_1IWfEKZU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ZQ6TCgz6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZQ6TCgz6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bErAuDLf, HV_BINOP_MULTIPLY, 1, m, &cBinop_bErAuDLf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nd5iXNsH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5o4eG2dK, HV_BINOP_MULTIPLY, 1, m, &cBinop_5o4eG2dK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oK3TIwXa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_J8C4OrrC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_J8C4OrrC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_nd5iXNsH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Zccd2GR2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DohczLiV, 1, m, &cVar_DohczLiV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_dDPRE2uh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_E4xRQesg, HV_BINOP_MULTIPLY, 1, m, &cBinop_E4xRQesg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xe7MurNZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_sJI9JbTf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sJI9JbTf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6VRZi4uQ, HV_BINOP_MULTIPLY, 1, m, &cBinop_6VRZi4uQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_DohczLiV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jY6nUf7s_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_N37D4UJl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DfmKiO3k_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_KccM0ij1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3RsMmRz8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_GTareE6u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_uVhxgGlP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_e3GAsfVO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_bD80mJoA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Eoy6qyiE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_oCoA0Eh5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_zpDi2o4Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_MbShK3Jg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_93CoqPn8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qCZ3LnLw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_AyiCfpzo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_h5yQydY7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_cJ4NbxGy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_MCF4FBfn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MCF4FBfn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_j1nXY9qV, HV_BINOP_MULTIPLY, 1, m, &cBinop_j1nXY9qV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_j1nXY9qV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_keQPhif4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_keQPhif4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_AyiCfpzo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_jY6nUf7s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_wQgijf6y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wQgijf6y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FxWQ49rW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_597JrO4u_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KgIkKLBx_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7hizDIJM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BZIljohF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nZZgJQtD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0Ynmkm4x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Az8HbQZE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_bErAuDLf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fL5PJK1i_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_5o4eG2dK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YCdX5bmd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_E4xRQesg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OZPn0Yz7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_6VRZi4uQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wRB1xdIv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_ADnWaKRf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_N37D4UJl, 0, m, &cVar_N37D4UJl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OKbak5Qw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GTareE6u, 1, m, &cVar_GTareE6u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7hizDIJM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5o4eG2dK, HV_BINOP_MULTIPLY, 0, m, &cBinop_5o4eG2dK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_597JrO4u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6VRZi4uQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_6VRZi4uQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BZIljohF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bErAuDLf, HV_BINOP_MULTIPLY, 0, m, &cBinop_bErAuDLf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nZZgJQtD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0Ynmkm4x, HV_BINOP_MULTIPLY, 0, m, &cBinop_0Ynmkm4x_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FxWQ49rW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_KgIkKLBx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_E4xRQesg, HV_BINOP_MULTIPLY, 0, m, &cBinop_E4xRQesg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3RsMmRz8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DohczLiV, 0, m, &cVar_DohczLiV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DfmKiO3k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GTareE6u, 0, m, &cVar_GTareE6u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_C6PxY0gE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0Xe0t8Md, 1, m, &cIf_0Xe0t8Md_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_stolRULu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_QnFa06Dw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_ziXlNZy1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_stolRULu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_8yeJWXpe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0Xe0t8Md, 0, m, &cIf_0Xe0t8Md_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4V61DIMi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TBOA38JT, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_QnFa06Dw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zt1p5iHv, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_CbFYqD6F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_s1aud8vu, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Sk2CETvL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_8yeJWXpe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SN6yMfeO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_C6PxY0gE_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ziXlNZy1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_gKHtUAEN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_l1CUhheM, 0, m, &cSlice_l1CUhheM_sendMessage);
      break;
    }
    default: {
      cSwitchcase_fJj2J4W8_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_l1CUhheM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_sxw2EUIv_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_sxw2EUIv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_ZfFa73wI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_sxw2EUIv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_sxw2EUIv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_f1GQgFBT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_0OWC80Ih_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_OllWnn3s_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_ovgx1ZnG, 0, m, &cIf_ovgx1ZnG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_ovgx1ZnG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_wrfW13UW_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_kR5ZplcX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_9djFX5bz_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_Nv6iK69d_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_I4HBcR2r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_vHR4G2dM, HV_BINOP_POW, 0, m, &cBinop_vHR4G2dM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vHR4G2dM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_838UAECk, 0, m, &cIf_838UAECk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1x7OQmTP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_8YbQjhpw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZuK7wtv2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_qgv9OnCZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KAcBER3c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kR5ZplcX, 0, m, &cIf_kR5ZplcX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qgv9OnCZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kR5ZplcX, 1, m, &cIf_kR5ZplcX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Nv6iK69d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_1x7OQmTP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9djFX5bz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_838UAECk, 0, m, &cIf_838UAECk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8YbQjhpw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vHR4G2dM, HV_BINOP_POW, 1, m, &cBinop_vHR4G2dM_sendMessage);
  cMsg_I4HBcR2r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_838UAECk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_G7T0txzm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_OllWnn3s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ovgx1ZnG, 1, m, &cIf_ovgx1ZnG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wrfW13UW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7XpZFle8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1ifBOJaR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_b0trpE4l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZuK7wtv2_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KAcBER3c_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_iY9QWaFZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_838UAECk, 1, m, &cIf_838UAECk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_AQMdPDA5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1dh5IPGq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_1dh5IPGq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_G7T0txzm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_d1AOSc7o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_b0trpE4l_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1ifBOJaR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iY9QWaFZ, HV_BINOP_GREATER_THAN, 1, m, &cBinop_iY9QWaFZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7XpZFle8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AQMdPDA5, HV_BINOP_EQ, 1, m, &cBinop_AQMdPDA5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8y3PA2BG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_d1AOSc7o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_CmuoZJQI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0OWC80Ih, 0, m, &cVar_0OWC80Ih_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FuMK0CRB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iY9QWaFZ, HV_BINOP_GREATER_THAN, 0, m, &cBinop_iY9QWaFZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fHTGhf7B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AQMdPDA5, HV_BINOP_EQ, 0, m, &cBinop_AQMdPDA5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_C4rwO80C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_drkNhfVg_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_C5YFTRm6, 0, m, &cIf_C5YFTRm6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_C5YFTRm6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_bAbP54QD_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_SzczcYKY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_PORRxXFg_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_ynxwE5Ll_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_CLgSFbGA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_O2O2SZm8, HV_BINOP_POW, 0, m, &cBinop_O2O2SZm8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_O2O2SZm8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6q7eTYbU, 0, m, &cIf_6q7eTYbU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VE9LUaUV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_aeuoWKyp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jQjr6Ryg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SzczcYKY, 0, m, &cIf_SzczcYKY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1ROUuGGM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_c4K8cKVO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_c4K8cKVO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SzczcYKY, 1, m, &cIf_SzczcYKY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ynxwE5Ll_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_VE9LUaUV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PORRxXFg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_6q7eTYbU, 0, m, &cIf_6q7eTYbU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_aeuoWKyp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_O2O2SZm8, HV_BINOP_POW, 1, m, &cBinop_O2O2SZm8_sendMessage);
  cMsg_CLgSFbGA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_6q7eTYbU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zx4HO9sx_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PpPxmBU2_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_drkNhfVg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_C5YFTRm6, 1, m, &cIf_C5YFTRm6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bAbP54QD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WvZrMsaJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_08Ul6ScZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GSC9HzHL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1ROUuGGM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jQjr6Ryg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JhPp6tev_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6q7eTYbU, 1, m, &cIf_6q7eTYbU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VoU17xkD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uTpJ1ZLF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_uTpJ1ZLF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zx4HO9sx_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PpPxmBU2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Alw8eh8f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_GSC9HzHL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_08Ul6ScZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JhPp6tev, HV_BINOP_GREATER_THAN, 1, m, &cBinop_JhPp6tev_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WvZrMsaJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VoU17xkD, HV_BINOP_EQ, 1, m, &cBinop_VoU17xkD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_duGWxrug_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JhPp6tev, HV_BINOP_GREATER_THAN, 0, m, &cBinop_JhPp6tev_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zNf8aIoK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VoU17xkD, HV_BINOP_EQ, 0, m, &cBinop_VoU17xkD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5LgViJpn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Alw8eh8f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_9zxeTRuC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_C4rwO80C, 0, m, &cVar_C4rwO80C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_muLLWIrF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_thBim5mn_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_aXVTcsCE, 0, m, &cIf_aXVTcsCE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_aXVTcsCE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_KjoRpBSG_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_2sfG8a9S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_Aaw1SK4O_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_cKbpjMi8_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_pn91hTIg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_yQurWq8l, HV_BINOP_POW, 0, m, &cBinop_yQurWq8l_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yQurWq8l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SpdYZ3QJ, 0, m, &cIf_SpdYZ3QJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_48vgG9FE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_UrDsOX71_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_t996Qjs8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ZGJzl868_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7hu1NPy9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2sfG8a9S, 0, m, &cIf_2sfG8a9S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZGJzl868_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2sfG8a9S, 1, m, &cIf_2sfG8a9S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_cKbpjMi8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_48vgG9FE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Aaw1SK4O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_SpdYZ3QJ, 0, m, &cIf_SpdYZ3QJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UrDsOX71_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yQurWq8l, HV_BINOP_POW, 1, m, &cBinop_yQurWq8l_sendMessage);
  cMsg_pn91hTIg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_SpdYZ3QJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_9pBdf16G_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_thBim5mn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aXVTcsCE, 1, m, &cIf_aXVTcsCE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_KjoRpBSG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NYWASrUr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XLkNqtxa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4pNDsJwU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_t996Qjs8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7hu1NPy9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_I6mN5O1u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SpdYZ3QJ, 1, m, &cIf_SpdYZ3QJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XZEofKd3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_idpRv8sk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_idpRv8sk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_9pBdf16G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_L7OCsNc4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_4pNDsJwU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XLkNqtxa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_I6mN5O1u, HV_BINOP_GREATER_THAN, 1, m, &cBinop_I6mN5O1u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NYWASrUr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XZEofKd3, HV_BINOP_EQ, 1, m, &cBinop_XZEofKd3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1nnUCPwN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_L7OCsNc4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_gdosaFdc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_I6mN5O1u, HV_BINOP_GREATER_THAN, 0, m, &cBinop_I6mN5O1u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nSHxesGV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_muLLWIrF, 0, m, &cVar_muLLWIrF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jfv86nq5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XZEofKd3, HV_BINOP_EQ, 0, m, &cBinop_XZEofKd3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_hNbJcHOs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_3FXzuSru_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_mNWu4f9e_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_XLieBJ9T, 0, m, &cSlice_XLieBJ9T_sendMessage);
      break;
    }
    default: {
      cSwitchcase_I0VS8sx1_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_XLieBJ9T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_GJIGL4mg_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_GJIGL4mg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_St2dqy6q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_GJIGL4mg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_GJIGL4mg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_yKCKSDcS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_I0VS8sx1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_JRy7pkkS, 0, m, &cSlice_JRy7pkkS_sendMessage);
      break;
    }
    default: {
      cSwitchcase_gKHtUAEN_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_JRy7pkkS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_sepV5LEu_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_sepV5LEu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_6Igd03oL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_sepV5LEu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_sepV5LEu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_gvcO9erG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_fJj2J4W8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_A1tPZnus, 0, m, &cSlice_A1tPZnus_sendMessage);
      break;
    }
    default: {
      cSwitchcase_4Yy7VNkY_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_A1tPZnus_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_KU4ANyFa_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_KU4ANyFa_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_R6hjSGv6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_KU4ANyFa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_KU4ANyFa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_IflMUPkz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_4Yy7VNkY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_aSspGPaE, 0, m, &cSlice_aSspGPaE_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_aSspGPaE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_YVKUq00Q_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_YVKUq00Q_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_hVLM6RAA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_YVKUq00Q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_YVKUq00Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_OrBgqcBI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_b0pVu6of_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zMjyTr0u, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ewdyKIhq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_v1KOckVX, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_yo2ZyoVc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KUugnaus, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_C9TLyfwT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nSPTYtSm, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_FT9lqoEx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dbTiADvR, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_36eWTSDP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_zhPdcORu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_zhPdcORu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nCHeNoEq, HV_BINOP_DIVIDE, 1, m, &cBinop_nCHeNoEq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OuNIMusG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_Io0DVB3m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_QMtgHK7w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_J3k5x1Jz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_Io0DVB3m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QMtgHK7w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nCHeNoEq, HV_BINOP_DIVIDE, 0, m, &cBinop_nCHeNoEq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OuNIMusG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_J3k5x1Jz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_nCHeNoEq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gH7JcNnV, HV_BINOP_MULTIPLY, 1, m, &cBinop_gH7JcNnV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gH7JcNnV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8aFu44hN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4DmbZxlj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_iyuWwaHd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_KC8iZW9J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_rB1GYABt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_gKuYarJC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_eFQ9jrOB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_AGSi0xyP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_AGSi0xyP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gH7JcNnV, HV_BINOP_MULTIPLY, 0, m, &cBinop_gH7JcNnV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xHLhPovQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_keSzNwVU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_keSzNwVU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wzynmf3o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_zJxDx5ho_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bUAJGZdE, 1, m, &cVar_bUAJGZdE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_bUAJGZdE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4wL2t4b6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_i29q8whd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_naic3jgd, HV_BINOP_MULTIPLY, 1, m, &cBinop_naic3jgd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xayPXJjL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_i29q8whd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PZMaizyq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_s2acWSo7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_s2acWSo7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lxRJwcq7, HV_BINOP_MULTIPLY, 1, m, &cBinop_lxRJwcq7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_z8ddE1hI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MxrHFDrm, HV_BINOP_MULTIPLY, 1, m, &cBinop_MxrHFDrm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bDBGgkyX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_z8ddE1hI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jQGGLyj5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SW3xK0YI, HV_BINOP_MULTIPLY, 1, m, &cBinop_SW3xK0YI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9SP3cA2h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_1buGXDyh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1buGXDyh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oRcytKaD, HV_BINOP_MULTIPLY, 1, m, &cBinop_oRcytKaD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_upquHCo0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wGsytXEj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_eFQ9jrOB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1h0meMeM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_LwcHvIQe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_xHLhPovQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8aFu44hN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_iyuWwaHd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4DmbZxlj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_rB1GYABt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_KC8iZW9J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_vhWqxrK7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_gKuYarJC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_UhSfu2si_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_fR3Bsvb1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_JWz9yoNO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_wzynmf3o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Z2ygeFsq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Z2ygeFsq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Qmn1gKH4, HV_BINOP_MULTIPLY, 1, m, &cBinop_Qmn1gKH4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Qmn1gKH4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_RI0qczEe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_RI0qczEe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_fR3Bsvb1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_4wL2t4b6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_lq6EeYRU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_lq6EeYRU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_h3BgDMOc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PqoiNGdO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Pj7HeDMM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fu5CfrrP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Y6A78kdp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AxPKWf3z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_naic3jgd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_b0pVu6of_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_lxRJwcq7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ewdyKIhq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_MxrHFDrm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yo2ZyoVc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_SW3xK0YI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_C9TLyfwT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_oRcytKaD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FT9lqoEx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_dmxD2Orf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_upquHCo0, 0, m, &cVar_upquHCo0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PdRlN9QL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LwcHvIQe, 1, m, &cVar_LwcHvIQe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PqoiNGdO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oRcytKaD, HV_BINOP_MULTIPLY, 0, m, &cBinop_oRcytKaD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fu5CfrrP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MxrHFDrm, HV_BINOP_MULTIPLY, 0, m, &cBinop_MxrHFDrm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Y6A78kdp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lxRJwcq7, HV_BINOP_MULTIPLY, 0, m, &cBinop_lxRJwcq7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Pj7HeDMM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SW3xK0YI, HV_BINOP_MULTIPLY, 0, m, &cBinop_SW3xK0YI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_AxPKWf3z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_naic3jgd, HV_BINOP_MULTIPLY, 0, m, &cBinop_naic3jgd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_h3BgDMOc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_wGsytXEj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LwcHvIQe, 0, m, &cVar_LwcHvIQe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1h0meMeM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bUAJGZdE, 0, m, &cVar_bUAJGZdE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NcqTEQFQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_In1qSAwl, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_0vjJoZnq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_d6TooCRm, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_jFUjElaZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_enFHH8Ay, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_0lsRbmYL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mmsOHDsg, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_5DLDBZ1f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7YBTf8Ir_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_7YBTf8Ir_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SdtLZivf, HV_BINOP_DIVIDE, 1, m, &cBinop_SdtLZivf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eIwpGLlY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_jWBaNTDc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_vCToQfhU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_os7FgVkm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_jWBaNTDc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vCToQfhU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SdtLZivf, HV_BINOP_DIVIDE, 0, m, &cBinop_SdtLZivf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eIwpGLlY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_os7FgVkm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_SdtLZivf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zOMfdtke, HV_BINOP_MULTIPLY, 1, m, &cBinop_zOMfdtke_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zOMfdtke_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XyBwFYSJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_owXW9flv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_MjiU56rR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_uRDvDLYO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_LRx20xf1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_PXYX9XRX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_pvdmewzu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_A0CdxEGM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_A0CdxEGM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zOMfdtke, HV_BINOP_MULTIPLY, 0, m, &cBinop_zOMfdtke_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0tXRfB3d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_oobI50kf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_oobI50kf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lbb28YA3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_UzTjglYL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vm4zM030, HV_BINOP_MULTIPLY, 1, m, &cBinop_vm4zM030_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6R6IQPyN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qkHmX6zU, 1, m, &cVar_qkHmX6zU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_BTYmbXHq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ez5vnkPF, HV_BINOP_MULTIPLY, 1, m, &cBinop_Ez5vnkPF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KrIQg34M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_9tg80NzS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9tg80NzS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_q18oW5sx, HV_BINOP_MULTIPLY, 1, m, &cBinop_q18oW5sx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_qkHmX6zU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SUznXiNM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_yQDk3Mz6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tRCQKnD2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_pvdmewzu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rPoNzBCV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_zrTWzWvA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_0tXRfB3d_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XyBwFYSJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_MjiU56rR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_owXW9flv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_LRx20xf1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_uRDvDLYO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_vIECjzOA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_PXYX9XRX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_6KdsW7Jr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_Q3tJWCOK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_rWlf5vQr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_lbb28YA3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_liWBA9wu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_liWBA9wu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fQU9GOUK, HV_BINOP_MULTIPLY, 1, m, &cBinop_fQU9GOUK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fQU9GOUK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_RdnD8hU8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_RdnD8hU8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Q3tJWCOK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_SUznXiNM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_GYf5zNzq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GYf5zNzq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4OHeola3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_j6VqobAc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xGYwdZZr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9GMwfhuQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_lXf5AGCg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NcqTEQFQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_vm4zM030_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0vjJoZnq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_Ez5vnkPF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jFUjElaZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_q18oW5sx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0lsRbmYL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_mvvSdUVk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yQDk3Mz6, 0, m, &cVar_yQDk3Mz6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YD90RdvO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zrTWzWvA, 1, m, &cVar_zrTWzWvA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rPoNzBCV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qkHmX6zU, 0, m, &cVar_qkHmX6zU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tRCQKnD2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zrTWzWvA, 0, m, &cVar_zrTWzWvA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xGYwdZZr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vm4zM030, HV_BINOP_MULTIPLY, 0, m, &cBinop_vm4zM030_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_j6VqobAc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ez5vnkPF, HV_BINOP_MULTIPLY, 0, m, &cBinop_Ez5vnkPF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4OHeola3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_q18oW5sx, HV_BINOP_MULTIPLY, 0, m, &cBinop_q18oW5sx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9GMwfhuQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lXf5AGCg, HV_BINOP_MULTIPLY, 0, m, &cBinop_lXf5AGCg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QriXdPoo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_a5QhekHt, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_r1a4WTJY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VUIuS4Kl, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_bFgC6YVJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kwZsL6j3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_yL31troi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_B6RArmUb, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_sUIlDXcd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_x982265M, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_fS2V1A19_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_GZfx6yIV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_GZfx6yIV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_s6yEP2aS, HV_BINOP_DIVIDE, 1, m, &cBinop_s6yEP2aS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Y8N6qunP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_5OglSNXf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_YvjSXT4Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TyFXF32p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_5OglSNXf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_YvjSXT4Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_s6yEP2aS, HV_BINOP_DIVIDE, 0, m, &cBinop_s6yEP2aS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Y8N6qunP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TyFXF32p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_s6yEP2aS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1OH8vj4b, HV_BINOP_MULTIPLY, 1, m, &cBinop_1OH8vj4b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1OH8vj4b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JeVK8S1P_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mBUPFihP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_rowRvrND_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_SjPfXjqH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_SlwIXdQ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_csAIkZPR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_EsozX08s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_RMKMveo7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_RMKMveo7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1OH8vj4b, HV_BINOP_MULTIPLY, 0, m, &cBinop_1OH8vj4b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vxRVtyRX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_WZSq2dxT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_WZSq2dxT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UwXzRcjW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_gOcnjETw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1sf8dAMy, HV_BINOP_MULTIPLY, 1, m, &cBinop_1sf8dAMy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_RjnCJkgX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_B9iz19UI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_B9iz19UI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_gOcnjETw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8mixVEX3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ogQRSMNb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ogQRSMNb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QCTJwJrK, HV_BINOP_MULTIPLY, 1, m, &cBinop_QCTJwJrK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fKfiPHjn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IMv9rAV6, HV_BINOP_MULTIPLY, 1, m, &cBinop_IMv9rAV6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_IsUnVujL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_EB9mc6JW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EB9mc6JW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_fKfiPHjn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QyQgCTJG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0xFSlKjP, 1, m, &cVar_0xFSlKjP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_aqh5ck1t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LFCX6kJU, HV_BINOP_MULTIPLY, 1, m, &cBinop_LFCX6kJU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WjuMZUrS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_LNwbvNYM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LNwbvNYM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dNMFUjHu, HV_BINOP_MULTIPLY, 1, m, &cBinop_dNMFUjHu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_0xFSlKjP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sSft7aWx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_Zb9knsvJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_X2ZIU2r4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_EsozX08s_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qsH5Zche_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_wGKaxe2F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_vxRVtyRX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mBUPFihP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_SlwIXdQ4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JeVK8S1P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_rowRvrND_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_SjPfXjqH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_gnLtuPT4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_csAIkZPR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_6sFcpR4Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_uk7JlJ5l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_7AJY4W4C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_UwXzRcjW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_DW5fJJL2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_DW5fJJL2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hEfTzeR8, HV_BINOP_MULTIPLY, 1, m, &cBinop_hEfTzeR8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hEfTzeR8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_3EtuHeHR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3EtuHeHR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_uk7JlJ5l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_sSft7aWx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Mk2iSNmX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Mk2iSNmX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CSJLBKX4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uaJsBid0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_v00LyEx6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JCSUcyA2_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9jXawWP7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ONF8p1WT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1sf8dAMy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QriXdPoo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_QCTJwJrK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_r1a4WTJY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_IMv9rAV6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bFgC6YVJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_LFCX6kJU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yL31troi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_dNMFUjHu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sUIlDXcd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_qElEUBEB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Zb9knsvJ, 0, m, &cVar_Zb9knsvJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XvT9ZHES_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wGKaxe2F, 1, m, &cVar_wGKaxe2F_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9jXawWP7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QCTJwJrK, HV_BINOP_MULTIPLY, 0, m, &cBinop_QCTJwJrK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CSJLBKX4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_ONF8p1WT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1sf8dAMy, HV_BINOP_MULTIPLY, 0, m, &cBinop_1sf8dAMy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uaJsBid0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dNMFUjHu, HV_BINOP_MULTIPLY, 0, m, &cBinop_dNMFUjHu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JCSUcyA2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IMv9rAV6, HV_BINOP_MULTIPLY, 0, m, &cBinop_IMv9rAV6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_v00LyEx6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LFCX6kJU, HV_BINOP_MULTIPLY, 0, m, &cBinop_LFCX6kJU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_X2ZIU2r4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wGKaxe2F, 0, m, &cVar_wGKaxe2F_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qsH5Zche_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0xFSlKjP, 0, m, &cVar_0xFSlKjP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bQjpwX6s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hNbJcHOs, 1, m, &cIf_hNbJcHOs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mqKOVwi9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_3FXzuSru_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_H3BdXBt6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mqKOVwi9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_1AJEPhNC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hNbJcHOs, 0, m, &cIf_hNbJcHOs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_G7T0txzm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6WlMSqI9, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_3FXzuSru_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QyaYwI9l, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_9pBdf16G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0O7FLgGr, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_PpPxmBU2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_1AJEPhNC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zx4HO9sx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_bQjpwX6s_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_H3BdXBt6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_kKwjc5WH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_U1td8e3z, HV_BINOP_DIVIDE, 0, m, &cBinop_U1td8e3z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_3jFB9ur3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0vfAtWXN, HV_BINOP_DIVIDE, 1, m, &cBinop_0vfAtWXN_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_U1td8e3z, HV_BINOP_DIVIDE, 1, m, &cBinop_U1td8e3z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_q9OQX3wa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AiyFooXu, HV_BINOP_DIVIDE, 0, m, &cBinop_AiyFooXu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_vLBIh7mI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AiyFooXu, HV_BINOP_DIVIDE, 1, m, &cBinop_AiyFooXu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_us5BwXRI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3jFB9ur3, 0, m, &cVar_3jFB9ur3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Pa3Tto5p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kKwjc5WH, 0, m, &cVar_kKwjc5WH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eP2TJVJp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0vfAtWXN, HV_BINOP_DIVIDE, 0, m, &cBinop_0vfAtWXN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0vfAtWXN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_q9OQX3wa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_U1td8e3z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_vLBIh7mI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_AiyFooXu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_gEnT2qss_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_X8Y1uYYr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_b8eIGYDu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_J4xATnA8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_LcU016ql_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gEnT2qss_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_J4xATnA8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LcU016ql_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_X8Y1uYYr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_b8eIGYDu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8HVBAXXD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_NjS3mhDX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_APub1j2r, 0, m, &cSlice_APub1j2r_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_APub1j2r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_tG7Zahwl_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_tG7Zahwl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Guyrg9pv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_tG7Zahwl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_tG7Zahwl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_RoY7vguA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_GUfDXyDj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_7KDmd1sO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7KDmd1sO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_s7jkHIjq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_s7jkHIjq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_c4WdxTEJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_c4WdxTEJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nMB0Nlds_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YvqOXFzj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nMB0Nlds_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_kvFtPjKn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YvqOXFzj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IDVs2YfZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_kvFtPjKn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_7kHzvbAk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_IDVs2YfZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_PJJvVn2e_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PJJvVn2e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_xMlfDYc3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7kHzvbAk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mEO6LSZ4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_xMlfDYc3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QrpB4d5B_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_mEO6LSZ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LeACA5HU, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_QrpB4d5B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mNqHcONZ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_dyWy1nMu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8ROPOvdv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_6biNPmA9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8INYcrew_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_5rgB0dIr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xzkd29kG_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_w6tHhyS3_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oLZMZwdx_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lY03KE3R_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Qhh4BFSW_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Jy9XNwEV_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_xzkd29kG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3jldtwtB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_w6tHhyS3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_quLOjSdc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_oLZMZwdx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tOKdRL7c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_lY03KE3R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_u6qvFFNF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_Qhh4BFSW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wtWujF0r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_Jy9XNwEV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_A6o6Oa3J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_u6uWRwKC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_4PiIrqDT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_m6FNgjh8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_llTTSts5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_SgQxfy4Q_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_w7wdH6cR_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_w7wdH6cR_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_wrgnocmm, 1, m, &cDelay_wrgnocmm_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RltaJnLX_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_wrgnocmm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wrgnocmm, m);
  cIf_onMessage(_c, &Context(_c)->cIf_u6uWRwKC, 0, m, &cIf_u6uWRwKC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_w7wdH6cR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_wrgnocmm, 0, m, &cDelay_wrgnocmm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RltaJnLX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_wrgnocmm, 0, m, &cDelay_wrgnocmm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Ob3l0nFe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xTGPRB6k_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_C6jOQnku_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_p6TDfLuY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oS9OfcAz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tLzIkPJo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tLzIkPJo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_SgQxfy4Q_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_oS9OfcAz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_u6uWRwKC, 1, m, &cIf_u6uWRwKC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_C6jOQnku_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_m6FNgjh8, 0, m, &cIf_m6FNgjh8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xTGPRB6k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_m6FNgjh8, 1, m, &cIf_m6FNgjh8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_llTTSts5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WXuza0tC, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_4PiIrqDT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WXuza0tC, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_UHmS9Sef_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_w0l1mgQ1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_gjWHdzJV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_cMNm2724_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_bEHo0LmK_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_PEJd0Hco_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_PEJd0Hco_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_sDC3PHWM, 1, m, &cDelay_sDC3PHWM_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Va8NaWVk_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_sDC3PHWM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_sDC3PHWM, m);
  cIf_onMessage(_c, &Context(_c)->cIf_UHmS9Sef, 0, m, &cIf_UHmS9Sef_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PEJd0Hco_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_sDC3PHWM, 0, m, &cDelay_sDC3PHWM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Va8NaWVk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_sDC3PHWM, 0, m, &cDelay_sDC3PHWM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_k31ftgrq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OxUneGGX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_F6CAi7Ek_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sxCAR2sf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gHtovwNw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jKY1M76t_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gHtovwNw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UHmS9Sef, 1, m, &cIf_UHmS9Sef_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jKY1M76t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_bEHo0LmK_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_OxUneGGX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gjWHdzJV, 1, m, &cIf_gjWHdzJV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_F6CAi7Ek_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gjWHdzJV, 0, m, &cIf_gjWHdzJV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cMNm2724_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CVghcKNl, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_w0l1mgQ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CVghcKNl, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Cod5RA1t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_UVvTnCHh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_dyNcG3DC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_GeTuzp7H_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_FzyGkaBy_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_uhurqdGJ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_uhurqdGJ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_2ohdcLgc, 1, m, &cDelay_2ohdcLgc_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zQuhDStj_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_2ohdcLgc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_2ohdcLgc, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Cod5RA1t, 0, m, &cIf_Cod5RA1t_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uhurqdGJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_2ohdcLgc, 0, m, &cDelay_2ohdcLgc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zQuhDStj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_2ohdcLgc, 0, m, &cDelay_2ohdcLgc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OTF0OrwF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uqOSZUHs_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5Z2F6wdg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JNP9AhcN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JffPkJYA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tgeJfaDl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tgeJfaDl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_FzyGkaBy_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_JffPkJYA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Cod5RA1t, 1, m, &cIf_Cod5RA1t_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5Z2F6wdg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dyNcG3DC, 0, m, &cIf_dyNcG3DC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uqOSZUHs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dyNcG3DC, 1, m, &cIf_dyNcG3DC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GeTuzp7H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VnXXFnXr, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_UVvTnCHh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VnXXFnXr, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_qMrS8954_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_HuCieyJm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_l0DxMTtz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_5Jk1ZZi1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_MWD5NwiC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_8dZP0vJG_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_8dZP0vJG_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_NEEYhMc9, 1, m, &cDelay_NEEYhMc9_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2daw5g2P_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_NEEYhMc9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_NEEYhMc9, m);
  cIf_onMessage(_c, &Context(_c)->cIf_qMrS8954, 0, m, &cIf_qMrS8954_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8dZP0vJG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_NEEYhMc9, 0, m, &cDelay_NEEYhMc9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2daw5g2P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_NEEYhMc9, 0, m, &cDelay_NEEYhMc9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3PMnC90h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BqevXdti_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_m6x5Z5Pg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QYh5PTkb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bUauF0rU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_w0454agJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_w0454agJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_MWD5NwiC_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_bUauF0rU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qMrS8954, 1, m, &cIf_qMrS8954_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BqevXdti_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_l0DxMTtz, 1, m, &cIf_l0DxMTtz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_m6x5Z5Pg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_l0DxMTtz, 0, m, &cIf_l0DxMTtz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5Jk1ZZi1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ktSmrdrI, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_HuCieyJm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ktSmrdrI, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_nrijqJwb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_a8tJzwVo_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_POmYch8h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_SLCrPUtC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_CQxl4WuS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_5LSgSFuU_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_5LSgSFuU_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_M9QtVVkN, 1, m, &cDelay_M9QtVVkN_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UG4eZqIy_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_M9QtVVkN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_M9QtVVkN, m);
  cIf_onMessage(_c, &Context(_c)->cIf_nrijqJwb, 0, m, &cIf_nrijqJwb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5LSgSFuU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_M9QtVVkN, 0, m, &cDelay_M9QtVVkN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UG4eZqIy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_M9QtVVkN, 0, m, &cDelay_M9QtVVkN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ElkCQsKV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MkJ4R7eD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rZPcklaK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ESN2sLmY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KbrfH3lB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1pLOP3aR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1pLOP3aR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_CQxl4WuS_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_KbrfH3lB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nrijqJwb, 1, m, &cIf_nrijqJwb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MkJ4R7eD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_POmYch8h, 1, m, &cIf_POmYch8h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rZPcklaK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_POmYch8h, 0, m, &cIf_POmYch8h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SLCrPUtC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bvlrJsRr, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_a8tJzwVo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bvlrJsRr, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_gmctIiKB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_qOM9WxrR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_6mqYph8h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_mM2yyqPd_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_jiNm20J3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ywbfqTu6_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ywbfqTu6_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_QNrLEQxH, 1, m, &cDelay_QNrLEQxH_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hQy4TNYQ_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_QNrLEQxH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_QNrLEQxH, m);
  cIf_onMessage(_c, &Context(_c)->cIf_gmctIiKB, 0, m, &cIf_gmctIiKB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ywbfqTu6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_QNrLEQxH, 0, m, &cDelay_QNrLEQxH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hQy4TNYQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_QNrLEQxH, 0, m, &cDelay_QNrLEQxH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HGenDxuE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_27wu4Lvm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MeJkNgNc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2ekS2odn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tZshgNJt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jczAxWrL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jczAxWrL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_jiNm20J3_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_tZshgNJt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gmctIiKB, 1, m, &cIf_gmctIiKB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MeJkNgNc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6mqYph8h, 0, m, &cIf_6mqYph8h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_27wu4Lvm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6mqYph8h, 1, m, &cIf_6mqYph8h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mM2yyqPd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wfdR3Vg4, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_qOM9WxrR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wfdR3Vg4, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_wj0Yt8eW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_xLSyTFyS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_oCMLkrrK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_OdjSto9T_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_tkDOm5gO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_XFUGGkDT_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_XFUGGkDT_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_FEnr2JPU, 1, m, &cDelay_FEnr2JPU_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2pcLveQR_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_FEnr2JPU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_FEnr2JPU, m);
  cIf_onMessage(_c, &Context(_c)->cIf_wj0Yt8eW, 0, m, &cIf_wj0Yt8eW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XFUGGkDT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_FEnr2JPU, 0, m, &cDelay_FEnr2JPU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2pcLveQR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_FEnr2JPU, 0, m, &cDelay_FEnr2JPU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ITVISmb5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NmgzNkMX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_r3TbCyNc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wHoiJtBp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WrrtPDpQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nGfz53B7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nGfz53B7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_tkDOm5gO_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_WrrtPDpQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wj0Yt8eW, 1, m, &cIf_wj0Yt8eW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NmgzNkMX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oCMLkrrK, 1, m, &cIf_oCMLkrrK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_r3TbCyNc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oCMLkrrK, 0, m, &cIf_oCMLkrrK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OdjSto9T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HDXkQlm1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_xLSyTFyS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HDXkQlm1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_faIyXzZO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_PD23XrnV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_q1DdfFmE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_KB5apMq9_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Z06DxRUF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Ezixxf14_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Ezixxf14_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_1IWWOSoF, 1, m, &cDelay_1IWWOSoF_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2j47WJnU_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_1IWWOSoF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_1IWWOSoF, m);
  cIf_onMessage(_c, &Context(_c)->cIf_faIyXzZO, 0, m, &cIf_faIyXzZO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Ezixxf14_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_1IWWOSoF, 0, m, &cDelay_1IWWOSoF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2j47WJnU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_1IWWOSoF, 0, m, &cDelay_1IWWOSoF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_IbNGdCFt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_F6oqGUzU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NgzQDUSO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mBPns1Ow_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_byDD9xrH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_STuBrtS5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_byDD9xrH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_faIyXzZO, 1, m, &cIf_faIyXzZO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_STuBrtS5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Z06DxRUF_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_NgzQDUSO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_q1DdfFmE, 0, m, &cIf_q1DdfFmE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_F6oqGUzU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_q1DdfFmE, 1, m, &cIf_q1DdfFmE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KB5apMq9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7gPIUr73, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_PD23XrnV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7gPIUr73, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_fZwZ39dG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Gk6ykFKW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_YzFq7Hpo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_H1VlUkX9_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_hIUZjU7R_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_CxEMuQRs_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_CxEMuQRs_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_hXSnrIZH, 1, m, &cDelay_hXSnrIZH_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3I33lSmd_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_hXSnrIZH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_hXSnrIZH, m);
  cIf_onMessage(_c, &Context(_c)->cIf_fZwZ39dG, 0, m, &cIf_fZwZ39dG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CxEMuQRs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_hXSnrIZH, 0, m, &cDelay_hXSnrIZH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3I33lSmd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_hXSnrIZH, 0, m, &cDelay_hXSnrIZH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5XpiJYkZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zVW7sHeW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lKUYW0Dy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_buRqqBR7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1HQOYZ7l_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_avB1rpae_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1HQOYZ7l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fZwZ39dG, 1, m, &cIf_fZwZ39dG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_avB1rpae_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_hIUZjU7R_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_lKUYW0Dy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YzFq7Hpo, 0, m, &cIf_YzFq7Hpo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zVW7sHeW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YzFq7Hpo, 1, m, &cIf_YzFq7Hpo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_H1VlUkX9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jduQ8tSo, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Gk6ykFKW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jduQ8tSo, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_VHn4yG94_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_521hnjBA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_H6dA0vAQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_KUReH4oc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_MaZfRvpB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_n4CkDHae_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_n4CkDHae_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_53myv8jy, 1, m, &cDelay_53myv8jy_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Qsqz6cPh_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_53myv8jy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_53myv8jy, m);
  cIf_onMessage(_c, &Context(_c)->cIf_VHn4yG94, 0, m, &cIf_VHn4yG94_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_n4CkDHae_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_53myv8jy, 0, m, &cDelay_53myv8jy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Qsqz6cPh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_53myv8jy, 0, m, &cDelay_53myv8jy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_YnTo4wvV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UBqfDnDu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_scMVXGV8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_eSNvp6Zp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fqQIN43w_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QYPpIrDC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QYPpIrDC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_MaZfRvpB_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_fqQIN43w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VHn4yG94, 1, m, &cIf_VHn4yG94_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_scMVXGV8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_H6dA0vAQ, 0, m, &cIf_H6dA0vAQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UBqfDnDu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_H6dA0vAQ, 1, m, &cIf_H6dA0vAQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KUReH4oc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eyT46bQz, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_521hnjBA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eyT46bQz, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_UPDRtnBT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_qe1WtymL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_uPYbni7X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_6GYPESHv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_FiECuRjQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_8D61JS9d_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_8D61JS9d_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_xfjBTlgJ, 1, m, &cDelay_xfjBTlgJ_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SDvFtxmg_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_xfjBTlgJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xfjBTlgJ, m);
  cIf_onMessage(_c, &Context(_c)->cIf_UPDRtnBT, 0, m, &cIf_UPDRtnBT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8D61JS9d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_xfjBTlgJ, 0, m, &cDelay_xfjBTlgJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SDvFtxmg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xfjBTlgJ, 0, m, &cDelay_xfjBTlgJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ncmHACbG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ae4yEHGG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SqdFDfGW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1viZqVGL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7WxXW70A_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CVnLmfLi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7WxXW70A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UPDRtnBT, 1, m, &cIf_UPDRtnBT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CVnLmfLi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_FiECuRjQ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ae4yEHGG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uPYbni7X, 1, m, &cIf_uPYbni7X_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SqdFDfGW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uPYbni7X, 0, m, &cIf_uPYbni7X_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6GYPESHv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HL8pyuNd, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_qe1WtymL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HL8pyuNd, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_tKvUZpbX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_hmqriDx7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_mne4RsAA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Yvg3fzSl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_rS3zeapw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_hC2ULCvh_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_hC2ULCvh_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_OfGfnKdt, 1, m, &cDelay_OfGfnKdt_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_afxYNLVa_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_OfGfnKdt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_OfGfnKdt, m);
  cIf_onMessage(_c, &Context(_c)->cIf_tKvUZpbX, 0, m, &cIf_tKvUZpbX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hC2ULCvh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_OfGfnKdt, 0, m, &cDelay_OfGfnKdt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_afxYNLVa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_OfGfnKdt, 0, m, &cDelay_OfGfnKdt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MI4gBsh7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xf6MJxln_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZnOKY2gE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2UpIwFos_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kNR4PArZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dlmwXhVR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dlmwXhVR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_rS3zeapw_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_kNR4PArZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tKvUZpbX, 1, m, &cIf_tKvUZpbX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xf6MJxln_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mne4RsAA, 1, m, &cIf_mne4RsAA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZnOKY2gE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mne4RsAA, 0, m, &cIf_mne4RsAA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Yvg3fzSl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_U4Bn7H0Q, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_hmqriDx7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_U4Bn7H0Q, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_3jldtwtB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_ailXwVna_sendMessage(_c, 0, m);
  cMsg_GTTGf7dT_sendMessage(_c, 0, m);
  cMsg_LdDhKhrR_sendMessage(_c, 0, m);
  cMsg_y5gUQFpj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_quLOjSdc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_ailXwVna_sendMessage(_c, 0, m);
  cMsg_9IQusbAi_sendMessage(_c, 0, m);
  cMsg_vH98rnz5_sendMessage(_c, 0, m);
  cMsg_CXSSFvk1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_tOKdRL7c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_lQ7akcIa_sendMessage(_c, 0, m);
  cMsg_9IQusbAi_sendMessage(_c, 0, m);
  cMsg_y5gUQFpj_sendMessage(_c, 0, m);
  cMsg_dAPRu442_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_u6qvFFNF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_lQ7akcIa_sendMessage(_c, 0, m);
  cMsg_3Smfklyn_sendMessage(_c, 0, m);
  cMsg_LdDhKhrR_sendMessage(_c, 0, m);
  cMsg_tzHPPtFM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_wtWujF0r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_FPmGnelw_sendMessage(_c, 0, m);
  cMsg_CXSSFvk1_sendMessage(_c, 0, m);
  cMsg_QqbwtIGQ_sendMessage(_c, 0, m);
  cMsg_LdDhKhrR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_A6o6Oa3J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_FPmGnelw_sendMessage(_c, 0, m);
  cMsg_tzHPPtFM_sendMessage(_c, 0, m);
  cMsg_9IQusbAi_sendMessage(_c, 0, m);
  cMsg_ENL4cXab_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_MgqPWE69_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_p6TDfLuY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Ob3l0nFe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kQe2Xsna_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_p6TDfLuY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Ob3l0nFe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ua2vdUWP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_sxCAR2sf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_k31ftgrq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zePXeSKT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_sxCAR2sf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_k31ftgrq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GVqHdbLH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_JNP9AhcN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_OTF0OrwF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GCJe9Dly_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_JNP9AhcN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_OTF0OrwF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ailXwVna_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_MgqPWE69_sendMessage(_c, 0, m);
  cMsg_zePXeSKT_sendMessage(_c, 0, m);
  cMsg_GCJe9Dly_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_lQ7akcIa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_kQe2Xsna_sendMessage(_c, 0, m);
  cMsg_ua2vdUWP_sendMessage(_c, 0, m);
  cMsg_GCJe9Dly_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_FPmGnelw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_kQe2Xsna_sendMessage(_c, 0, m);
  cMsg_zePXeSKT_sendMessage(_c, 0, m);
  cMsg_GVqHdbLH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_qY7l9bJd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_QYh5PTkb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_3PMnC90h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_g8x7MNrG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_QYh5PTkb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_3PMnC90h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VSdGVuZK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ESN2sLmY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ElkCQsKV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5ndGxu62_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ESN2sLmY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ElkCQsKV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_aEtUyu04_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2ekS2odn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_HGenDxuE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_neDxbsKb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2ekS2odn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_HGenDxuE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9IQusbAi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_g8x7MNrG_sendMessage(_c, 0, m);
  cMsg_5ndGxu62_sendMessage(_c, 0, m);
  cMsg_neDxbsKb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_GTTGf7dT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_g8x7MNrG_sendMessage(_c, 0, m);
  cMsg_VSdGVuZK_sendMessage(_c, 0, m);
  cMsg_aEtUyu04_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_3Smfklyn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_qY7l9bJd_sendMessage(_c, 0, m);
  cMsg_5ndGxu62_sendMessage(_c, 0, m);
  cMsg_aEtUyu04_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_KLyDZapk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_eSNvp6Zp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_YnTo4wvV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mM3gAOw3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_eSNvp6Zp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_YnTo4wvV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XcZPURyW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_1viZqVGL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ncmHACbG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8y8ZQVRE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_1viZqVGL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ncmHACbG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WywqiHUM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2UpIwFos_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_MI4gBsh7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4VJRNAac_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2UpIwFos_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_MI4gBsh7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_tzHPPtFM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_KLyDZapk_sendMessage(_c, 0, m);
  cMsg_8y8ZQVRE_sendMessage(_c, 0, m);
  cMsg_4VJRNAac_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_CXSSFvk1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_mM3gAOw3_sendMessage(_c, 0, m);
  cMsg_XcZPURyW_sendMessage(_c, 0, m);
  cMsg_4VJRNAac_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_y5gUQFpj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_mM3gAOw3_sendMessage(_c, 0, m);
  cMsg_8y8ZQVRE_sendMessage(_c, 0, m);
  cMsg_WywqiHUM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_9QIKMhQx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_wHoiJtBp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ITVISmb5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_vQjUys1j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_wHoiJtBp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ITVISmb5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0revFp3U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_mBPns1Ow_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_IbNGdCFt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6lDOvrvf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_mBPns1Ow_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_IbNGdCFt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DVT8WxqE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_buRqqBR7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_5XpiJYkZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MuxQK0d4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_buRqqBR7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_5XpiJYkZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LdDhKhrR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_vQjUys1j_sendMessage(_c, 0, m);
  cMsg_6lDOvrvf_sendMessage(_c, 0, m);
  cMsg_MuxQK0d4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_vH98rnz5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_vQjUys1j_sendMessage(_c, 0, m);
  cMsg_0revFp3U_sendMessage(_c, 0, m);
  cMsg_DVT8WxqE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ENL4cXab_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_9QIKMhQx_sendMessage(_c, 0, m);
  cMsg_0revFp3U_sendMessage(_c, 0, m);
  cMsg_MuxQK0d4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_QqbwtIGQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_qY7l9bJd_sendMessage(_c, 0, m);
  cMsg_VSdGVuZK_sendMessage(_c, 0, m);
  cMsg_neDxbsKb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_dAPRu442_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_9QIKMhQx_sendMessage(_c, 0, m);
  cMsg_6lDOvrvf_sendMessage(_c, 0, m);
  cMsg_DVT8WxqE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_dCQwsTkt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HXoev4IJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_THv8CD90_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_1Q5IYjeC, 0, m, &cSlice_1Q5IYjeC_sendMessage);
      break;
    }
    default: {
      cSwitchcase_hzy4HDmE_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_1Q5IYjeC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_XWq7Cm7T_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_XWq7Cm7T_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_AHwUWgMU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_XWq7Cm7T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_XWq7Cm7T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_PUNdC6Uf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_FzxVxfgI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_k9cjxd3G, 0, m, &cSlice_k9cjxd3G_sendMessage);
      break;
    }
    default: {
      cSwitchcase_AcCORmnf_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_k9cjxd3G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_QsK8Ic1h_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_QsK8Ic1h_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_i9EJm2mP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_QsK8Ic1h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_QsK8Ic1h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_7qdUOggm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_AcCORmnf_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_x6mM31z8, 0, m, &cSlice_x6mM31z8_sendMessage);
      break;
    }
    default: {
      cSwitchcase_THv8CD90_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_x6mM31z8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_mC1XgXpb_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_mC1XgXpb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_cLWTceW3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_mC1XgXpb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_mC1XgXpb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_4KqSILvi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_hzy4HDmE_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_OvjrPFHz, 0, m, &cSlice_OvjrPFHz_sendMessage);
      break;
    }
    default: {
      cSwitchcase_fGNTONi0_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_OvjrPFHz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Qymcl0Tx_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Qymcl0Tx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_3TDJBqy8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Qymcl0Tx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_Qymcl0Tx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_DsaQeoGc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_fGNTONi0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_nX0XRTpI, 0, m, &cSlice_nX0XRTpI_sendMessage);
      break;
    }
    default: {
      cSwitchcase_icsiCvvD_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_nX0XRTpI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_IX00BfF4_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_IX00BfF4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_BN7QuS2U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_IX00BfF4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_IX00BfF4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ZlS4WCJh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_MsQnlb8r_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_p7BHPHab_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_p7BHPHab_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_sO33tgWy, 1, m, &cDelay_sO33tgWy_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RPeem9Jw_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_sO33tgWy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_sO33tgWy, m);
  cMsg_NUnUrO4T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_p7BHPHab_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_sO33tgWy, 0, m, &cDelay_sO33tgWy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RPeem9Jw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_sO33tgWy, 0, m, &cDelay_sO33tgWy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_0RkJUlb1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7e93Fsdw, HV_BINOP_SUBTRACT, 0, m, &cBinop_7e93Fsdw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_tGjep0Qc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_zAY0VC3x_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_5tQuanjA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_zAY0VC3x_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_amdktgx2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0RkJUlb1, 0, m, &cVar_0RkJUlb1_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_uvsNytTE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KvfJFfmX_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Wzlp37sp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_erU4Qruf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7e93Fsdw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Mk4bsmdE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Mk4bsmdE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_GSZwgmeT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GSZwgmeT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_c7Kfncxf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gJdquK7H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jeh0VJX7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dT7GSMdh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dT7GSMdh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xYlscuWL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_jeh0VJX7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tGjep0Qc, 1, m, &cIf_tGjep0Qc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7RyotKV8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5tQuanjA, 1, m, &cIf_5tQuanjA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xYlscuWL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_tGjep0Qc, 0, m, &cIf_tGjep0Qc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_c7Kfncxf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5tQuanjA, 0, m, &cIf_5tQuanjA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_erU4Qruf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0RkJUlb1, 0, m, &cVar_0RkJUlb1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KvfJFfmX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_Wzlp37sp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7e93Fsdw, HV_BINOP_SUBTRACT, 1, m, &cBinop_7e93Fsdw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zAY0VC3x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rhrcSe5m, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_icsiCvvD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_JaD6ipX2, 0, m, &cSlice_JaD6ipX2_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_JaD6ipX2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_QpCaxkzf_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_QpCaxkzf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_ICVtV6kh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_QpCaxkzf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_QpCaxkzf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ib5oMwEu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_8ROPOvdv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xPrjmNv9, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_8INYcrew_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8LL4rMpR, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_xw3OMi1H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6biNPmA9, 0, m, &cVar_6biNPmA9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HXoev4IJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wxLaUmLU, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_EhL4YPh8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_MsQnlb8r_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_YeJI5FJE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3Wtnyl9h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_NUnUrO4T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_o6KUdQVW, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_3Wtnyl9h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_o6KUdQVW, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_8Pco7q6e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_qjcgEnng_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qjcgEnng_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ubr4GqK0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ubr4GqK0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1eiigbFo, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_fQwSNugO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EomzM1ea_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_uoKQMV4x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3br6GcVv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ee5RW5Rx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_43CBeS1h_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XfKTfL5I_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kvqLGNYU_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KzynuO2m_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SWS0HIXN_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QcBrqzip_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_43CBeS1h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EfH7SLDj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_XfKTfL5I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UjleumoH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_kvqLGNYU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ClUFlrV4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_KzynuO2m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZJF6Hl8f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_SWS0HIXN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_D5qqnCo2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_QcBrqzip_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XvbMe6RZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_5Qfw6Woy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_X9E6P97X_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_1g4FBURK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_pqwye6bX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_pOMcB1cA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_WN0yr8uD_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_WN0yr8uD_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_x7gbZr11, 1, m, &cDelay_x7gbZr11_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nnSPOrkO_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_x7gbZr11_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_x7gbZr11, m);
  cIf_onMessage(_c, &Context(_c)->cIf_5Qfw6Woy, 0, m, &cIf_5Qfw6Woy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WN0yr8uD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_x7gbZr11, 0, m, &cDelay_x7gbZr11_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nnSPOrkO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_x7gbZr11, 0, m, &cDelay_x7gbZr11_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7Xl9zCtu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qEBx3QkI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sdzJICXr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5EzrGEUU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RdcqVzMP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nChkiKHR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RdcqVzMP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5Qfw6Woy, 1, m, &cIf_5Qfw6Woy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nChkiKHR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_pOMcB1cA_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_sdzJICXr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1g4FBURK, 0, m, &cIf_1g4FBURK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qEBx3QkI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1g4FBURK, 1, m, &cIf_1g4FBURK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pqwye6bX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ERkRCuVM, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_X9E6P97X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ERkRCuVM, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_crmrXsZp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_OQafFAeK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_rMdxWSOp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_9aulbdIH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_7L7UOMCb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_gHaDUHEG_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_gHaDUHEG_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_NbGicS6g, 1, m, &cDelay_NbGicS6g_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_d94mWLVw_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_NbGicS6g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_NbGicS6g, m);
  cIf_onMessage(_c, &Context(_c)->cIf_crmrXsZp, 0, m, &cIf_crmrXsZp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gHaDUHEG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_NbGicS6g, 0, m, &cDelay_NbGicS6g_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_d94mWLVw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_NbGicS6g, 0, m, &cDelay_NbGicS6g_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_uVcQEoao_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_d5FJl309_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RfhFTvlC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Si9W9OwP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GECAokyh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LCuEfTTx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GECAokyh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_crmrXsZp, 1, m, &cIf_crmrXsZp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LCuEfTTx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_7L7UOMCb_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_RfhFTvlC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rMdxWSOp, 0, m, &cIf_rMdxWSOp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_d5FJl309_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rMdxWSOp, 1, m, &cIf_rMdxWSOp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9aulbdIH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_u3uNDQuc, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_OQafFAeK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_u3uNDQuc, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_0AGlclli_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ct7yC7JH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_0BsSrqTs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_07VTctjk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_yNvWo7GZ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Do8l0Z8v_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Do8l0Z8v_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_xrGwNKJR, 1, m, &cDelay_xrGwNKJR_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OK9Y27Eg_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_xrGwNKJR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xrGwNKJR, m);
  cIf_onMessage(_c, &Context(_c)->cIf_0AGlclli, 0, m, &cIf_0AGlclli_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Do8l0Z8v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_xrGwNKJR, 0, m, &cDelay_xrGwNKJR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OK9Y27Eg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xrGwNKJR, 0, m, &cDelay_xrGwNKJR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_f5FCwJdi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WMIqSimd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hTnzDPLj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OlV5OU00_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZOBAAT0J_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zLi9K8gl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZOBAAT0J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0AGlclli, 1, m, &cIf_0AGlclli_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zLi9K8gl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_yNvWo7GZ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_WMIqSimd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0BsSrqTs, 1, m, &cIf_0BsSrqTs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hTnzDPLj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0BsSrqTs, 0, m, &cIf_0BsSrqTs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_07VTctjk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZHXcpn88, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ct7yC7JH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZHXcpn88, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_tuUJ1Qfn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_LG4Ljg6l_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_YkiEEsiE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_rq7G87Pj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_xGQN4keL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ZHZ7M65S_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ZHZ7M65S_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_62725Ohe, 1, m, &cDelay_62725Ohe_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SK4Kai90_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_62725Ohe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_62725Ohe, m);
  cIf_onMessage(_c, &Context(_c)->cIf_tuUJ1Qfn, 0, m, &cIf_tuUJ1Qfn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZHZ7M65S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_62725Ohe, 0, m, &cDelay_62725Ohe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SK4Kai90_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_62725Ohe, 0, m, &cDelay_62725Ohe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HnrWYBZQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EOQqLb14_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GwPgAwqi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MLJsjIKG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_e2EEB6Sb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_h5H5tiS6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_h5H5tiS6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_xGQN4keL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_e2EEB6Sb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tuUJ1Qfn, 1, m, &cIf_tuUJ1Qfn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_EOQqLb14_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YkiEEsiE, 1, m, &cIf_YkiEEsiE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GwPgAwqi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YkiEEsiE, 0, m, &cIf_YkiEEsiE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rq7G87Pj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_b5GAwSZW, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_LG4Ljg6l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_b5GAwSZW, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Tf76S2t7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_iYGTPm7t_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_y6XwiCvj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Fvbfqnec_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_lbQ2P88K_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_uedhKXFy_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_uedhKXFy_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_y13yNyj5, 1, m, &cDelay_y13yNyj5_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JEE8IHp5_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_y13yNyj5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_y13yNyj5, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Tf76S2t7, 0, m, &cIf_Tf76S2t7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uedhKXFy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_y13yNyj5, 0, m, &cDelay_y13yNyj5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JEE8IHp5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_y13yNyj5, 0, m, &cDelay_y13yNyj5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6Nu5J9gZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7DQLuBH3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3eRZlYFx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_IwsprVbz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sQMxSQUx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aSiwOyF0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sQMxSQUx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Tf76S2t7, 1, m, &cIf_Tf76S2t7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aSiwOyF0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_lbQ2P88K_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_3eRZlYFx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_y6XwiCvj, 0, m, &cIf_y6XwiCvj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7DQLuBH3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_y6XwiCvj, 1, m, &cIf_y6XwiCvj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Fvbfqnec_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qypLIBho, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_iYGTPm7t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qypLIBho, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_auCLLwFR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Tvd35qzL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_XqEkOmul_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_XN957kVH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_oHmkvujh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_KcXqroMn_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_KcXqroMn_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_CNKBWhjh, 1, m, &cDelay_CNKBWhjh_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bMAFGf6I_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_CNKBWhjh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_CNKBWhjh, m);
  cIf_onMessage(_c, &Context(_c)->cIf_auCLLwFR, 0, m, &cIf_auCLLwFR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KcXqroMn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_CNKBWhjh, 0, m, &cDelay_CNKBWhjh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bMAFGf6I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_CNKBWhjh, 0, m, &cDelay_CNKBWhjh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_IGdTALg4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cdA4WbIE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OPToFYgY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NMoeK4LH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BY4A8mgq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5qLOrK1V_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5qLOrK1V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_oHmkvujh_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_BY4A8mgq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_auCLLwFR, 1, m, &cIf_auCLLwFR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cdA4WbIE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XqEkOmul, 1, m, &cIf_XqEkOmul_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OPToFYgY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XqEkOmul, 0, m, &cIf_XqEkOmul_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XN957kVH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lhpJiZEn, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Tvd35qzL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lhpJiZEn, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_6KPJiawV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_3AhIlTsK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_SPJ9SuWr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_et6gLMiv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Gkr0lLpX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_xbdLyOeS_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_xbdLyOeS_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_knBkuHhf, 1, m, &cDelay_knBkuHhf_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FIpL10Dk_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_knBkuHhf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_knBkuHhf, m);
  cIf_onMessage(_c, &Context(_c)->cIf_6KPJiawV, 0, m, &cIf_6KPJiawV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xbdLyOeS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_knBkuHhf, 0, m, &cDelay_knBkuHhf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FIpL10Dk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_knBkuHhf, 0, m, &cDelay_knBkuHhf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_C7zskFDH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MVnPRdFr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_L14kshi4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Qp0L7Q8I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IM26dUfE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VplpyfoR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_IM26dUfE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6KPJiawV, 1, m, &cIf_6KPJiawV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VplpyfoR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Gkr0lLpX_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_MVnPRdFr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SPJ9SuWr, 1, m, &cIf_SPJ9SuWr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_L14kshi4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SPJ9SuWr, 0, m, &cIf_SPJ9SuWr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_et6gLMiv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1tS8Hsl8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_3AhIlTsK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1tS8Hsl8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_PDqonvx2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_qFFApGzE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_4i56jT0C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_7BMloWW1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_EJHoqlyX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_iFAQahWp_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_iFAQahWp_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_et17YxIc, 1, m, &cDelay_et17YxIc_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aFWx6T4e_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_et17YxIc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_et17YxIc, m);
  cIf_onMessage(_c, &Context(_c)->cIf_PDqonvx2, 0, m, &cIf_PDqonvx2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_iFAQahWp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_et17YxIc, 0, m, &cDelay_et17YxIc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aFWx6T4e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_et17YxIc, 0, m, &cDelay_et17YxIc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rV40NBjf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_O63x1s6H_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pZOsww71_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Fm6uPgtz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hxpHIH64_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PU3Jd4G2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PU3Jd4G2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_EJHoqlyX_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_hxpHIH64_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PDqonvx2, 1, m, &cIf_PDqonvx2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pZOsww71_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4i56jT0C, 0, m, &cIf_4i56jT0C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_O63x1s6H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4i56jT0C, 1, m, &cIf_4i56jT0C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7BMloWW1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UAiVrkEi, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_qFFApGzE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UAiVrkEi, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_eGdx1dBG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_e5v73BSd_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Wto5V93X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_klZOqMA0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_9jxIYaeO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_L0iAJqAS_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_L0iAJqAS_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_uKYGz7Wu, 1, m, &cDelay_uKYGz7Wu_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UclO8OIT_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_uKYGz7Wu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_uKYGz7Wu, m);
  cIf_onMessage(_c, &Context(_c)->cIf_eGdx1dBG, 0, m, &cIf_eGdx1dBG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_L0iAJqAS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_uKYGz7Wu, 0, m, &cDelay_uKYGz7Wu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UclO8OIT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_uKYGz7Wu, 0, m, &cDelay_uKYGz7Wu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_IFqREoHh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2xrCqMHA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_T4cJAPiA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_x1n6Lyhk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7OjYX0So_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_K8KpGGrp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7OjYX0So_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eGdx1dBG, 1, m, &cIf_eGdx1dBG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_K8KpGGrp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_9jxIYaeO_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_2xrCqMHA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Wto5V93X, 1, m, &cIf_Wto5V93X_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_T4cJAPiA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Wto5V93X, 0, m, &cIf_Wto5V93X_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_klZOqMA0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9e1fxvuk, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_e5v73BSd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9e1fxvuk, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_SkO5LlSu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_4jPxADFa_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_7jM8u9Zd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Mw3GV1Kj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_9rWxVF8E_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_2CXyxXES_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_2CXyxXES_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_fpEaHDwp, 1, m, &cDelay_fpEaHDwp_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ny4IR6tV_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_fpEaHDwp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_fpEaHDwp, m);
  cIf_onMessage(_c, &Context(_c)->cIf_SkO5LlSu, 0, m, &cIf_SkO5LlSu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2CXyxXES_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_fpEaHDwp, 0, m, &cDelay_fpEaHDwp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ny4IR6tV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_fpEaHDwp, 0, m, &cDelay_fpEaHDwp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_cFBQwd8c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uBCRBfN7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sXPKkqrJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bp5uN5ro_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VkEc1g49_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jGuYA68n_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VkEc1g49_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SkO5LlSu, 1, m, &cIf_SkO5LlSu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jGuYA68n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_9rWxVF8E_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_uBCRBfN7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7jM8u9Zd, 1, m, &cIf_7jM8u9Zd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sXPKkqrJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7jM8u9Zd, 0, m, &cIf_7jM8u9Zd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Mw3GV1Kj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_c5ICqQdL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_4jPxADFa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_c5ICqQdL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_1DLelIbE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_GNrQSwi8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_lVauBXJB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_FzcQdSXj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_zpV5dDUQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_k2F4HMEG_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_k2F4HMEG_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_sHZjJG7u, 1, m, &cDelay_sHZjJG7u_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4IBt3h0M_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_sHZjJG7u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_sHZjJG7u, m);
  cIf_onMessage(_c, &Context(_c)->cIf_1DLelIbE, 0, m, &cIf_1DLelIbE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_k2F4HMEG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_sHZjJG7u, 0, m, &cDelay_sHZjJG7u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4IBt3h0M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_sHZjJG7u, 0, m, &cDelay_sHZjJG7u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_l7DvGDOX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Eiv1NKiB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8B69EAMP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yimQuYAW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1huPA548_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xXShXU3s_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1huPA548_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1DLelIbE, 1, m, &cIf_1DLelIbE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xXShXU3s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_zpV5dDUQ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Eiv1NKiB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lVauBXJB, 1, m, &cIf_lVauBXJB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8B69EAMP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lVauBXJB, 0, m, &cIf_lVauBXJB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_FzcQdSXj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cdk1A4sU, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_GNrQSwi8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cdk1A4sU, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_aapIS6oJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_givww9qP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_bu6oDlXV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_xywbBSlI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_IErcTBJr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Vxvarf0S_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Vxvarf0S_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_YPSYQtvz, 1, m, &cDelay_YPSYQtvz_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_D5c015Gh_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_YPSYQtvz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_YPSYQtvz, m);
  cIf_onMessage(_c, &Context(_c)->cIf_aapIS6oJ, 0, m, &cIf_aapIS6oJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Vxvarf0S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_YPSYQtvz, 0, m, &cDelay_YPSYQtvz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_D5c015Gh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_YPSYQtvz, 0, m, &cDelay_YPSYQtvz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XDpEwWZT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2ZFeQsvC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_igRYK6Sw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_n6EtQt11_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sXpVMYFV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZU505PYl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZU505PYl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_IErcTBJr_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_sXpVMYFV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aapIS6oJ, 1, m, &cIf_aapIS6oJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2ZFeQsvC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bu6oDlXV, 1, m, &cIf_bu6oDlXV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_igRYK6Sw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bu6oDlXV, 0, m, &cIf_bu6oDlXV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xywbBSlI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4qyWwiDQ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_givww9qP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4qyWwiDQ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_EfH7SLDj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_KlBrAHk0_sendMessage(_c, 0, m);
  cMsg_QZGmyNML_sendMessage(_c, 0, m);
  cMsg_19GIQhsr_sendMessage(_c, 0, m);
  cMsg_6gcspTsj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_UjleumoH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_KlBrAHk0_sendMessage(_c, 0, m);
  cMsg_ZX0zVU5s_sendMessage(_c, 0, m);
  cMsg_YoTZyLou_sendMessage(_c, 0, m);
  cMsg_pBy9V0pf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ClUFlrV4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_SDEz2Szd_sendMessage(_c, 0, m);
  cMsg_ZX0zVU5s_sendMessage(_c, 0, m);
  cMsg_6gcspTsj_sendMessage(_c, 0, m);
  cMsg_ghdxg6yd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ZJF6Hl8f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_SDEz2Szd_sendMessage(_c, 0, m);
  cMsg_yjpJpqax_sendMessage(_c, 0, m);
  cMsg_19GIQhsr_sendMessage(_c, 0, m);
  cMsg_WpQ0Y3Kk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_D5qqnCo2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_KqW30LCq_sendMessage(_c, 0, m);
  cMsg_pBy9V0pf_sendMessage(_c, 0, m);
  cMsg_q6zvd1KP_sendMessage(_c, 0, m);
  cMsg_19GIQhsr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_XvbMe6RZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_KqW30LCq_sendMessage(_c, 0, m);
  cMsg_WpQ0Y3Kk_sendMessage(_c, 0, m);
  cMsg_ZX0zVU5s_sendMessage(_c, 0, m);
  cMsg_sPnK73W4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Ce0sSdu7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_5EzrGEUU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7Xl9zCtu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uZ45gxHx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_5EzrGEUU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7Xl9zCtu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BOmguP3H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Si9W9OwP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_uVcQEoao_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mC1nab2d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Si9W9OwP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_uVcQEoao_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hNCLNHlS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_OlV5OU00_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_f5FCwJdi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_sAdcNP5J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_OlV5OU00_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_f5FCwJdi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KlBrAHk0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_Ce0sSdu7_sendMessage(_c, 0, m);
  cMsg_mC1nab2d_sendMessage(_c, 0, m);
  cMsg_sAdcNP5J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_SDEz2Szd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_uZ45gxHx_sendMessage(_c, 0, m);
  cMsg_BOmguP3H_sendMessage(_c, 0, m);
  cMsg_sAdcNP5J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_KqW30LCq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_uZ45gxHx_sendMessage(_c, 0, m);
  cMsg_mC1nab2d_sendMessage(_c, 0, m);
  cMsg_hNCLNHlS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_TaZ4MXwS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_MLJsjIKG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_HnrWYBZQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mkyUgVwX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_MLJsjIKG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_HnrWYBZQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gejmh49s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_IwsprVbz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_6Nu5J9gZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_v8pdHdI4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_IwsprVbz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_6Nu5J9gZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_foHF4rb8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_NMoeK4LH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_IGdTALg4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ATjWPsSn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_NMoeK4LH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_IGdTALg4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZX0zVU5s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_mkyUgVwX_sendMessage(_c, 0, m);
  cMsg_v8pdHdI4_sendMessage(_c, 0, m);
  cMsg_ATjWPsSn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_QZGmyNML_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_mkyUgVwX_sendMessage(_c, 0, m);
  cMsg_gejmh49s_sendMessage(_c, 0, m);
  cMsg_foHF4rb8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_yjpJpqax_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_TaZ4MXwS_sendMessage(_c, 0, m);
  cMsg_v8pdHdI4_sendMessage(_c, 0, m);
  cMsg_foHF4rb8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_svr3G7S1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_bp5uN5ro_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_cFBQwd8c_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NJwLZTT3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_bp5uN5ro_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_cFBQwd8c_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pqmAzUPR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_yimQuYAW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_l7DvGDOX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pK1VmYd4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_yimQuYAW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_l7DvGDOX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YfkmTAHf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_n6EtQt11_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_XDpEwWZT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WgFHOsyt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_n6EtQt11_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_XDpEwWZT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WpQ0Y3Kk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_svr3G7S1_sendMessage(_c, 0, m);
  cMsg_pK1VmYd4_sendMessage(_c, 0, m);
  cMsg_WgFHOsyt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_pBy9V0pf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_NJwLZTT3_sendMessage(_c, 0, m);
  cMsg_pqmAzUPR_sendMessage(_c, 0, m);
  cMsg_WgFHOsyt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_6gcspTsj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_NJwLZTT3_sendMessage(_c, 0, m);
  cMsg_pK1VmYd4_sendMessage(_c, 0, m);
  cMsg_YfkmTAHf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_BGpoviQH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Qp0L7Q8I_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_C7zskFDH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KeFwv3Jj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Qp0L7Q8I_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_C7zskFDH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_r2A0lPAf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Fm6uPgtz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_rV40NBjf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mlPnu66V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Fm6uPgtz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_rV40NBjf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LI0mvw9E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_x1n6Lyhk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_IFqREoHh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_f0sSfmai_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_x1n6Lyhk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_IFqREoHh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_19GIQhsr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_KeFwv3Jj_sendMessage(_c, 0, m);
  cMsg_mlPnu66V_sendMessage(_c, 0, m);
  cMsg_f0sSfmai_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_YoTZyLou_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_KeFwv3Jj_sendMessage(_c, 0, m);
  cMsg_r2A0lPAf_sendMessage(_c, 0, m);
  cMsg_LI0mvw9E_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_sPnK73W4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_BGpoviQH_sendMessage(_c, 0, m);
  cMsg_r2A0lPAf_sendMessage(_c, 0, m);
  cMsg_f0sSfmai_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_q6zvd1KP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_TaZ4MXwS_sendMessage(_c, 0, m);
  cMsg_gejmh49s_sendMessage(_c, 0, m);
  cMsg_ATjWPsSn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ghdxg6yd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_BGpoviQH_sendMessage(_c, 0, m);
  cMsg_mlPnu66V_sendMessage(_c, 0, m);
  cMsg_LI0mvw9E_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_pffCTxAk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_azRdBJGp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_IY9kAlHx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_SGj21zYu, 0, m, &cSlice_SGj21zYu_sendMessage);
      break;
    }
    default: {
      cSwitchcase_KuZ99ty4_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_SGj21zYu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_W5vX3Hj7_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_W5vX3Hj7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_65a1NuXo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_W5vX3Hj7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_W5vX3Hj7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ij3cSz4B_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_363w0UvM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_gSmONRbX, 0, m, &cSlice_gSmONRbX_sendMessage);
      break;
    }
    default: {
      cSwitchcase_6nSAaOyf_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_gSmONRbX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_P10zQdqw_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_P10zQdqw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_CkEzV85r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_P10zQdqw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_P10zQdqw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_RfK2KCgj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_6nSAaOyf_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_eDdCcLZn, 0, m, &cSlice_eDdCcLZn_sendMessage);
      break;
    }
    default: {
      cSwitchcase_IY9kAlHx_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_eDdCcLZn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_BMYA8SxA_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_BMYA8SxA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_4NR9La5c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_BMYA8SxA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_BMYA8SxA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_fudxfYZI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_KuZ99ty4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_sHENvmDp, 0, m, &cSlice_sHENvmDp_sendMessage);
      break;
    }
    default: {
      cSwitchcase_AxRoYsiH_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_sHENvmDp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_aKGZeGxV_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_aKGZeGxV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_RFyIMaCL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_aKGZeGxV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_aKGZeGxV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_6kiHIAtu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_AxRoYsiH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Z9RRL9Kw, 0, m, &cSlice_Z9RRL9Kw_sendMessage);
      break;
    }
    default: {
      cSwitchcase_HzyJqvqh_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_Z9RRL9Kw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_jbhovo1u_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_jbhovo1u_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_8njYz1CI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_jbhovo1u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_jbhovo1u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_US12jSWc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_zb7EVS7b_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_e5qeipPj_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_e5qeipPj_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_p0evDe1O, 1, m, &cDelay_p0evDe1O_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FVASisJm_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_p0evDe1O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_p0evDe1O, m);
  cMsg_XBHQY5qE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_e5qeipPj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_p0evDe1O, 0, m, &cDelay_p0evDe1O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FVASisJm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_p0evDe1O, 0, m, &cDelay_p0evDe1O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_RfW5Y5EO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vbXOSYRH, HV_BINOP_SUBTRACT, 0, m, &cBinop_vbXOSYRH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_olSPltjc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_85dkHmxT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_CW7AwfVT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_85dkHmxT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_YDtP158m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RfW5Y5EO, 0, m, &cVar_RfW5Y5EO_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_oG6Qdp2Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6HmBZDVY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4yUFUkiw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7PqdFFqO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vbXOSYRH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VCdo3JjD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_VCdo3JjD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_LFVsV5bi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LFVsV5bi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_ValTZYPO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7qr7ORWg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZWQmnuri_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gK2QcyYp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gK2QcyYp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_feuf28eE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_ZWQmnuri_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_olSPltjc, 1, m, &cIf_olSPltjc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qtR90Amm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CW7AwfVT, 1, m, &cIf_CW7AwfVT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_feuf28eE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_olSPltjc, 0, m, &cIf_olSPltjc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ValTZYPO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CW7AwfVT, 0, m, &cIf_CW7AwfVT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4yUFUkiw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vbXOSYRH, HV_BINOP_SUBTRACT, 1, m, &cBinop_vbXOSYRH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6HmBZDVY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_7PqdFFqO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RfW5Y5EO, 0, m, &cVar_RfW5Y5EO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_85dkHmxT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rt3ISCkG, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_HzyJqvqh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ffPq6yJf, 0, m, &cSlice_ffPq6yJf_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_ffPq6yJf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_HWF0ldHT_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_HWF0ldHT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_0xBlM5zL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_HWF0ldHT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_HWF0ldHT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_oKGQeHE7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_EomzM1ea_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rjIKolWT, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_3br6GcVv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_M3RnsdTT, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_T6NG8tjR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uoKQMV4x, 0, m, &cVar_uoKQMV4x_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_azRdBJGp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RobXwJdN, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_nfNSYGLn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_zb7EVS7b_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_TuytQeKe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HZdyLvOo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_XBHQY5qE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lnuvZCQq, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_HZdyLvOo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lnuvZCQq, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_hVY88Nws_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_FTX3x71E_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_FTX3x71E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_a1xrBDj5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_a1xrBDj5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8NW95XIy, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_FlhZNHv1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5w9PKCsH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_F0wdYKvN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3ANxTvYQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_fWpGrJQV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WezEXe2P_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_3wF0Pmdv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6ZgrNtE0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_VzKBosDs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HRCxULDU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_FPrOgSj7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_4zFxSLvp_sendMessage);
  cMsg_xHMqwC7p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_4zFxSLvp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FPrOgSj7, 1, m, &cVar_FPrOgSj7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_I51ecPJv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_u9pbQUj3_sendMessage(_c, 0, m);
  cMsg_lIs1nYny_sendMessage(_c, 0, m);
  cMsg_yAEZ5NAK_sendMessage(_c, 0, m);
  cMsg_915RPNk9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_1gvcfkul_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Jimm3cYP, 0, m, &cSlice_Jimm3cYP_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_Jimm3cYP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_iPYwsagP_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_iPYwsagP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_MUEpMTPQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_iPYwsagP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_iPYwsagP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_eWAGIg2L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_2M7OTfXE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_HfoKNxh7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HfoKNxh7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_EmNgg7DQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EmNgg7DQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_BXmbvm7t_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_BXmbvm7t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_P0xb3F0y_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VY037Uky_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_P0xb3F0y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_lX9pUClb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VY037Uky_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PTQ2EeOj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_lX9pUClb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_T81XOoal_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PTQ2EeOj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_2dneNtku_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2dneNtku_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_OlOBus5L_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_T81XOoal_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_e8rtgjhE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_OlOBus5L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_j5yP9wa4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_e8rtgjhE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_b18mzmUe, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_j5yP9wa4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_E0V5JFk1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_1Wj7EdcT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SKa8FE7i_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_ayDIsEJV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YuZZ5zLj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_90RDzwKp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CgEKk8lc_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_v39MIlIz_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_89bY08FO_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mTnfJhKD_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ayiBU2XH_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4nxWCR58_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_CgEKk8lc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EewbAlAV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_v39MIlIz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ypWzMkH9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_89bY08FO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_muFibMfH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_mTnfJhKD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aeRd1hnR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_ayiBU2XH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iyxI9Jfy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_4nxWCR58_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_n0TAKO7c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_5EP1CrzT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ueMFo1Uy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_G8xOSVE4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_I0obz3qD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_UQhK5jTr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_VIPJIXat_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_VIPJIXat_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_yiDTzD2V, 1, m, &cDelay_yiDTzD2V_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_A2X1dPSP_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_yiDTzD2V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_yiDTzD2V, m);
  cIf_onMessage(_c, &Context(_c)->cIf_5EP1CrzT, 0, m, &cIf_5EP1CrzT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VIPJIXat_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_yiDTzD2V, 0, m, &cDelay_yiDTzD2V_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_A2X1dPSP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_yiDTzD2V, 0, m, &cDelay_yiDTzD2V_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_cnSGVGRH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yTDEDoea_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PcJRm3uo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PzX3T6JY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SNxOljeW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_POdksfpM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_POdksfpM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_UQhK5jTr_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_SNxOljeW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5EP1CrzT, 1, m, &cIf_5EP1CrzT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PcJRm3uo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_G8xOSVE4, 0, m, &cIf_G8xOSVE4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yTDEDoea_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_G8xOSVE4, 1, m, &cIf_G8xOSVE4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_I0obz3qD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BzWpBC0W, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ueMFo1Uy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BzWpBC0W, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_oC0fnHca_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_dcyqTX19_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_JzFmPZbb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_6wBkrSgg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Peg8uWNT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_9uh8842m_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_9uh8842m_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_YY2CBMq5, 1, m, &cDelay_YY2CBMq5_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8BZfvXtc_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_YY2CBMq5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_YY2CBMq5, m);
  cIf_onMessage(_c, &Context(_c)->cIf_oC0fnHca, 0, m, &cIf_oC0fnHca_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9uh8842m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_YY2CBMq5, 0, m, &cDelay_YY2CBMq5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8BZfvXtc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_YY2CBMq5, 0, m, &cDelay_YY2CBMq5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_AzG4vbyj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZSkvfjKZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bL48wRA1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_lwjKJyI0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UMhBsDTo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Oqrapm4a_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Oqrapm4a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Peg8uWNT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_UMhBsDTo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oC0fnHca, 1, m, &cIf_oC0fnHca_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZSkvfjKZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JzFmPZbb, 1, m, &cIf_JzFmPZbb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bL48wRA1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JzFmPZbb, 0, m, &cIf_JzFmPZbb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6wBkrSgg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NvDWlxMv, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_dcyqTX19_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NvDWlxMv, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_GIPnlPE8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_YzZGNd4I_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_fcJjJuwd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_1Guvnrl6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_41oKYXD1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_1foUPHI4_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_1foUPHI4_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_NmlQmLGc, 1, m, &cDelay_NmlQmLGc_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_agy2lBvG_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_NmlQmLGc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_NmlQmLGc, m);
  cIf_onMessage(_c, &Context(_c)->cIf_GIPnlPE8, 0, m, &cIf_GIPnlPE8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_1foUPHI4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_NmlQmLGc, 0, m, &cDelay_NmlQmLGc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_agy2lBvG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_NmlQmLGc, 0, m, &cDelay_NmlQmLGc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zr03zMjH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tMpcDHkk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_D7x9J99A_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MWuuRkzy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xsry23XD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Q2QX8qnL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xsry23XD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GIPnlPE8, 1, m, &cIf_GIPnlPE8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Q2QX8qnL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_41oKYXD1_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_tMpcDHkk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fcJjJuwd, 1, m, &cIf_fcJjJuwd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_D7x9J99A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fcJjJuwd, 0, m, &cIf_fcJjJuwd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_1Guvnrl6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_73Y8FIew, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_YzZGNd4I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_73Y8FIew, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_KYWOZfba_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_qcqW0Am5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_i8uhUsQD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_fW2JBb6j_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_KHrK78CN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_k2OIAi2S_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_k2OIAi2S_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_vVJWZksE, 1, m, &cDelay_vVJWZksE_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IOyzWKsK_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_vVJWZksE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_vVJWZksE, m);
  cIf_onMessage(_c, &Context(_c)->cIf_KYWOZfba, 0, m, &cIf_KYWOZfba_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_k2OIAi2S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_vVJWZksE, 0, m, &cDelay_vVJWZksE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_IOyzWKsK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_vVJWZksE, 0, m, &cDelay_vVJWZksE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kMwRQdrH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_unXsg32e_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8LtAE5dH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_P3hL5ypI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jL2jtM5E_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QdVSGo3X_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jL2jtM5E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KYWOZfba, 1, m, &cIf_KYWOZfba_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QdVSGo3X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_KHrK78CN_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_unXsg32e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_i8uhUsQD, 1, m, &cIf_i8uhUsQD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8LtAE5dH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_i8uhUsQD, 0, m, &cIf_i8uhUsQD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fW2JBb6j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_H5UbUhca, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_qcqW0Am5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_H5UbUhca, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_pjAyjp2f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_kgoCVuMx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_WzEeb3CZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_IV1YuH0h_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_zfuBFvpS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_M88CPuqk_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_M88CPuqk_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_7ApLfyjd, 1, m, &cDelay_7ApLfyjd_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7YwaYhRl_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_7ApLfyjd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_7ApLfyjd, m);
  cIf_onMessage(_c, &Context(_c)->cIf_pjAyjp2f, 0, m, &cIf_pjAyjp2f_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_M88CPuqk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_7ApLfyjd, 0, m, &cDelay_7ApLfyjd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7YwaYhRl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_7ApLfyjd, 0, m, &cDelay_7ApLfyjd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ORyBG921_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OwhBzF3I_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WGa9DNsX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_X3GMtdUH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pP2wRwpo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pBrBbdRu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pBrBbdRu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_zfuBFvpS_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_pP2wRwpo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pjAyjp2f, 1, m, &cIf_pjAyjp2f_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WGa9DNsX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WzEeb3CZ, 0, m, &cIf_WzEeb3CZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OwhBzF3I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WzEeb3CZ, 1, m, &cIf_WzEeb3CZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_IV1YuH0h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_sO3YwkWJ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_kgoCVuMx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_sO3YwkWJ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_fmIDFpq4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Dsl7uip4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_IZqO09o3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_3VEdTxF7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_BJTPznoH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_JCPgwBZF_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_JCPgwBZF_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_VFQpfeXi, 1, m, &cDelay_VFQpfeXi_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FywXt7qR_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_VFQpfeXi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_VFQpfeXi, m);
  cIf_onMessage(_c, &Context(_c)->cIf_fmIDFpq4, 0, m, &cIf_fmIDFpq4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JCPgwBZF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_VFQpfeXi, 0, m, &cDelay_VFQpfeXi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FywXt7qR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_VFQpfeXi, 0, m, &cDelay_VFQpfeXi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_oYQsD0Yp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1JNqFFlI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_20sTGzxe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XdWuWbvE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1Slqmnsz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RSPbMAL4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RSPbMAL4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_BJTPznoH_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_1Slqmnsz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fmIDFpq4, 1, m, &cIf_fmIDFpq4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1JNqFFlI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IZqO09o3, 1, m, &cIf_IZqO09o3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_20sTGzxe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IZqO09o3, 0, m, &cIf_IZqO09o3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3VEdTxF7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_A2KmQ5Ep, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Dsl7uip4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_A2KmQ5Ep, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_3iEv0HAs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_vLHHXQyx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_GcmfV9kC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_QSYPyaTZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_JxKAEyXA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_1ZzhCwQp_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_1ZzhCwQp_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Qt91ZizM, 1, m, &cDelay_Qt91ZizM_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_czw3BkFa_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Qt91ZizM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Qt91ZizM, m);
  cIf_onMessage(_c, &Context(_c)->cIf_3iEv0HAs, 0, m, &cIf_3iEv0HAs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_1ZzhCwQp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Qt91ZizM, 0, m, &cDelay_Qt91ZizM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_czw3BkFa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Qt91ZizM, 0, m, &cDelay_Qt91ZizM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_H9GsQCSS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BXwtcjPx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CaQPJEDZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_C2GTJXcq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FYzWNDr5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8di4vYIt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FYzWNDr5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3iEv0HAs, 1, m, &cIf_3iEv0HAs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8di4vYIt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_JxKAEyXA_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_BXwtcjPx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GcmfV9kC, 1, m, &cIf_GcmfV9kC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CaQPJEDZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GcmfV9kC, 0, m, &cIf_GcmfV9kC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QSYPyaTZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cnpt15z6, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_vLHHXQyx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cnpt15z6, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_jOXpOkD3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ZFedhh7t_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_hIntLnWl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_OtAv0Q85_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_aP9kf4T1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_LIcimHE4_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_LIcimHE4_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_7FkR9LyA, 1, m, &cDelay_7FkR9LyA_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7kITNoG0_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_7FkR9LyA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_7FkR9LyA, m);
  cIf_onMessage(_c, &Context(_c)->cIf_jOXpOkD3, 0, m, &cIf_jOXpOkD3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LIcimHE4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_7FkR9LyA, 0, m, &cDelay_7FkR9LyA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7kITNoG0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_7FkR9LyA, 0, m, &cDelay_7FkR9LyA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_dvewl0k4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1CV8iBPp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Y7EHo60A_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EbzoabP3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7QdczFVb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_h7FQF4hX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_h7FQF4hX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_aP9kf4T1_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_7QdczFVb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jOXpOkD3, 1, m, &cIf_jOXpOkD3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Y7EHo60A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hIntLnWl, 0, m, &cIf_hIntLnWl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1CV8iBPp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hIntLnWl, 1, m, &cIf_hIntLnWl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OtAv0Q85_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ApMk57IA, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ZFedhh7t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ApMk57IA, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_TKovYxTf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_vycdwky7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_kNuIQ7BN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_zjCqKalH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_3KyuFO6T_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_7YuRlhvS_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_7YuRlhvS_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_UWEK8pzW, 1, m, &cDelay_UWEK8pzW_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6zCVpsnW_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_UWEK8pzW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_UWEK8pzW, m);
  cIf_onMessage(_c, &Context(_c)->cIf_TKovYxTf, 0, m, &cIf_TKovYxTf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7YuRlhvS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_UWEK8pzW, 0, m, &cDelay_UWEK8pzW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6zCVpsnW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_UWEK8pzW, 0, m, &cDelay_UWEK8pzW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5Q7SuGD9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_l5K55uRz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uQXnS1jK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8lvHe2fN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_roy9X2XR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Z8wEVPuC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Z8wEVPuC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_3KyuFO6T_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_roy9X2XR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TKovYxTf, 1, m, &cIf_TKovYxTf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uQXnS1jK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kNuIQ7BN, 0, m, &cIf_kNuIQ7BN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_l5K55uRz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kNuIQ7BN, 1, m, &cIf_kNuIQ7BN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zjCqKalH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Hl5iayna, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_vycdwky7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Hl5iayna, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_BEMqDXwr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_G2YF6JUD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_xzOTHW0q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Vmj9CMqy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_euBp9UG7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_6YW0UmcZ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_6YW0UmcZ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ZdxCQN7x, 1, m, &cDelay_ZdxCQN7x_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7W2O4c5a_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_ZdxCQN7x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ZdxCQN7x, m);
  cIf_onMessage(_c, &Context(_c)->cIf_BEMqDXwr, 0, m, &cIf_BEMqDXwr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6YW0UmcZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZdxCQN7x, 0, m, &cDelay_ZdxCQN7x_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7W2O4c5a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZdxCQN7x, 0, m, &cDelay_ZdxCQN7x_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_BcN4wcXY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wYttokzV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FKgDj3E5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tNjAk4lj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Nu9JHqS3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wTxMfFNW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wTxMfFNW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_euBp9UG7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Nu9JHqS3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BEMqDXwr, 1, m, &cIf_BEMqDXwr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wYttokzV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xzOTHW0q, 1, m, &cIf_xzOTHW0q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FKgDj3E5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xzOTHW0q, 0, m, &cIf_xzOTHW0q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Vmj9CMqy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1XCzkdz0, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_G2YF6JUD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1XCzkdz0, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_CSVET7S0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ihxj1MP6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_5yAfLWTf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_l2Cwjinb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_NPJcdA2i_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_eNfbI8aF_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_eNfbI8aF_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_tBiSGde2, 1, m, &cDelay_tBiSGde2_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PpVoUjhk_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_tBiSGde2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_tBiSGde2, m);
  cIf_onMessage(_c, &Context(_c)->cIf_CSVET7S0, 0, m, &cIf_CSVET7S0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_eNfbI8aF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_tBiSGde2, 0, m, &cDelay_tBiSGde2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PpVoUjhk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_tBiSGde2, 0, m, &cDelay_tBiSGde2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HqWJIHif_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wNFIe8NE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AS48VMXW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zDWZegVD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_f8Q8Iipl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZPxAOggX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_f8Q8Iipl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CSVET7S0, 1, m, &cIf_CSVET7S0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZPxAOggX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_NPJcdA2i_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_AS48VMXW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5yAfLWTf, 0, m, &cIf_5yAfLWTf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wNFIe8NE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5yAfLWTf, 1, m, &cIf_5yAfLWTf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_l2Cwjinb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_20oX5RVM, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ihxj1MP6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_20oX5RVM, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_BLqVeYnv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_40PL6Uey_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Iu8HWRkb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_4kriCN2J_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ftgKVPgt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_BXPzyUcM_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_BXPzyUcM_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_yXVPAevL, 1, m, &cDelay_yXVPAevL_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Bn6ZSOq2_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_yXVPAevL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_yXVPAevL, m);
  cIf_onMessage(_c, &Context(_c)->cIf_BLqVeYnv, 0, m, &cIf_BLqVeYnv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BXPzyUcM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_yXVPAevL, 0, m, &cDelay_yXVPAevL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Bn6ZSOq2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_yXVPAevL, 0, m, &cDelay_yXVPAevL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_l1CrDn10_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2MyGeHkZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_X14I16JY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Nzf0xXKn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kzhvzT4V_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QMGz4LQE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QMGz4LQE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ftgKVPgt_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_kzhvzT4V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BLqVeYnv, 1, m, &cIf_BLqVeYnv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_X14I16JY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Iu8HWRkb, 0, m, &cIf_Iu8HWRkb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2MyGeHkZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Iu8HWRkb, 1, m, &cIf_Iu8HWRkb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4kriCN2J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Mmd2kNS9, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_40PL6Uey_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Mmd2kNS9, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_EewbAlAV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_eTgsrRe8_sendMessage(_c, 0, m);
  cMsg_MVpwfofs_sendMessage(_c, 0, m);
  cMsg_nWiasYhl_sendMessage(_c, 0, m);
  cMsg_whHE61Ny_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ypWzMkH9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_eTgsrRe8_sendMessage(_c, 0, m);
  cMsg_N11Man26_sendMessage(_c, 0, m);
  cMsg_gpYCYQER_sendMessage(_c, 0, m);
  cMsg_gOF1WKNm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_muFibMfH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_ADsz50tQ_sendMessage(_c, 0, m);
  cMsg_N11Man26_sendMessage(_c, 0, m);
  cMsg_whHE61Ny_sendMessage(_c, 0, m);
  cMsg_1BVM9rjg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_aeRd1hnR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_ADsz50tQ_sendMessage(_c, 0, m);
  cMsg_lgnviCzE_sendMessage(_c, 0, m);
  cMsg_nWiasYhl_sendMessage(_c, 0, m);
  cMsg_keq3RC5a_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_iyxI9Jfy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_UH8DG982_sendMessage(_c, 0, m);
  cMsg_gOF1WKNm_sendMessage(_c, 0, m);
  cMsg_Yi2vfcUf_sendMessage(_c, 0, m);
  cMsg_nWiasYhl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_n0TAKO7c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_UH8DG982_sendMessage(_c, 0, m);
  cMsg_keq3RC5a_sendMessage(_c, 0, m);
  cMsg_N11Man26_sendMessage(_c, 0, m);
  cMsg_8nPSeDUF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Wrkm1WeQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_PzX3T6JY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_cnSGVGRH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3XGpYFda_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_PzX3T6JY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_cnSGVGRH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_s9b3yQGJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_lwjKJyI0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_AzG4vbyj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PTjlumlv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_lwjKJyI0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_AzG4vbyj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8TmhXmfU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_MWuuRkzy_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_zr03zMjH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7cnSeveu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_MWuuRkzy_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_zr03zMjH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_eTgsrRe8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_Wrkm1WeQ_sendMessage(_c, 0, m);
  cMsg_PTjlumlv_sendMessage(_c, 0, m);
  cMsg_7cnSeveu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ADsz50tQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_3XGpYFda_sendMessage(_c, 0, m);
  cMsg_s9b3yQGJ_sendMessage(_c, 0, m);
  cMsg_7cnSeveu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_UH8DG982_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_3XGpYFda_sendMessage(_c, 0, m);
  cMsg_PTjlumlv_sendMessage(_c, 0, m);
  cMsg_8TmhXmfU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Y4qDgbY6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_P3hL5ypI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_kMwRQdrH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_u67hSfqw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_P3hL5ypI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_kMwRQdrH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MfNAGsmx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_X3GMtdUH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ORyBG921_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_vqD8Xky9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_X3GMtdUH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ORyBG921_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_h6xmXFOr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_XdWuWbvE_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_oYQsD0Yp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_S7tYd6ir_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_XdWuWbvE_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_oYQsD0Yp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_N11Man26_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_u67hSfqw_sendMessage(_c, 0, m);
  cMsg_vqD8Xky9_sendMessage(_c, 0, m);
  cMsg_S7tYd6ir_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_MVpwfofs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_u67hSfqw_sendMessage(_c, 0, m);
  cMsg_MfNAGsmx_sendMessage(_c, 0, m);
  cMsg_h6xmXFOr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_lgnviCzE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_Y4qDgbY6_sendMessage(_c, 0, m);
  cMsg_vqD8Xky9_sendMessage(_c, 0, m);
  cMsg_h6xmXFOr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_5UKw6HOS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_tNjAk4lj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_BcN4wcXY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2O5U4KQl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_tNjAk4lj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_BcN4wcXY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_1M4YBf0y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_zDWZegVD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_HqWJIHif_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mRJh59Ei_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_zDWZegVD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_HqWJIHif_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VqfdQGjx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Nzf0xXKn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_l1CrDn10_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bj6d7UVc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Nzf0xXKn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_l1CrDn10_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_keq3RC5a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_5UKw6HOS_sendMessage(_c, 0, m);
  cMsg_mRJh59Ei_sendMessage(_c, 0, m);
  cMsg_bj6d7UVc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_gOF1WKNm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_2O5U4KQl_sendMessage(_c, 0, m);
  cMsg_1M4YBf0y_sendMessage(_c, 0, m);
  cMsg_bj6d7UVc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_whHE61Ny_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_2O5U4KQl_sendMessage(_c, 0, m);
  cMsg_mRJh59Ei_sendMessage(_c, 0, m);
  cMsg_VqfdQGjx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_d4OdDvlq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_C2GTJXcq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_H9GsQCSS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nPWK92mD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_C2GTJXcq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_H9GsQCSS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uqqymEJh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_EbzoabP3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_dvewl0k4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9g5zTk7T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_EbzoabP3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_dvewl0k4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MHskeusG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_8lvHe2fN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_5Q7SuGD9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YGeSNAC6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_8lvHe2fN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_5Q7SuGD9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nWiasYhl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_nPWK92mD_sendMessage(_c, 0, m);
  cMsg_9g5zTk7T_sendMessage(_c, 0, m);
  cMsg_YGeSNAC6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_gpYCYQER_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_nPWK92mD_sendMessage(_c, 0, m);
  cMsg_uqqymEJh_sendMessage(_c, 0, m);
  cMsg_MHskeusG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_8nPSeDUF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_d4OdDvlq_sendMessage(_c, 0, m);
  cMsg_uqqymEJh_sendMessage(_c, 0, m);
  cMsg_YGeSNAC6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Yi2vfcUf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_Y4qDgbY6_sendMessage(_c, 0, m);
  cMsg_MfNAGsmx_sendMessage(_c, 0, m);
  cMsg_S7tYd6ir_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_1BVM9rjg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_d4OdDvlq_sendMessage(_c, 0, m);
  cMsg_9g5zTk7T_sendMessage(_c, 0, m);
  cMsg_MHskeusG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_orhaUeuv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rVzwLj9i_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_B5G3qAfe_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Ja6VPpgo, 0, m, &cSlice_Ja6VPpgo_sendMessage);
      break;
    }
    default: {
      cSwitchcase_iMSPkhPO_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_Ja6VPpgo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Xj6EmIy1_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Xj6EmIy1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_sGAr1xaR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Xj6EmIy1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_Xj6EmIy1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_3G5jmUUB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_zp1IPytk_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_bituh0Yt, 0, m, &cSlice_bituh0Yt_sendMessage);
      break;
    }
    default: {
      cSwitchcase_pUjGtV7i_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_bituh0Yt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_563PC8fT_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_563PC8fT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_ransgAHx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_563PC8fT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_563PC8fT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_2nhWJ6cV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_pUjGtV7i_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_A5xbB2yb, 0, m, &cSlice_A5xbB2yb_sendMessage);
      break;
    }
    default: {
      cSwitchcase_B5G3qAfe_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_A5xbB2yb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_dzTjv4iU_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_dzTjv4iU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_8NbY07DF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_dzTjv4iU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_dzTjv4iU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_NEXuz19N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_iMSPkhPO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_wFlNrQS9, 0, m, &cSlice_wFlNrQS9_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Gw8el5jD_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_wFlNrQS9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_gMYBqWwg_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_gMYBqWwg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_3j0McVlx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_gMYBqWwg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_gMYBqWwg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_GwBr1cEL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Gw8el5jD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_XawAKIf7, 0, m, &cSlice_XawAKIf7_sendMessage);
      break;
    }
    default: {
      cSwitchcase_DmIAe3Eq_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_XawAKIf7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_3Cc1yusI_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_3Cc1yusI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_RY8HOqIe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_3Cc1yusI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_3Cc1yusI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_pRGGr1jS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_FY18KFZ2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Yl39URyT_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Yl39URyT_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_tbIFMRUJ, 1, m, &cDelay_tbIFMRUJ_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tAfcbB3s_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_tbIFMRUJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_tbIFMRUJ, m);
  cMsg_25kTZwLj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Yl39URyT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_tbIFMRUJ, 0, m, &cDelay_tbIFMRUJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tAfcbB3s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_tbIFMRUJ, 0, m, &cDelay_tbIFMRUJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_vFcAfHS0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fFM9Qydn, HV_BINOP_SUBTRACT, 0, m, &cBinop_fFM9Qydn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_gUQTfA6O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_PsnO35uM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_zj24EOUj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_PsnO35uM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_RZCH8jAL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vFcAfHS0, 0, m, &cVar_vFcAfHS0_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_bj8QzG7b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LCiab5yo_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_abWwPWYf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iLNhn5Tj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fFM9Qydn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pdwZBEf6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_pdwZBEf6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_XIREBukT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XIREBukT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_aSfoNqc2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_YjrRuTuc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_t32Yn3KF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7cRNc0Sj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7cRNc0Sj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RHqsLqO3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_t32Yn3KF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gUQTfA6O, 1, m, &cIf_gUQTfA6O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_oELMLbl0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zj24EOUj, 1, m, &cIf_zj24EOUj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_RHqsLqO3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_gUQTfA6O, 0, m, &cIf_gUQTfA6O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_aSfoNqc2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zj24EOUj, 0, m, &cIf_zj24EOUj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_abWwPWYf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fFM9Qydn, HV_BINOP_SUBTRACT, 1, m, &cBinop_fFM9Qydn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LCiab5yo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_iLNhn5Tj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vFcAfHS0, 0, m, &cVar_vFcAfHS0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PsnO35uM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FA5b1MXg, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_DmIAe3Eq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_XzUn4uh8, 0, m, &cSlice_XzUn4uh8_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_XzUn4uh8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_9UyumBvt_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_9UyumBvt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_o1djFV8E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_9UyumBvt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_9UyumBvt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_F4QLsFC2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_SKa8FE7i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4vtZuQ7f, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_YuZZ5zLj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KmK1fSNj, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_O7Wg5Rc5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ayDIsEJV, 0, m, &cVar_ayDIsEJV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rVzwLj9i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fXGk3TNG, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_7PI0WKym_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qbjfOxQ3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_3ppSYQ1O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_FY18KFZ2_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_25kTZwLj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6r47bCT1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_qbjfOxQ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6r47bCT1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_SODjgOjB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_Vfn60GqP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Vfn60GqP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lpw3KIfg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_lpw3KIfg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oL5q1K2N, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_VoOOqu1O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4xNblrEi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_UlM7lBhj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_I9ttYnMn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_jUyJmEiP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hGsPxoHP_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_q51NafLq_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WNKiE5Re_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jVSEReMs_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wXUythEf_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7WsVzfyz_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_hGsPxoHP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WSqJYsbr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_q51NafLq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_i0ZZl9bk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_WNKiE5Re_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xeQKB2lX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_jVSEReMs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nuIOqeIw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_wXUythEf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hlSElsOC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_7WsVzfyz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6wM5vvQB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_BhatrJ5W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_CjL1JXnC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_1fZPAyIu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_XbcS7LXF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_rrpszmdM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_HYgTeNYq_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_HYgTeNYq_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_OUPGhjE0, 1, m, &cDelay_OUPGhjE0_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_INvNfGmX_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_OUPGhjE0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_OUPGhjE0, m);
  cIf_onMessage(_c, &Context(_c)->cIf_BhatrJ5W, 0, m, &cIf_BhatrJ5W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HYgTeNYq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_OUPGhjE0, 0, m, &cDelay_OUPGhjE0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_INvNfGmX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_OUPGhjE0, 0, m, &cDelay_OUPGhjE0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZV1nIrv6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7SeJWl7u_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HieyAdcu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jOJg4imC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_omB6x2rf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vfrS1ks2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vfrS1ks2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_rrpszmdM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_omB6x2rf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BhatrJ5W, 1, m, &cIf_BhatrJ5W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HieyAdcu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1fZPAyIu, 0, m, &cIf_1fZPAyIu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7SeJWl7u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1fZPAyIu, 1, m, &cIf_1fZPAyIu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XbcS7LXF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bUZA1afd, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_CjL1JXnC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bUZA1afd, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_qAI0UIw2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_kFjfjfr8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_oRf3Hijj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_OI12SeCq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_J0tHN6X6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_bPoccglg_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_bPoccglg_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_HYf3VKyy, 1, m, &cDelay_HYf3VKyy_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rekhRBQ7_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_HYf3VKyy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_HYf3VKyy, m);
  cIf_onMessage(_c, &Context(_c)->cIf_qAI0UIw2, 0, m, &cIf_qAI0UIw2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bPoccglg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_HYf3VKyy, 0, m, &cDelay_HYf3VKyy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rekhRBQ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_HYf3VKyy, 0, m, &cDelay_HYf3VKyy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_M6HFhVak_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YpmXFDth_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KlEdowP6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LRWdHHtR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aW9clP5M_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ff0HMsl9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ff0HMsl9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_J0tHN6X6_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_aW9clP5M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qAI0UIw2, 1, m, &cIf_qAI0UIw2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KlEdowP6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oRf3Hijj, 0, m, &cIf_oRf3Hijj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YpmXFDth_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oRf3Hijj, 1, m, &cIf_oRf3Hijj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OI12SeCq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Qy0ZIMpy, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_kFjfjfr8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Qy0ZIMpy, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_2cnZQHiB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ZrlSfMsF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_j1yf3oul_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_3D3X7IOc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_CWeoetbe_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_TJMDgl73_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_TJMDgl73_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_fhj7uDuV, 1, m, &cDelay_fhj7uDuV_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZrOnY3MI_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_fhj7uDuV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_fhj7uDuV, m);
  cIf_onMessage(_c, &Context(_c)->cIf_2cnZQHiB, 0, m, &cIf_2cnZQHiB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TJMDgl73_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_fhj7uDuV, 0, m, &cDelay_fhj7uDuV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZrOnY3MI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_fhj7uDuV, 0, m, &cDelay_fhj7uDuV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_BeuanjPj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6HO4PaQ9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_X3VXtDFm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EFD6JEJy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xVrvBmNR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vtfMDInb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vtfMDInb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_CWeoetbe_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_xVrvBmNR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2cnZQHiB, 1, m, &cIf_2cnZQHiB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_X3VXtDFm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_j1yf3oul, 0, m, &cIf_j1yf3oul_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6HO4PaQ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_j1yf3oul, 1, m, &cIf_j1yf3oul_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3D3X7IOc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zkX03kpk, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ZrlSfMsF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zkX03kpk, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_SwlAuWHG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ZxCSjgAZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_FmjnvTlM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Uag9y7LS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_xLrbmXB9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_68KIEOkc_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_68KIEOkc_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_kzM4lGxX, 1, m, &cDelay_kzM4lGxX_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tdJxWsDa_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_kzM4lGxX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_kzM4lGxX, m);
  cIf_onMessage(_c, &Context(_c)->cIf_SwlAuWHG, 0, m, &cIf_SwlAuWHG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_68KIEOkc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_kzM4lGxX, 0, m, &cDelay_kzM4lGxX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tdJxWsDa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_kzM4lGxX, 0, m, &cDelay_kzM4lGxX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0KQVf7fW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_30PEBbo6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dLQyZRTt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4UOFxiyM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9kQqHOCZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_x26zjWin_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_x26zjWin_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_xLrbmXB9_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_9kQqHOCZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SwlAuWHG, 1, m, &cIf_SwlAuWHG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_30PEBbo6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FmjnvTlM, 1, m, &cIf_FmjnvTlM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dLQyZRTt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FmjnvTlM, 0, m, &cIf_FmjnvTlM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Uag9y7LS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0BHFvKMK, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ZxCSjgAZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0BHFvKMK, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_tb366rz2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_7pVoAgib_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_ds9cliEm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_DAo4WKnO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_c3nqwum4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_SG4D8lit_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_SG4D8lit_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_HE44uwFV, 1, m, &cDelay_HE44uwFV_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7hcQOk8e_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_HE44uwFV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_HE44uwFV, m);
  cIf_onMessage(_c, &Context(_c)->cIf_tb366rz2, 0, m, &cIf_tb366rz2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SG4D8lit_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_HE44uwFV, 0, m, &cDelay_HE44uwFV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7hcQOk8e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_HE44uwFV, 0, m, &cDelay_HE44uwFV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Twlmr1kL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Cwii3J1p_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DMIt8Gu8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ra7tOGyf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_w766twnZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CGbM3Xqi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CGbM3Xqi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_c3nqwum4_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_w766twnZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tb366rz2, 1, m, &cIf_tb366rz2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Cwii3J1p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ds9cliEm, 1, m, &cIf_ds9cliEm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DMIt8Gu8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ds9cliEm, 0, m, &cIf_ds9cliEm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DAo4WKnO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VOURrgbZ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_7pVoAgib_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VOURrgbZ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_0XK92Nu3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0ulGNqDS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_JoHgxUA4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_2XhzzXuZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_SeXJtgSo_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_qBCqkecU_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_qBCqkecU_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_n07GgZsM, 1, m, &cDelay_n07GgZsM_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1h8fjg3P_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_n07GgZsM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_n07GgZsM, m);
  cIf_onMessage(_c, &Context(_c)->cIf_0XK92Nu3, 0, m, &cIf_0XK92Nu3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qBCqkecU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_n07GgZsM, 0, m, &cDelay_n07GgZsM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1h8fjg3P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_n07GgZsM, 0, m, &cDelay_n07GgZsM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_eoQamKRM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9fhXx7Bv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tdovC8Eo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_t8qUFGby_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lmvVHxTA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dZA980rc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dZA980rc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_SeXJtgSo_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_lmvVHxTA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0XK92Nu3, 1, m, &cIf_0XK92Nu3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9fhXx7Bv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JoHgxUA4, 1, m, &cIf_JoHgxUA4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tdovC8Eo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JoHgxUA4, 0, m, &cIf_JoHgxUA4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2XhzzXuZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6Nf0eLXa, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_0ulGNqDS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6Nf0eLXa, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_T8Ta5Gfs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_qpTevu4j_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_NZzBCpRp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_gu58VzFg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_iE5Roaiv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_zYMY5KSP_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_zYMY5KSP_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_lWquL44y, 1, m, &cDelay_lWquL44y_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7dTDO6vV_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_lWquL44y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_lWquL44y, m);
  cIf_onMessage(_c, &Context(_c)->cIf_T8Ta5Gfs, 0, m, &cIf_T8Ta5Gfs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zYMY5KSP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_lWquL44y, 0, m, &cDelay_lWquL44y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7dTDO6vV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_lWquL44y, 0, m, &cDelay_lWquL44y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZzXM2Bk9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IsyvkMN0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jt2OSYHz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MNr770Mv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZCaDJYr6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mHOLKhRA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mHOLKhRA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_iE5Roaiv_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ZCaDJYr6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_T8Ta5Gfs, 1, m, &cIf_T8Ta5Gfs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jt2OSYHz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NZzBCpRp, 0, m, &cIf_NZzBCpRp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_IsyvkMN0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NZzBCpRp, 1, m, &cIf_NZzBCpRp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gu58VzFg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LK60hgXP, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_qpTevu4j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LK60hgXP, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_FXBnVKsU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ZrY5gb1g_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_fCGMocZV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_MBDJknB3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_UA9XU9Wx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_kxFZIsw3_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_kxFZIsw3_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_MiEr5tYy, 1, m, &cDelay_MiEr5tYy_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DcrUHy4S_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_MiEr5tYy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_MiEr5tYy, m);
  cIf_onMessage(_c, &Context(_c)->cIf_FXBnVKsU, 0, m, &cIf_FXBnVKsU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kxFZIsw3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_MiEr5tYy, 0, m, &cDelay_MiEr5tYy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DcrUHy4S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_MiEr5tYy, 0, m, &cDelay_MiEr5tYy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_87ifb64J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Jx7Ugb7H_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HaIyTpaq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6Qvc4BM5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZowCAAZX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gAvLqbRP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gAvLqbRP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_UA9XU9Wx_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ZowCAAZX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FXBnVKsU, 1, m, &cIf_FXBnVKsU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HaIyTpaq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fCGMocZV, 0, m, &cIf_fCGMocZV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Jx7Ugb7H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fCGMocZV, 1, m, &cIf_fCGMocZV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MBDJknB3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_AJnmZVbY, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ZrY5gb1g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_AJnmZVbY, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_ItolwcWJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ai53hNWh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_3aU4lxpF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_5wlBVUlQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_iI8CEZZa_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_lF4qylHG_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_lF4qylHG_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_cqi8ktGS, 1, m, &cDelay_cqi8ktGS_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1HlopGUJ_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_cqi8ktGS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_cqi8ktGS, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ItolwcWJ, 0, m, &cIf_ItolwcWJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lF4qylHG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_cqi8ktGS, 0, m, &cDelay_cqi8ktGS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1HlopGUJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_cqi8ktGS, 0, m, &cDelay_cqi8ktGS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_SFfuPlk6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RHyZnfcz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IVIfl7aj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_N2ca4tfg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GtONpM2U_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LGALYgXX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LGALYgXX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_iI8CEZZa_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_GtONpM2U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ItolwcWJ, 1, m, &cIf_ItolwcWJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_IVIfl7aj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3aU4lxpF, 0, m, &cIf_3aU4lxpF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RHyZnfcz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3aU4lxpF, 1, m, &cIf_3aU4lxpF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5wlBVUlQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uNZINdA4, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ai53hNWh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uNZINdA4, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_dHbOdBo0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_eAg5veIc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_IdiVkzoi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_E4zHZsD5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_mMQfP2V0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_w1nsdjHu_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_w1nsdjHu_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ZHUdJQtC, 1, m, &cDelay_ZHUdJQtC_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KkIphPut_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_ZHUdJQtC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ZHUdJQtC, m);
  cIf_onMessage(_c, &Context(_c)->cIf_dHbOdBo0, 0, m, &cIf_dHbOdBo0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_w1nsdjHu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZHUdJQtC, 0, m, &cDelay_ZHUdJQtC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KkIphPut_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZHUdJQtC, 0, m, &cDelay_ZHUdJQtC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gKkefnk2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Q4M610xV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cIqlKosu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7JEegYsO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jP4mOCWw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_c4wgdDX6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jP4mOCWw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dHbOdBo0, 1, m, &cIf_dHbOdBo0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_c4wgdDX6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_mMQfP2V0_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_cIqlKosu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IdiVkzoi, 0, m, &cIf_IdiVkzoi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Q4M610xV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IdiVkzoi, 1, m, &cIf_IdiVkzoi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_E4zHZsD5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_67M3E6wP, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_eAg5veIc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_67M3E6wP, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_YDbYPeGt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_zdks9LiN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_wDghrXU7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_dGEeXOcX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_s2OLq6Z9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_SnWEVWRk_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_SnWEVWRk_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_rIT18sbD, 1, m, &cDelay_rIT18sbD_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6KJ5Qw9q_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_rIT18sbD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_rIT18sbD, m);
  cIf_onMessage(_c, &Context(_c)->cIf_YDbYPeGt, 0, m, &cIf_YDbYPeGt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SnWEVWRk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_rIT18sbD, 0, m, &cDelay_rIT18sbD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6KJ5Qw9q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_rIT18sbD, 0, m, &cDelay_rIT18sbD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_q5PmsMVt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sysJKZgc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XeabmiJG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_URRe00zp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8Ak12gDZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cvB8KsuC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8Ak12gDZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YDbYPeGt, 1, m, &cIf_YDbYPeGt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cvB8KsuC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_s2OLq6Z9_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_sysJKZgc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wDghrXU7, 1, m, &cIf_wDghrXU7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XeabmiJG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wDghrXU7, 0, m, &cIf_wDghrXU7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_dGEeXOcX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iSIE0oz8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_zdks9LiN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iSIE0oz8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_kGwYV8A1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_lIw5wvRc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_38MOS45M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_W0X9vhrG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_PQstpHER_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ErPRQstM_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ErPRQstM_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_4ZI4BuNw, 1, m, &cDelay_4ZI4BuNw_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Foow3Fqa_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_4ZI4BuNw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_4ZI4BuNw, m);
  cIf_onMessage(_c, &Context(_c)->cIf_kGwYV8A1, 0, m, &cIf_kGwYV8A1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ErPRQstM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_4ZI4BuNw, 0, m, &cDelay_4ZI4BuNw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Foow3Fqa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_4ZI4BuNw, 0, m, &cDelay_4ZI4BuNw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2WfkWSKc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_scB4Iqaf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FKvR4ttD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_KMZEglgb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yjqHM90y_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Wy03eiW9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yjqHM90y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kGwYV8A1, 1, m, &cIf_kGwYV8A1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Wy03eiW9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_PQstpHER_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_scB4Iqaf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_38MOS45M, 1, m, &cIf_38MOS45M_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FKvR4ttD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_38MOS45M, 0, m, &cIf_38MOS45M_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_W0X9vhrG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DfYr3m1d, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_lIw5wvRc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DfYr3m1d, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_WSqJYsbr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_vs41Z7OT_sendMessage(_c, 0, m);
  cMsg_ZQI9M8q8_sendMessage(_c, 0, m);
  cMsg_qoNDxSwl_sendMessage(_c, 0, m);
  cMsg_wsCmMDTl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_i0ZZl9bk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_vs41Z7OT_sendMessage(_c, 0, m);
  cMsg_cJdDGZX6_sendMessage(_c, 0, m);
  cMsg_ckA21NUP_sendMessage(_c, 0, m);
  cMsg_1MP9Mzt4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_xeQKB2lX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_KY5Ji0W3_sendMessage(_c, 0, m);
  cMsg_cJdDGZX6_sendMessage(_c, 0, m);
  cMsg_wsCmMDTl_sendMessage(_c, 0, m);
  cMsg_xwn0rrIn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_nuIOqeIw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_KY5Ji0W3_sendMessage(_c, 0, m);
  cMsg_TYVxzGXC_sendMessage(_c, 0, m);
  cMsg_qoNDxSwl_sendMessage(_c, 0, m);
  cMsg_Q6B6RQRs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_hlSElsOC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_4wIF3D9N_sendMessage(_c, 0, m);
  cMsg_1MP9Mzt4_sendMessage(_c, 0, m);
  cMsg_ktiOWvp0_sendMessage(_c, 0, m);
  cMsg_qoNDxSwl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_6wM5vvQB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_4wIF3D9N_sendMessage(_c, 0, m);
  cMsg_Q6B6RQRs_sendMessage(_c, 0, m);
  cMsg_cJdDGZX6_sendMessage(_c, 0, m);
  cMsg_XNz8DfkZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Qr4DsX9r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_jOJg4imC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ZV1nIrv6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bBlr7qG8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_jOJg4imC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ZV1nIrv6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jJfOxBqC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_LRWdHHtR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_M6HFhVak_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OHV8FyZZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_LRWdHHtR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_M6HFhVak_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XJtsHpIg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_EFD6JEJy_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_BeuanjPj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KhV8E0EW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_EFD6JEJy_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_BeuanjPj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_vs41Z7OT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_Qr4DsX9r_sendMessage(_c, 0, m);
  cMsg_OHV8FyZZ_sendMessage(_c, 0, m);
  cMsg_KhV8E0EW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_KY5Ji0W3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_bBlr7qG8_sendMessage(_c, 0, m);
  cMsg_jJfOxBqC_sendMessage(_c, 0, m);
  cMsg_KhV8E0EW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_4wIF3D9N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_bBlr7qG8_sendMessage(_c, 0, m);
  cMsg_OHV8FyZZ_sendMessage(_c, 0, m);
  cMsg_XJtsHpIg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_g7Uexbly_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_4UOFxiyM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_0KQVf7fW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GEWV0SR7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_4UOFxiyM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_0KQVf7fW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Kj6mxcY7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ra7tOGyf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Twlmr1kL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_o14tjRBC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ra7tOGyf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Twlmr1kL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Djy0WOlf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_t8qUFGby_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_eoQamKRM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8lHgfNe6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_t8qUFGby_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_eoQamKRM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cJdDGZX6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_GEWV0SR7_sendMessage(_c, 0, m);
  cMsg_o14tjRBC_sendMessage(_c, 0, m);
  cMsg_8lHgfNe6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ZQI9M8q8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_GEWV0SR7_sendMessage(_c, 0, m);
  cMsg_Kj6mxcY7_sendMessage(_c, 0, m);
  cMsg_Djy0WOlf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_TYVxzGXC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_g7Uexbly_sendMessage(_c, 0, m);
  cMsg_o14tjRBC_sendMessage(_c, 0, m);
  cMsg_Djy0WOlf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_NSURvW6B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_7JEegYsO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_gKkefnk2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fC6ROWLN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_7JEegYsO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_gKkefnk2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MzRytamp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_URRe00zp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_q5PmsMVt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oXGXGD5r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_URRe00zp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_q5PmsMVt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_q2q4MERr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_KMZEglgb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2WfkWSKc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CQV6rdyq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_KMZEglgb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2WfkWSKc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Q6B6RQRs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_NSURvW6B_sendMessage(_c, 0, m);
  cMsg_oXGXGD5r_sendMessage(_c, 0, m);
  cMsg_CQV6rdyq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_1MP9Mzt4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_fC6ROWLN_sendMessage(_c, 0, m);
  cMsg_MzRytamp_sendMessage(_c, 0, m);
  cMsg_CQV6rdyq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_wsCmMDTl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_fC6ROWLN_sendMessage(_c, 0, m);
  cMsg_oXGXGD5r_sendMessage(_c, 0, m);
  cMsg_q2q4MERr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_PRIIzaa5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_MNr770Mv_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ZzXM2Bk9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_IilBNju4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_MNr770Mv_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ZzXM2Bk9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9BzQ9rAu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_6Qvc4BM5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_87ifb64J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TniEqmbN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_6Qvc4BM5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_87ifb64J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_U1GJPI7R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_N2ca4tfg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_SFfuPlk6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NjewXf1p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_N2ca4tfg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_SFfuPlk6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qoNDxSwl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_IilBNju4_sendMessage(_c, 0, m);
  cMsg_TniEqmbN_sendMessage(_c, 0, m);
  cMsg_NjewXf1p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ckA21NUP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_IilBNju4_sendMessage(_c, 0, m);
  cMsg_9BzQ9rAu_sendMessage(_c, 0, m);
  cMsg_U1GJPI7R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_XNz8DfkZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_PRIIzaa5_sendMessage(_c, 0, m);
  cMsg_9BzQ9rAu_sendMessage(_c, 0, m);
  cMsg_NjewXf1p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ktiOWvp0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_g7Uexbly_sendMessage(_c, 0, m);
  cMsg_Kj6mxcY7_sendMessage(_c, 0, m);
  cMsg_8lHgfNe6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_xwn0rrIn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_PRIIzaa5_sendMessage(_c, 0, m);
  cMsg_TniEqmbN_sendMessage(_c, 0, m);
  cMsg_U1GJPI7R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_KeGyhv4R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BALKH6yz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_RlYQDR0q_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_sLQiJSw9, 0, m, &cSlice_sLQiJSw9_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Z1nwTWWN_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_sLQiJSw9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_QolScQHL_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_QolScQHL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_MkzEypdd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_QolScQHL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_QolScQHL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_t44ahREf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_bGRYcfTu_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_QS2hFI4z, 0, m, &cSlice_QS2hFI4z_sendMessage);
      break;
    }
    default: {
      cSwitchcase_n1aBkscb_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_QS2hFI4z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_EJlwvtBP_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_EJlwvtBP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_igJnpcI1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_EJlwvtBP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_EJlwvtBP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_HNXbsGFM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_n1aBkscb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_mpXHmoCx, 0, m, &cSlice_mpXHmoCx_sendMessage);
      break;
    }
    default: {
      cSwitchcase_RlYQDR0q_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_mpXHmoCx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ieWNjVSc_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ieWNjVSc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Op1P6H2G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ieWNjVSc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_ieWNjVSc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_CunywCnR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Z1nwTWWN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_1pynreZF, 0, m, &cSlice_1pynreZF_sendMessage);
      break;
    }
    default: {
      cSwitchcase_i9nJMGpu_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_1pynreZF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_S0iLFGFJ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_S0iLFGFJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_sISJbFDo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_S0iLFGFJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_S0iLFGFJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_aUNCouzS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_i9nJMGpu_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_AnrJa0WR, 0, m, &cSlice_AnrJa0WR_sendMessage);
      break;
    }
    default: {
      cSwitchcase_NpCoAYkS_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_AnrJa0WR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_za8Qj8DQ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_za8Qj8DQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_daVytTZQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_za8Qj8DQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_za8Qj8DQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_zgvPvukY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_qInkWVPV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_UxBydKqW_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_UxBydKqW_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_2ZvFh2Sn, 1, m, &cDelay_2ZvFh2Sn_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BzNfZl9C_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_2ZvFh2Sn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_2ZvFh2Sn, m);
  cMsg_G8XilOla_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_UxBydKqW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_2ZvFh2Sn, 0, m, &cDelay_2ZvFh2Sn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BzNfZl9C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_2ZvFh2Sn, 0, m, &cDelay_2ZvFh2Sn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_I0yNsIkB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lLHcXJZJ, HV_BINOP_SUBTRACT, 0, m, &cBinop_lLHcXJZJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_sxQl0krv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_3doigsBu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_97a3pK0e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_3doigsBu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_VWLEd1QS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_I0yNsIkB, 0, m, &cVar_I0yNsIkB_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_ikRhLRMF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NjxpCNaj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_D7wl5kDA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HPn8bahi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_lLHcXJZJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kqaffvjP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_kqaffvjP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_kzwXUv9H_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kzwXUv9H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_wKkMkBU2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8mZXiCES_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SzWLA5YU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2hyJlbOC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2hyJlbOC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_d1sSa4ww_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_SzWLA5YU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sxQl0krv, 1, m, &cIf_sxQl0krv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vgINHIoR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_97a3pK0e, 1, m, &cIf_97a3pK0e_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_d1sSa4ww_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_sxQl0krv, 0, m, &cIf_sxQl0krv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wKkMkBU2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_97a3pK0e, 0, m, &cIf_97a3pK0e_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NjxpCNaj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_HPn8bahi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_I0yNsIkB, 0, m, &cVar_I0yNsIkB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_D7wl5kDA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lLHcXJZJ, HV_BINOP_SUBTRACT, 1, m, &cBinop_lLHcXJZJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3doigsBu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IrBLfNLc, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_NpCoAYkS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_R0eJWsbv, 0, m, &cSlice_R0eJWsbv_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_R0eJWsbv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_pI7sW99Y_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_pI7sW99Y_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_ocYHFT03_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_pI7sW99Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_pI7sW99Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_AxH5hjcr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_4xNblrEi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NakVpx3o, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_I9ttYnMn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HqOCtpVt, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_c31lNgcE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UlM7lBhj, 0, m, &cVar_UlM7lBhj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BALKH6yz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_n4hu2Je3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_yzCEaojy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_G1ldnyHi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_sRCr4es1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_qInkWVPV_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_G8XilOla_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5NCcLyqi, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_G1ldnyHi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5NCcLyqi, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_xGSFrGcv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_ItDTwq4H_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ItDTwq4H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TCEXTQ4d_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_TCEXTQ4d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_khdOAqc2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_Y8115dMv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fFidIty5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_XrOkVY1P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mL3Cj0yW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_YaEk4EjA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RXfKuZ3Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_2lkPAudV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_t6gZfpn3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_beHC6D9R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JI4S5NXN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_pGmUEVAf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_BlVVNBWr_sendMessage);
  cMsg_DLt8If60_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_BlVVNBWr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pGmUEVAf, 1, m, &cVar_pGmUEVAf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BeanKCbZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YpjCcU3X_sendMessage(_c, 0, m);
  cMsg_mVoQnVaL_sendMessage(_c, 0, m);
  cMsg_rVPdSqGx_sendMessage(_c, 0, m);
  cMsg_Jr5dCnvI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Ree85Zjj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_eKcMhOwR, 0, m, &cSlice_eKcMhOwR_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_eKcMhOwR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_c9rWhFcN_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_c9rWhFcN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_eT6dLPOC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_c9rWhFcN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_c9rWhFcN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_zizwtY1l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_PxmB7ZT1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_GthMe9me_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GthMe9me_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_NWDKwATG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NWDKwATG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_yBQlAKa9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yBQlAKa9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_r1JvAFjl_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PWydMxrb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_r1JvAFjl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_dkKV6ca0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PWydMxrb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BF7BtT8c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_dkKV6ca0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_0qEKlaGv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BF7BtT8c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_3dxjpYqO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3dxjpYqO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_PDTFmDhy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0qEKlaGv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_p10T7I3T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_PDTFmDhy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jzWecRF7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_p10T7I3T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_X8kZHPkM, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_jzWecRF7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fBBJoQcB, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_RwgEjkOv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hynHNc0H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_ajYI5RK4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YqphoNTl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_mRFAYg93_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dVVgml6H_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lEkiqBAY_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pCzXVpAe_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8FIDuEzU_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wmTjbUh2_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mjPuhZeZ_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_dVVgml6H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RKuilNft_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_lEkiqBAY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GA8cZqt2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_pCzXVpAe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_a394AbOK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_8FIDuEzU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LdZ3K04M_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_wmTjbUh2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_v7rxfADD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_mjPuhZeZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GErlGT3c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_NR2cbYZ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_hKHuO5iJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_9yAG4yua_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_y7df6luN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_CEEwG6hn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_wEpmJ7oX_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_wEpmJ7oX_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_RvQx5Z9i, 1, m, &cDelay_RvQx5Z9i_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TBIu6ap1_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_RvQx5Z9i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_RvQx5Z9i, m);
  cIf_onMessage(_c, &Context(_c)->cIf_NR2cbYZ7, 0, m, &cIf_NR2cbYZ7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wEpmJ7oX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_RvQx5Z9i, 0, m, &cDelay_RvQx5Z9i_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TBIu6ap1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_RvQx5Z9i, 0, m, &cDelay_RvQx5Z9i_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_aZfo8xR8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_j6epANgM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_a2BTSOpu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_eWrUeynS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kUJkPF8U_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_889i2Yku_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_889i2Yku_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_CEEwG6hn_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_kUJkPF8U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NR2cbYZ7, 1, m, &cIf_NR2cbYZ7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_a2BTSOpu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9yAG4yua, 0, m, &cIf_9yAG4yua_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_j6epANgM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9yAG4yua, 1, m, &cIf_9yAG4yua_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_y7df6luN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RcQs6LOx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_hKHuO5iJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RcQs6LOx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_6f39tevr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Zw3Olc0U_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_QWp2Dq00_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_1wGiHDvm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_x2pPMpQP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_BO7fr6JY_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_BO7fr6JY_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_4HOXbJnU, 1, m, &cDelay_4HOXbJnU_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TiIluxUh_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_4HOXbJnU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_4HOXbJnU, m);
  cIf_onMessage(_c, &Context(_c)->cIf_6f39tevr, 0, m, &cIf_6f39tevr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BO7fr6JY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_4HOXbJnU, 0, m, &cDelay_4HOXbJnU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TiIluxUh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_4HOXbJnU, 0, m, &cDelay_4HOXbJnU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jPxr8SNB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LDumYnmZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_drowASjY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hglaSMYb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QnwQkN7u_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ixmqAV3M_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ixmqAV3M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_x2pPMpQP_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_QnwQkN7u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6f39tevr, 1, m, &cIf_6f39tevr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LDumYnmZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QWp2Dq00, 1, m, &cIf_QWp2Dq00_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_drowASjY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QWp2Dq00, 0, m, &cIf_QWp2Dq00_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_1wGiHDvm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_c1x18Lyx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Zw3Olc0U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_c1x18Lyx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_PQUIL9sS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_FdPfXdg0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_dbdUW3m4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_jeX0wszY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_tyLFHHDM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_MToTgURs_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_MToTgURs_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_TSjFNM6w, 1, m, &cDelay_TSjFNM6w_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_U84vF7B6_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_TSjFNM6w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_TSjFNM6w, m);
  cIf_onMessage(_c, &Context(_c)->cIf_PQUIL9sS, 0, m, &cIf_PQUIL9sS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MToTgURs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_TSjFNM6w, 0, m, &cDelay_TSjFNM6w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_U84vF7B6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_TSjFNM6w, 0, m, &cDelay_TSjFNM6w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qWoQNZ60_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2V0J0Ld0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mEKCaeqA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2EYTuhmf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CyHveVnC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4gA6mEWb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4gA6mEWb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_tyLFHHDM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_CyHveVnC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PQUIL9sS, 1, m, &cIf_PQUIL9sS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mEKCaeqA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dbdUW3m4, 0, m, &cIf_dbdUW3m4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2V0J0Ld0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dbdUW3m4, 1, m, &cIf_dbdUW3m4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jeX0wszY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9h26dRM0, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_FdPfXdg0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9h26dRM0, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_pEIMJMET_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Sy5vEzBl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_U0Cogc4a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_XAzj4Vf8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_E5g38Umo_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_LbwufilB_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_LbwufilB_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_utSFqSBi, 1, m, &cDelay_utSFqSBi_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ffKmzI2B_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_utSFqSBi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_utSFqSBi, m);
  cIf_onMessage(_c, &Context(_c)->cIf_pEIMJMET, 0, m, &cIf_pEIMJMET_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LbwufilB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_utSFqSBi, 0, m, &cDelay_utSFqSBi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ffKmzI2B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_utSFqSBi, 0, m, &cDelay_utSFqSBi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5iTuRMdg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HNijBIzX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nOJSvXvv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mP8Ne7M1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PRug4sDo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HuVBKj48_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PRug4sDo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pEIMJMET, 1, m, &cIf_pEIMJMET_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HuVBKj48_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_E5g38Umo_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_nOJSvXvv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_U0Cogc4a, 0, m, &cIf_U0Cogc4a_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HNijBIzX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_U0Cogc4a, 1, m, &cIf_U0Cogc4a_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XAzj4Vf8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_klQHZ4J5, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Sy5vEzBl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_klQHZ4J5, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_NAuzZmt3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_11XRjPcP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_liWrHxd4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_530nX2Yh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_aMsF810O_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ShJT7J2U_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ShJT7J2U_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_CVxa70na, 1, m, &cDelay_CVxa70na_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XNtQyb4W_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_CVxa70na_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_CVxa70na, m);
  cIf_onMessage(_c, &Context(_c)->cIf_NAuzZmt3, 0, m, &cIf_NAuzZmt3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ShJT7J2U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_CVxa70na, 0, m, &cDelay_CVxa70na_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XNtQyb4W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_CVxa70na, 0, m, &cDelay_CVxa70na_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_TfTOQ05i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yDA2z5AG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3bjfnYnb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tKgs8b4e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_u08V7QoH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LbIy2D9D_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LbIy2D9D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_aMsF810O_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_u08V7QoH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NAuzZmt3, 1, m, &cIf_NAuzZmt3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yDA2z5AG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_liWrHxd4, 1, m, &cIf_liWrHxd4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3bjfnYnb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_liWrHxd4, 0, m, &cIf_liWrHxd4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_530nX2Yh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WsP5El7I, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_11XRjPcP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WsP5El7I, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Xqliy8Ll_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0O5dlHjT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_S5lX1dwa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_VdRQfqkL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_fardD61k_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_somwfCHh_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_somwfCHh_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_2NskvG2v, 1, m, &cDelay_2NskvG2v_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_z8qej9f6_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_2NskvG2v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_2NskvG2v, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Xqliy8Ll, 0, m, &cIf_Xqliy8Ll_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_somwfCHh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_2NskvG2v, 0, m, &cDelay_2NskvG2v_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_z8qej9f6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_2NskvG2v, 0, m, &cDelay_2NskvG2v_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2l1nrktK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2W726Brk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wPsHTS0o_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3ss5HrOs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SR8hx4TC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_H1Nl9UzQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SR8hx4TC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Xqliy8Ll, 1, m, &cIf_Xqliy8Ll_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_H1Nl9UzQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_fardD61k_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_2W726Brk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_S5lX1dwa, 1, m, &cIf_S5lX1dwa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wPsHTS0o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_S5lX1dwa, 0, m, &cIf_S5lX1dwa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VdRQfqkL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Zfab4kx2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_0O5dlHjT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Zfab4kx2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_MLCPPt8O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_YnMsO8VN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_q3hcNOt2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_VdXxHgNK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_JuzA7HHE_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_yZDB5tl6_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_yZDB5tl6_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_7gKPV5xQ, 1, m, &cDelay_7gKPV5xQ_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TDFAAtse_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_7gKPV5xQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_7gKPV5xQ, m);
  cIf_onMessage(_c, &Context(_c)->cIf_MLCPPt8O, 0, m, &cIf_MLCPPt8O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_yZDB5tl6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_7gKPV5xQ, 0, m, &cDelay_7gKPV5xQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TDFAAtse_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_7gKPV5xQ, 0, m, &cDelay_7gKPV5xQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xG5UJ87T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OJpL7cIe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_j3Hdc0ex_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fjQAZNGg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iX2C7KcI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bT1iYFZW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bT1iYFZW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_JuzA7HHE_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_iX2C7KcI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MLCPPt8O, 1, m, &cIf_MLCPPt8O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OJpL7cIe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_q3hcNOt2, 1, m, &cIf_q3hcNOt2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_j3Hdc0ex_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_q3hcNOt2, 0, m, &cIf_q3hcNOt2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VdXxHgNK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YK7QtwsW, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_YnMsO8VN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YK7QtwsW, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_WsOktgOY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_BrewNxil_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_KCtjIWXC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_zNTefl3i_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_5frT9bht_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ZFJ2ZmA1_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ZFJ2ZmA1_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_F2tyJVt6, 1, m, &cDelay_F2tyJVt6_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aYQGzTds_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_F2tyJVt6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_F2tyJVt6, m);
  cIf_onMessage(_c, &Context(_c)->cIf_WsOktgOY, 0, m, &cIf_WsOktgOY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZFJ2ZmA1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_F2tyJVt6, 0, m, &cDelay_F2tyJVt6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aYQGzTds_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_F2tyJVt6, 0, m, &cDelay_F2tyJVt6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_AeIo6ShK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_O8XgI8QQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HRra9eu8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fP6nO42t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SiPGvT0L_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oPK0lCKI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_oPK0lCKI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_5frT9bht_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_SiPGvT0L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WsOktgOY, 1, m, &cIf_WsOktgOY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_O8XgI8QQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KCtjIWXC, 1, m, &cIf_KCtjIWXC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HRra9eu8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KCtjIWXC, 0, m, &cIf_KCtjIWXC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zNTefl3i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BpqGwC6Q, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_BrewNxil_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BpqGwC6Q, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_70c17vUD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_QADGOWIS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_0wQR5gds_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_dn0GEOvK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_bTlarLiq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Wofu9shE_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Wofu9shE_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_KYtpbQhW, 1, m, &cDelay_KYtpbQhW_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TW0jj3xh_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_KYtpbQhW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_KYtpbQhW, m);
  cIf_onMessage(_c, &Context(_c)->cIf_70c17vUD, 0, m, &cIf_70c17vUD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Wofu9shE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_KYtpbQhW, 0, m, &cDelay_KYtpbQhW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TW0jj3xh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_KYtpbQhW, 0, m, &cDelay_KYtpbQhW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hy2zH4WF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7mm5qfGT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_R00kXuts_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xSyR2hgj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MnmdAj8B_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jXmSHOVj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jXmSHOVj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_bTlarLiq_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_MnmdAj8B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_70c17vUD, 1, m, &cIf_70c17vUD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_R00kXuts_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0wQR5gds, 0, m, &cIf_0wQR5gds_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7mm5qfGT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0wQR5gds, 1, m, &cIf_0wQR5gds_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_dn0GEOvK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_sHQr4Y7K, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_QADGOWIS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_sHQr4Y7K, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_f8066dYg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_x6VMogW7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_3oNUCkoH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_t6juYxRA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_n1jvd2b7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_W8mgUhaV_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_W8mgUhaV_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_rMM92iq4, 1, m, &cDelay_rMM92iq4_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cbceJo8n_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_rMM92iq4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_rMM92iq4, m);
  cIf_onMessage(_c, &Context(_c)->cIf_f8066dYg, 0, m, &cIf_f8066dYg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_W8mgUhaV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_rMM92iq4, 0, m, &cDelay_rMM92iq4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cbceJo8n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_rMM92iq4, 0, m, &cDelay_rMM92iq4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nMAAfNV0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YEAOhoQJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Hb8vrOA6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pemh2bg0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wETdD9K6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BzUkDW3d_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BzUkDW3d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_n1jvd2b7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_wETdD9K6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_f8066dYg, 1, m, &cIf_f8066dYg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Hb8vrOA6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3oNUCkoH, 0, m, &cIf_3oNUCkoH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YEAOhoQJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3oNUCkoH, 1, m, &cIf_3oNUCkoH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_t6juYxRA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_AiFyovRL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_x6VMogW7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_AiFyovRL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_ghBxKIbX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_W6OtMRgL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_q45HAmwB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_vaBcKs6N_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_BJMKsfbq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_xdZzH7RZ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_xdZzH7RZ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_vkKikaUA, 1, m, &cDelay_vkKikaUA_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_or83Jk40_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_vkKikaUA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_vkKikaUA, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ghBxKIbX, 0, m, &cIf_ghBxKIbX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xdZzH7RZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_vkKikaUA, 0, m, &cDelay_vkKikaUA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_or83Jk40_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_vkKikaUA, 0, m, &cDelay_vkKikaUA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_L0gQqAcM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kiwPXI5R_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Q9YmMJ38_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OJ1xdT9e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZuKEsZXD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QISMnKfJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QISMnKfJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_BJMKsfbq_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ZuKEsZXD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ghBxKIbX, 1, m, &cIf_ghBxKIbX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kiwPXI5R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_q45HAmwB, 1, m, &cIf_q45HAmwB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Q9YmMJ38_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_q45HAmwB, 0, m, &cIf_q45HAmwB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_vaBcKs6N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZOv2MMg6, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_W6OtMRgL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZOv2MMg6, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_kt2Xobqv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_S7SrKL0r_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_f6u75NcD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_rhwAlP32_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_azDRXPZg_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_inivuldh_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_inivuldh_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_tq40xhYQ, 1, m, &cDelay_tq40xhYQ_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6R3X3WwG_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_tq40xhYQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_tq40xhYQ, m);
  cIf_onMessage(_c, &Context(_c)->cIf_kt2Xobqv, 0, m, &cIf_kt2Xobqv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_inivuldh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_tq40xhYQ, 0, m, &cDelay_tq40xhYQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6R3X3WwG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_tq40xhYQ, 0, m, &cDelay_tq40xhYQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_WBHJfbZo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0wuadGOY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QL8dHe4O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_g6sDCf32_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cPjYgnX7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_r0wyt3eu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cPjYgnX7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kt2Xobqv, 1, m, &cIf_kt2Xobqv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_r0wyt3eu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_azDRXPZg_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_QL8dHe4O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_f6u75NcD, 0, m, &cIf_f6u75NcD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0wuadGOY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_f6u75NcD, 1, m, &cIf_f6u75NcD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rhwAlP32_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eXWrgpTt, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_S7SrKL0r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eXWrgpTt, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_RKuilNft_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_Da7M0wtO_sendMessage(_c, 0, m);
  cMsg_CUemjNkx_sendMessage(_c, 0, m);
  cMsg_yHkLu5V4_sendMessage(_c, 0, m);
  cMsg_9OVp1uIT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_GA8cZqt2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_Da7M0wtO_sendMessage(_c, 0, m);
  cMsg_HKzP2EPD_sendMessage(_c, 0, m);
  cMsg_uDUwZAfd_sendMessage(_c, 0, m);
  cMsg_rtRalEJY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_a394AbOK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_n8wqBXEx_sendMessage(_c, 0, m);
  cMsg_HKzP2EPD_sendMessage(_c, 0, m);
  cMsg_9OVp1uIT_sendMessage(_c, 0, m);
  cMsg_Q6waZub3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_LdZ3K04M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_n8wqBXEx_sendMessage(_c, 0, m);
  cMsg_VY8CcQyG_sendMessage(_c, 0, m);
  cMsg_yHkLu5V4_sendMessage(_c, 0, m);
  cMsg_vpMESVzu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_v7rxfADD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_WjiQLqSQ_sendMessage(_c, 0, m);
  cMsg_rtRalEJY_sendMessage(_c, 0, m);
  cMsg_iIzkF8mB_sendMessage(_c, 0, m);
  cMsg_yHkLu5V4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_GErlGT3c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_WjiQLqSQ_sendMessage(_c, 0, m);
  cMsg_vpMESVzu_sendMessage(_c, 0, m);
  cMsg_HKzP2EPD_sendMessage(_c, 0, m);
  cMsg_JRUBNyOj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ciq6KBNm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_eWrUeynS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_aZfo8xR8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bvHxPta0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_eWrUeynS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_aZfo8xR8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_W1gPlzFS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_hglaSMYb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_jPxr8SNB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XDGUaPVM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_hglaSMYb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_jPxr8SNB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0qUNwkus_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2EYTuhmf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_qWoQNZ60_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cOkWmSUO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2EYTuhmf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_qWoQNZ60_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Da7M0wtO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_ciq6KBNm_sendMessage(_c, 0, m);
  cMsg_XDGUaPVM_sendMessage(_c, 0, m);
  cMsg_cOkWmSUO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_n8wqBXEx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_bvHxPta0_sendMessage(_c, 0, m);
  cMsg_W1gPlzFS_sendMessage(_c, 0, m);
  cMsg_cOkWmSUO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_WjiQLqSQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_bvHxPta0_sendMessage(_c, 0, m);
  cMsg_XDGUaPVM_sendMessage(_c, 0, m);
  cMsg_0qUNwkus_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_rvacx284_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_mP8Ne7M1_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_5iTuRMdg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zW5ivGIe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_mP8Ne7M1_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_5iTuRMdg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bLOmxiXo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_tKgs8b4e_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_TfTOQ05i_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ESPY0XN7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_tKgs8b4e_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_TfTOQ05i_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SeePUqDK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_3ss5HrOs_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2l1nrktK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cu5GZJ0H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_3ss5HrOs_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2l1nrktK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HKzP2EPD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_zW5ivGIe_sendMessage(_c, 0, m);
  cMsg_ESPY0XN7_sendMessage(_c, 0, m);
  cMsg_cu5GZJ0H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_CUemjNkx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_zW5ivGIe_sendMessage(_c, 0, m);
  cMsg_bLOmxiXo_sendMessage(_c, 0, m);
  cMsg_SeePUqDK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_VY8CcQyG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_rvacx284_sendMessage(_c, 0, m);
  cMsg_ESPY0XN7_sendMessage(_c, 0, m);
  cMsg_SeePUqDK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_rsV0W83U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_pemh2bg0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_nMAAfNV0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5jQf65v2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_pemh2bg0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_nMAAfNV0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_RnmjWygd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_OJ1xdT9e_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_L0gQqAcM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Z2UYjBx5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_OJ1xdT9e_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_L0gQqAcM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7mhRlqCp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_g6sDCf32_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_WBHJfbZo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_UjAJCCo2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_g6sDCf32_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_WBHJfbZo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_vpMESVzu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_rsV0W83U_sendMessage(_c, 0, m);
  cMsg_Z2UYjBx5_sendMessage(_c, 0, m);
  cMsg_UjAJCCo2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_rtRalEJY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_5jQf65v2_sendMessage(_c, 0, m);
  cMsg_RnmjWygd_sendMessage(_c, 0, m);
  cMsg_UjAJCCo2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_9OVp1uIT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_5jQf65v2_sendMessage(_c, 0, m);
  cMsg_Z2UYjBx5_sendMessage(_c, 0, m);
  cMsg_7mhRlqCp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_fr9lMaUh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fjQAZNGg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xG5UJ87T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_v324ZzzE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fjQAZNGg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xG5UJ87T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bOaP5OXV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fP6nO42t_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_AeIo6ShK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_d3lPDYKM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fP6nO42t_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_AeIo6ShK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_M2UVYLkM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_xSyR2hgj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_hy2zH4WF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_yZ3OC61L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_xSyR2hgj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_hy2zH4WF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_yHkLu5V4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_v324ZzzE_sendMessage(_c, 0, m);
  cMsg_d3lPDYKM_sendMessage(_c, 0, m);
  cMsg_yZ3OC61L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_uDUwZAfd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_v324ZzzE_sendMessage(_c, 0, m);
  cMsg_bOaP5OXV_sendMessage(_c, 0, m);
  cMsg_M2UVYLkM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_JRUBNyOj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_fr9lMaUh_sendMessage(_c, 0, m);
  cMsg_bOaP5OXV_sendMessage(_c, 0, m);
  cMsg_yZ3OC61L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_iIzkF8mB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_rvacx284_sendMessage(_c, 0, m);
  cMsg_bLOmxiXo_sendMessage(_c, 0, m);
  cMsg_cu5GZJ0H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Q6waZub3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_fr9lMaUh_sendMessage(_c, 0, m);
  cMsg_d3lPDYKM_sendMessage(_c, 0, m);
  cMsg_M2UVYLkM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_NTFz56sC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LQsSPqmA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_TRg7FKh6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_BZHNWR8m, 0, m, &cSlice_BZHNWR8m_sendMessage);
      break;
    }
    default: {
      cSwitchcase_sZwjsu3u_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_BZHNWR8m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_LitltiTl_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_LitltiTl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_GcjXpOrx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_LitltiTl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_LitltiTl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Qiq47Gw9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_QlB7Lmm1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ctF1Kf0M, 0, m, &cSlice_ctF1Kf0M_sendMessage);
      break;
    }
    default: {
      cSwitchcase_0tzCOZp8_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_ctF1Kf0M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_kLolDGYe_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_kLolDGYe_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_3bIYDQfC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_kLolDGYe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_kLolDGYe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_LT9lWEcg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_0tzCOZp8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_AVGc02Gd, 0, m, &cSlice_AVGc02Gd_sendMessage);
      break;
    }
    default: {
      cSwitchcase_TRg7FKh6_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_AVGc02Gd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_MrZtVEnt_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_MrZtVEnt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_v5k5IrVW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_MrZtVEnt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_MrZtVEnt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_TJ2oI67R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_sZwjsu3u_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_8t5jz6DQ, 0, m, &cSlice_8t5jz6DQ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_UOMvq4O8_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_8t5jz6DQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_LgngLC9x_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_LgngLC9x_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_iHZgW33S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_LgngLC9x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_LgngLC9x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_YiEHmaPo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_UOMvq4O8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_pKha3PPk, 0, m, &cSlice_pKha3PPk_sendMessage);
      break;
    }
    default: {
      cSwitchcase_XuE2srbw_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_pKha3PPk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_WKfGO0hI_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_WKfGO0hI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Gqa0s6mI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_WKfGO0hI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_WKfGO0hI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Cyp69SMj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_SeN40Z4j_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ACeXVzWi_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ACeXVzWi_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_pSK3syJj, 1, m, &cDelay_pSK3syJj_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kxK0n4Wc_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_pSK3syJj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_pSK3syJj, m);
  cMsg_S9LXbfSJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ACeXVzWi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_pSK3syJj, 0, m, &cDelay_pSK3syJj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kxK0n4Wc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_pSK3syJj, 0, m, &cDelay_pSK3syJj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_pjkvrD6N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PO1rQzh3, HV_BINOP_SUBTRACT, 0, m, &cBinop_PO1rQzh3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_Z5Aga7Nl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_yVfAjJza_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_jaJHSg3l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_yVfAjJza_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_Uja3rtBC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pjkvrD6N, 0, m, &cVar_pjkvrD6N_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_9YT4CYSZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qarL8y5b_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HhuuojqG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zePPbdin_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PO1rQzh3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FLcTQr7m_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_FLcTQr7m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_shq9jSWQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_shq9jSWQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_jQZ71SLC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_YhWiKH4M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_knSv9uCM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JZ4rEsqu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JZ4rEsqu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_132JI8oa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_knSv9uCM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Z5Aga7Nl, 1, m, &cIf_Z5Aga7Nl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_YUh0Pt1D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jaJHSg3l, 1, m, &cIf_jaJHSg3l_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_132JI8oa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_Z5Aga7Nl, 0, m, &cIf_Z5Aga7Nl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jQZ71SLC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jaJHSg3l, 0, m, &cIf_jaJHSg3l_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qarL8y5b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_HhuuojqG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PO1rQzh3, HV_BINOP_SUBTRACT, 1, m, &cBinop_PO1rQzh3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zePPbdin_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pjkvrD6N, 0, m, &cVar_pjkvrD6N_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_yVfAjJza_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eDdP3Ui4, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_XuE2srbw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Xa07SF7e, 0, m, &cSlice_Xa07SF7e_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_Xa07SF7e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_sFgsbhyg_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_sFgsbhyg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_qcj7rJBd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_sFgsbhyg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_sFgsbhyg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_gqctyWap_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_hynHNc0H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PFVF3uxl, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_YqphoNTl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4TRTDGaC, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_WqamFWsC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ajYI5RK4, 0, m, &cVar_ajYI5RK4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LQsSPqmA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Fqqz2Xvr, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_vth1XmYc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MrzLFxw3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_3EVnw8Hr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_SeN40Z4j_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_S9LXbfSJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8JJbkCBp, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_MrzLFxw3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8JJbkCBp, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_bI4tUomy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_YddXUQNt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_YddXUQNt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_72DdUKPt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_72DdUKPt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OpwcPXeP, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_W06qEWHs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fuSaTSHp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_78HjdcfH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_22IDR20B_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_0rI97Ont_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ElOKWLCn_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BFIrHQMP_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rUmAmqUq_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rbON6wLJ_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IelCNOGa_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PifDLoIo_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_ElOKWLCn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_E0x4UHzI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_BFIrHQMP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kPsQHqe4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_rUmAmqUq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_U3AratBx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_rbON6wLJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Bs5UHWcH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_IelCNOGa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iz5dWCwY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_PifDLoIo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sKI4w3qL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_x3K0gJuT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_u7F1Hl0W_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_leXefD4D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_A4Tlucct_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_EopGLNsT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_NuNhUuVP_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_NuNhUuVP_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_DfEZuY0o, 1, m, &cDelay_DfEZuY0o_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MLCCgSmd_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_DfEZuY0o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_DfEZuY0o, m);
  cIf_onMessage(_c, &Context(_c)->cIf_x3K0gJuT, 0, m, &cIf_x3K0gJuT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NuNhUuVP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_DfEZuY0o, 0, m, &cDelay_DfEZuY0o_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MLCCgSmd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_DfEZuY0o, 0, m, &cDelay_DfEZuY0o_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_V4FgeEfT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eGp5KukD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fMibPghk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kp8U2aS2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_swb1AMxb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EzDXbcnI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_EzDXbcnI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_EopGLNsT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_swb1AMxb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_x3K0gJuT, 1, m, &cIf_x3K0gJuT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eGp5KukD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_leXefD4D, 1, m, &cIf_leXefD4D_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fMibPghk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_leXefD4D, 0, m, &cIf_leXefD4D_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_A4Tlucct_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_K2mW0Yy1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_u7F1Hl0W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_K2mW0Yy1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Azx682HF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_KYttWMcO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_H87SGFLU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_TR8eD3lx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_IqJZy95Y_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_5hiKnjeW_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_5hiKnjeW_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ehQL40Tz, 1, m, &cDelay_ehQL40Tz_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jA5vgUYN_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_ehQL40Tz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ehQL40Tz, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Azx682HF, 0, m, &cIf_Azx682HF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5hiKnjeW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ehQL40Tz, 0, m, &cDelay_ehQL40Tz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jA5vgUYN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ehQL40Tz, 0, m, &cDelay_ehQL40Tz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gbeHtTaG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WYzlSyTP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LbF37DzI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HDynbu8F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nCw77lPF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JmPNWdgF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JmPNWdgF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_IqJZy95Y_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_nCw77lPF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Azx682HF, 1, m, &cIf_Azx682HF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LbF37DzI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_H87SGFLU, 0, m, &cIf_H87SGFLU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WYzlSyTP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_H87SGFLU, 1, m, &cIf_H87SGFLU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TR8eD3lx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_32XgHKmY, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_KYttWMcO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_32XgHKmY, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_ZObCGtak_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_SuztfM61_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_eNx09xwL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Zb3FwIRJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Utckbmzh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_t9YbPRhb_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_t9YbPRhb_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_wtowDd5K, 1, m, &cDelay_wtowDd5K_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nGX3Kqlk_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_wtowDd5K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wtowDd5K, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ZObCGtak, 0, m, &cIf_ZObCGtak_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_t9YbPRhb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_wtowDd5K, 0, m, &cDelay_wtowDd5K_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nGX3Kqlk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_wtowDd5K, 0, m, &cDelay_wtowDd5K_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_k1WTm26G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_t4zJrLF0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_acTyqWlD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_m9a2DTmp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_m1W85NgP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1D8X6Hi9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1D8X6Hi9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Utckbmzh_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_m1W85NgP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZObCGtak, 1, m, &cIf_ZObCGtak_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_acTyqWlD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eNx09xwL, 0, m, &cIf_eNx09xwL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_t4zJrLF0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eNx09xwL, 1, m, &cIf_eNx09xwL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Zb3FwIRJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_E2cG6c6O, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_SuztfM61_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_E2cG6c6O, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_vf9rYztg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_MUwU1tvK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_J0Exyu4m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_LY4Lzf5l_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_lZ8WtByN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_RCdSTMft_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_RCdSTMft_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_oyUKfyTW, 1, m, &cDelay_oyUKfyTW_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2x6joc4P_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_oyUKfyTW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_oyUKfyTW, m);
  cIf_onMessage(_c, &Context(_c)->cIf_vf9rYztg, 0, m, &cIf_vf9rYztg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_RCdSTMft_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_oyUKfyTW, 0, m, &cDelay_oyUKfyTW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2x6joc4P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_oyUKfyTW, 0, m, &cDelay_oyUKfyTW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5iqn74bH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PtcboL3c_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RTrvnU8n_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9jZyahZm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jZeZpens_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iPmq0gwv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iPmq0gwv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_lZ8WtByN_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_jZeZpens_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vf9rYztg, 1, m, &cIf_vf9rYztg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RTrvnU8n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_J0Exyu4m, 0, m, &cIf_J0Exyu4m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PtcboL3c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_J0Exyu4m, 1, m, &cIf_J0Exyu4m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LY4Lzf5l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ujwkCfHM, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_MUwU1tvK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ujwkCfHM, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_5EgSCZaM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_gCEnPOSn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_VySf7gpL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_xa9OwqC3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_UmoPeiRJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_AHqYGzqd_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_AHqYGzqd_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_5IbMyO8v, 1, m, &cDelay_5IbMyO8v_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WZACRP9I_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_5IbMyO8v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_5IbMyO8v, m);
  cIf_onMessage(_c, &Context(_c)->cIf_5EgSCZaM, 0, m, &cIf_5EgSCZaM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_AHqYGzqd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_5IbMyO8v, 0, m, &cDelay_5IbMyO8v_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WZACRP9I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_5IbMyO8v, 0, m, &cDelay_5IbMyO8v_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_SDgnQASs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JH50VEAa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4pITjhjW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xMupECp2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JK4xa9xV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GtcCbsQM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GtcCbsQM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_UmoPeiRJ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_JK4xa9xV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5EgSCZaM, 1, m, &cIf_5EgSCZaM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JH50VEAa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VySf7gpL, 1, m, &cIf_VySf7gpL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4pITjhjW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VySf7gpL, 0, m, &cIf_VySf7gpL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xa9OwqC3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Yn97wxJX, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_gCEnPOSn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Yn97wxJX, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_e9cNXnFj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_QI6kHthF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_euRv9WTZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_2s3HzA6g_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_hCtASQ2X_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_WdQfFWxM_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_WdQfFWxM_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_7tzs8NNY, 1, m, &cDelay_7tzs8NNY_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uWPkQAaO_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_7tzs8NNY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_7tzs8NNY, m);
  cIf_onMessage(_c, &Context(_c)->cIf_e9cNXnFj, 0, m, &cIf_e9cNXnFj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WdQfFWxM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_7tzs8NNY, 0, m, &cDelay_7tzs8NNY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uWPkQAaO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_7tzs8NNY, 0, m, &cDelay_7tzs8NNY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xga45lxq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EzwwDN7F_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aswK2Lyk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zOTtoqO9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_t0WbpemV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DnguUgP9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DnguUgP9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_hCtASQ2X_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_t0WbpemV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_e9cNXnFj, 1, m, &cIf_e9cNXnFj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_EzwwDN7F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_euRv9WTZ, 1, m, &cIf_euRv9WTZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aswK2Lyk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_euRv9WTZ, 0, m, &cIf_euRv9WTZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2s3HzA6g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_W2hipR6s, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_QI6kHthF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_W2hipR6s, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_4BXif1Xo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_wujr1xYp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_sCqhh2Ak_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_hzD1aorI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_nhEON6Hu_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_bB0VGbQg_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_bB0VGbQg_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ZrFRQUAW, 1, m, &cDelay_ZrFRQUAW_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EJWA227Z_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_ZrFRQUAW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ZrFRQUAW, m);
  cIf_onMessage(_c, &Context(_c)->cIf_4BXif1Xo, 0, m, &cIf_4BXif1Xo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bB0VGbQg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZrFRQUAW, 0, m, &cDelay_ZrFRQUAW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_EJWA227Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZrFRQUAW, 0, m, &cDelay_ZrFRQUAW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZjPvCJrG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dOPrMiUU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_U6hf5Q7O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_eiAj6Qjd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5MpSlpIM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_f7tot71Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5MpSlpIM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4BXif1Xo, 1, m, &cIf_4BXif1Xo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_f7tot71Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_nhEON6Hu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_dOPrMiUU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sCqhh2Ak, 1, m, &cIf_sCqhh2Ak_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_U6hf5Q7O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sCqhh2Ak, 0, m, &cIf_sCqhh2Ak_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hzD1aorI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oxW5DE8f, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_wujr1xYp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oxW5DE8f, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_73ZfUKSo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_a2FHjsAy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_29HigVO9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_tKuE0PdF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_COEUjUud_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_xlomUYUG_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_xlomUYUG_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_21HEftWd, 1, m, &cDelay_21HEftWd_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_85YuNv7o_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_21HEftWd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_21HEftWd, m);
  cIf_onMessage(_c, &Context(_c)->cIf_73ZfUKSo, 0, m, &cIf_73ZfUKSo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xlomUYUG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_21HEftWd, 0, m, &cDelay_21HEftWd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_85YuNv7o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_21HEftWd, 0, m, &cDelay_21HEftWd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_iwnMy6N4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YALLjQmp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BAdXRFu3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PiGkbRny_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YgtKY90P_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_c7rsA1Fg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_c7rsA1Fg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_COEUjUud_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_YgtKY90P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_73ZfUKSo, 1, m, &cIf_73ZfUKSo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YALLjQmp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_29HigVO9, 1, m, &cIf_29HigVO9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BAdXRFu3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_29HigVO9, 0, m, &cIf_29HigVO9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_tKuE0PdF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_D7JQgWmw, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_a2FHjsAy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_D7JQgWmw, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_bZUD0Rt0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_XPSwf1Ad_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_AgsfungG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_bs2uXyJo_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_53Nk1Lsv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Hsl0XGai_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Hsl0XGai_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_NeTSitak, 1, m, &cDelay_NeTSitak_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SrVSr0WV_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_NeTSitak_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_NeTSitak, m);
  cIf_onMessage(_c, &Context(_c)->cIf_bZUD0Rt0, 0, m, &cIf_bZUD0Rt0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Hsl0XGai_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_NeTSitak, 0, m, &cDelay_NeTSitak_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SrVSr0WV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_NeTSitak, 0, m, &cDelay_NeTSitak_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gvD0h0Gp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Mkf2qwaS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CzPHWntv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fxwtFkz6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vABytcvS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mYUVCjPX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vABytcvS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bZUD0Rt0, 1, m, &cIf_bZUD0Rt0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mYUVCjPX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_53Nk1Lsv_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Mkf2qwaS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AgsfungG, 1, m, &cIf_AgsfungG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CzPHWntv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AgsfungG, 0, m, &cIf_AgsfungG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bs2uXyJo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GO7UIQlw, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_XPSwf1Ad_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GO7UIQlw, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_NkAsNV0I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_hKf6ZRPf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_7wH3u2lh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Du6QYYfG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_0lpJtXhO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_9GQBEJj3_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_9GQBEJj3_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_4cXzBp5w, 1, m, &cDelay_4cXzBp5w_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FiD0moE0_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_4cXzBp5w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_4cXzBp5w, m);
  cIf_onMessage(_c, &Context(_c)->cIf_NkAsNV0I, 0, m, &cIf_NkAsNV0I_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9GQBEJj3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_4cXzBp5w, 0, m, &cDelay_4cXzBp5w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FiD0moE0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_4cXzBp5w, 0, m, &cDelay_4cXzBp5w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_cc1M9tPr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5tb7kbZo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tH0mS6U1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_L1w8cNH5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pZHUdXQg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cK1W1yPC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pZHUdXQg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NkAsNV0I, 1, m, &cIf_NkAsNV0I_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cK1W1yPC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_0lpJtXhO_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_tH0mS6U1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7wH3u2lh, 0, m, &cIf_7wH3u2lh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5tb7kbZo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7wH3u2lh, 1, m, &cIf_7wH3u2lh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Du6QYYfG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mERTw4es, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_hKf6ZRPf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mERTw4es, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_2U6bJr6A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_05D3bAZv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_T2LcHl9J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_jqRGEJTG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_0Kv77MEK_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_I8G0ro9T_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_I8G0ro9T_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_9qDz9vwx, 1, m, &cDelay_9qDz9vwx_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ClLjkXkK_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_9qDz9vwx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_9qDz9vwx, m);
  cIf_onMessage(_c, &Context(_c)->cIf_2U6bJr6A, 0, m, &cIf_2U6bJr6A_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_I8G0ro9T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_9qDz9vwx, 0, m, &cDelay_9qDz9vwx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ClLjkXkK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_9qDz9vwx, 0, m, &cDelay_9qDz9vwx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_YPaoTQ5y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NKe6lcTZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gr1EKO2C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_iqiARxof_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eLq6nxtS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_biNZ5x66_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eLq6nxtS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2U6bJr6A, 1, m, &cIf_2U6bJr6A_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_biNZ5x66_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_0Kv77MEK_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_gr1EKO2C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_T2LcHl9J, 0, m, &cIf_T2LcHl9J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NKe6lcTZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_T2LcHl9J, 1, m, &cIf_T2LcHl9J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jqRGEJTG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_aW5zsayP, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_05D3bAZv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_aW5zsayP, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_WA0QixJw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_vBmGiyUG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_KBImS6Gf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_FP03awTT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_yLQ6steu_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_OxRJrTrQ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_OxRJrTrQ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_E0A3G2nT, 1, m, &cDelay_E0A3G2nT_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6hLXTmJf_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_E0A3G2nT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_E0A3G2nT, m);
  cIf_onMessage(_c, &Context(_c)->cIf_WA0QixJw, 0, m, &cIf_WA0QixJw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OxRJrTrQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_E0A3G2nT, 0, m, &cDelay_E0A3G2nT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6hLXTmJf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_E0A3G2nT, 0, m, &cDelay_E0A3G2nT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jLvZfaJT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_T392l9of_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vcuRR2pr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6c8bb9O0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_D617y5xK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SQBnLfzI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SQBnLfzI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_yLQ6steu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_D617y5xK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WA0QixJw, 1, m, &cIf_WA0QixJw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vcuRR2pr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KBImS6Gf, 0, m, &cIf_KBImS6Gf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_T392l9of_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KBImS6Gf, 1, m, &cIf_KBImS6Gf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_FP03awTT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bl4zBN47, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_vBmGiyUG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bl4zBN47, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_E0x4UHzI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_2qaj5EW8_sendMessage(_c, 0, m);
  cMsg_F4gs9v2N_sendMessage(_c, 0, m);
  cMsg_jvCxtQxd_sendMessage(_c, 0, m);
  cMsg_VxacNoRW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_kPsQHqe4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_2qaj5EW8_sendMessage(_c, 0, m);
  cMsg_8hSBuypR_sendMessage(_c, 0, m);
  cMsg_AWyiadNe_sendMessage(_c, 0, m);
  cMsg_wgMHO0qq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_U3AratBx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_3WtnxDFT_sendMessage(_c, 0, m);
  cMsg_8hSBuypR_sendMessage(_c, 0, m);
  cMsg_VxacNoRW_sendMessage(_c, 0, m);
  cMsg_9qdeDNJc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Bs5UHWcH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_3WtnxDFT_sendMessage(_c, 0, m);
  cMsg_fZht8yIa_sendMessage(_c, 0, m);
  cMsg_jvCxtQxd_sendMessage(_c, 0, m);
  cMsg_jJksPhBi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_iz5dWCwY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_LWkReclx_sendMessage(_c, 0, m);
  cMsg_wgMHO0qq_sendMessage(_c, 0, m);
  cMsg_uhLPr6Oh_sendMessage(_c, 0, m);
  cMsg_jvCxtQxd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_sKI4w3qL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_LWkReclx_sendMessage(_c, 0, m);
  cMsg_jJksPhBi_sendMessage(_c, 0, m);
  cMsg_8hSBuypR_sendMessage(_c, 0, m);
  cMsg_LKJkeFfs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_YGzEm6Xx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_kp8U2aS2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_V4FgeEfT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bGfklzi6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_kp8U2aS2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_V4FgeEfT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_njHUkrpX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_HDynbu8F_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_gbeHtTaG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_obhbNkpe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_HDynbu8F_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_gbeHtTaG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rxyniYd5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_m9a2DTmp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_k1WTm26G_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rVFQ0SfL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_m9a2DTmp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_k1WTm26G_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2qaj5EW8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_YGzEm6Xx_sendMessage(_c, 0, m);
  cMsg_obhbNkpe_sendMessage(_c, 0, m);
  cMsg_rVFQ0SfL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_3WtnxDFT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_bGfklzi6_sendMessage(_c, 0, m);
  cMsg_njHUkrpX_sendMessage(_c, 0, m);
  cMsg_rVFQ0SfL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_LWkReclx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_bGfklzi6_sendMessage(_c, 0, m);
  cMsg_obhbNkpe_sendMessage(_c, 0, m);
  cMsg_rxyniYd5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_kyv3Y2XE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_9jZyahZm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_5iqn74bH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2siSoq0D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_9jZyahZm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_5iqn74bH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GJCHcLej_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_xMupECp2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_SDgnQASs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_n7ZKzuaj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_xMupECp2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_SDgnQASs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_K1BqA8sI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_zOTtoqO9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xga45lxq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_dteA3COa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_zOTtoqO9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xga45lxq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8hSBuypR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_2siSoq0D_sendMessage(_c, 0, m);
  cMsg_n7ZKzuaj_sendMessage(_c, 0, m);
  cMsg_dteA3COa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_F4gs9v2N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_2siSoq0D_sendMessage(_c, 0, m);
  cMsg_GJCHcLej_sendMessage(_c, 0, m);
  cMsg_K1BqA8sI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_fZht8yIa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_kyv3Y2XE_sendMessage(_c, 0, m);
  cMsg_n7ZKzuaj_sendMessage(_c, 0, m);
  cMsg_K1BqA8sI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_YJqpFnUV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_L1w8cNH5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_cc1M9tPr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fWO2NjEU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_L1w8cNH5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_cc1M9tPr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8iH7EZSo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_iqiARxof_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_YPaoTQ5y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fpOuDEyi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_iqiARxof_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_YPaoTQ5y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_m8NMHNE2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_6c8bb9O0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_jLvZfaJT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_eLGjj6b4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_6c8bb9O0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_jLvZfaJT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jJksPhBi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_YJqpFnUV_sendMessage(_c, 0, m);
  cMsg_fpOuDEyi_sendMessage(_c, 0, m);
  cMsg_eLGjj6b4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_wgMHO0qq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_fWO2NjEU_sendMessage(_c, 0, m);
  cMsg_8iH7EZSo_sendMessage(_c, 0, m);
  cMsg_eLGjj6b4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_VxacNoRW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_fWO2NjEU_sendMessage(_c, 0, m);
  cMsg_fpOuDEyi_sendMessage(_c, 0, m);
  cMsg_m8NMHNE2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_6TEfzGTN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_eiAj6Qjd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ZjPvCJrG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_FlMPIdg7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_eiAj6Qjd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ZjPvCJrG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_856iEkmB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_PiGkbRny_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_iwnMy6N4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mHumk7G5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_PiGkbRny_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_iwnMy6N4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GXhnLLOW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fxwtFkz6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_gvD0h0Gp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MxwSxayn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fxwtFkz6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_gvD0h0Gp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jvCxtQxd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_FlMPIdg7_sendMessage(_c, 0, m);
  cMsg_mHumk7G5_sendMessage(_c, 0, m);
  cMsg_MxwSxayn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_AWyiadNe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_FlMPIdg7_sendMessage(_c, 0, m);
  cMsg_856iEkmB_sendMessage(_c, 0, m);
  cMsg_GXhnLLOW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_LKJkeFfs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_6TEfzGTN_sendMessage(_c, 0, m);
  cMsg_856iEkmB_sendMessage(_c, 0, m);
  cMsg_MxwSxayn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_uhLPr6Oh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_kyv3Y2XE_sendMessage(_c, 0, m);
  cMsg_GJCHcLej_sendMessage(_c, 0, m);
  cMsg_dteA3COa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_9qdeDNJc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_6TEfzGTN_sendMessage(_c, 0, m);
  cMsg_mHumk7G5_sendMessage(_c, 0, m);
  cMsg_GXhnLLOW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_3ZTpcMVi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UXOTdHtb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_5CYWjldz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_OSOkkV3n, 0, m, &cSlice_OSOkkV3n_sendMessage);
      break;
    }
    default: {
      cSwitchcase_uRoyV0ch_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_OSOkkV3n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_nhvXndzS_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_nhvXndzS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_IAXDoqcv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_nhvXndzS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_nhvXndzS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_DPFxHZcx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_O2ZyY2Nj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_otad7vWp, 0, m, &cSlice_otad7vWp_sendMessage);
      break;
    }
    default: {
      cSwitchcase_SZPALlUj_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_otad7vWp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_FHgxHpnM_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_FHgxHpnM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_qYw5Nnzz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_FHgxHpnM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_FHgxHpnM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_xcYFfEzd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_SZPALlUj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_S3sZAdoT, 0, m, &cSlice_S3sZAdoT_sendMessage);
      break;
    }
    default: {
      cSwitchcase_5CYWjldz_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_S3sZAdoT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_z5kOz878_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_z5kOz878_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_JRyrMC2q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_z5kOz878_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_z5kOz878_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_08skz0q5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_uRoyV0ch_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_OMqpihDO, 0, m, &cSlice_OMqpihDO_sendMessage);
      break;
    }
    default: {
      cSwitchcase_eFSGBt7Y_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_OMqpihDO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_zpq9kSus_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_zpq9kSus_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Jy9Wtnoi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_zpq9kSus_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_zpq9kSus_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_OGlqaYd9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_eFSGBt7Y_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_pHMFf44b, 0, m, &cSlice_pHMFf44b_sendMessage);
      break;
    }
    default: {
      cSwitchcase_7E9cd0HT_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_pHMFf44b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_LBVaPiZJ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_LBVaPiZJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_YWtgzD15_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_LBVaPiZJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_LBVaPiZJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_3HF70q1F_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_VF40jMqS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_um1Odf1i_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_um1Odf1i_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_laObv0Vi, 1, m, &cDelay_laObv0Vi_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GmSV5oaY_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_laObv0Vi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_laObv0Vi, m);
  cMsg_VlhNJi5j_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_um1Odf1i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_laObv0Vi, 0, m, &cDelay_laObv0Vi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GmSV5oaY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_laObv0Vi, 0, m, &cDelay_laObv0Vi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_9E5Q3hCP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2G1Oa2WT, HV_BINOP_SUBTRACT, 0, m, &cBinop_2G1Oa2WT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_WK2JpHLc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_77hcSNq0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_5lbbQkPA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_77hcSNq0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_i5GMNo5M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9E5Q3hCP, 0, m, &cVar_9E5Q3hCP_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_nQo2j2mt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VCV5mjw9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GIamkymS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rh5fNcb6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2G1Oa2WT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ray7u0b2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Ray7u0b2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_PoLxXW6b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PoLxXW6b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_zu7gcKUj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_lqJSk0Va_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4eSqYIQL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hc5uzkBp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4eSqYIQL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WK2JpHLc, 1, m, &cIf_WK2JpHLc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hc5uzkBp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2Ab8Oh14_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_vg9t8Hsc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5lbbQkPA, 1, m, &cIf_5lbbQkPA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2Ab8Oh14_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_WK2JpHLc, 0, m, &cIf_WK2JpHLc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zu7gcKUj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5lbbQkPA, 0, m, &cIf_5lbbQkPA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rh5fNcb6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9E5Q3hCP, 0, m, &cVar_9E5Q3hCP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VCV5mjw9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_GIamkymS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2G1Oa2WT, HV_BINOP_SUBTRACT, 1, m, &cBinop_2G1Oa2WT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_77hcSNq0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LvVDuBiv, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_7E9cd0HT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_dLAolreu, 0, m, &cSlice_dLAolreu_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_dLAolreu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_5p5OTnYu_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_5p5OTnYu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_QwkJng3y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_5p5OTnYu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_5p5OTnYu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_4wjopuE6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_fuSaTSHp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cTf1YjyK, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_22IDR20B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_efGcVWp6, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_ySYdkyhe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_78HjdcfH, 0, m, &cVar_78HjdcfH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_UXOTdHtb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Kj529jJK, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ORWLjfSt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_VF40jMqS_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_XERsYdTV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qrgTEDYj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_VlhNJi5j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_X6A4In9K, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_qrgTEDYj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_X6A4In9K, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_80wtPJeH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_YC8LUtxC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_YC8LUtxC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LokCCny8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_LokCCny8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8Q1IobaF, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_TQynuUxf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cY2frkBr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_ag59sBKb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wW8wz26k_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_YdPIfgoO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IBAxtpDw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_GnRSOKup_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_NjS3mhDX_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_FzxVxfgI_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_363w0UvM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_l35gwMw4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_NjS3mhDX_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_FzxVxfgI_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_363w0UvM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_ZQLpevCN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7Jfx6kVS, 0, m, &cVar_7Jfx6kVS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_yeZDHQg2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_NjS3mhDX_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_FzxVxfgI_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_363w0UvM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_NB0bcgZZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_NjS3mhDX_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_FzxVxfgI_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_363w0UvM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_2ZcH2wq8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_NjS3mhDX_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_FzxVxfgI_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_363w0UvM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_JBDmgtKp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_32mPIaFF, 0, m, &cVar_32mPIaFF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Zk2bCPAB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_kvRmVjGG, 0, m, &cVar_kvRmVjGG_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_2yCKe9az, 0, m, &cVar_2yCKe9az_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_9j99Ghpc, 0, m, &cVar_9j99Ghpc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_y7qpGvyZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_ZQLpevCN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kJ7z6DUa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_6RKw33lT_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_mNWu4f9e_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_yF9xfJKZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_6RKw33lT_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_mNWu4f9e_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Bib9oW1x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_6RKw33lT_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_mNWu4f9e_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_4nEeDL2m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_6RKw33lT_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_mNWu4f9e_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_8HVBAXXD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_6RKw33lT_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_mNWu4f9e_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ojUlhOTz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_Fun23bOA, 0, m, &cVar_Fun23bOA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Za2A9Ddf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_cvHbHbu1, 0, m, &cVar_cvHbHbu1_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_o3KKLi0y, 0, m, &cVar_o3KKLi0y_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_MTv7inTU, 0, m, &cVar_MTv7inTU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_FKldWI31_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_NjS3mhDX_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_FzxVxfgI_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_363w0UvM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_5w9PKCsH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_1gvcfkul_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_zp1IPytk_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_bGRYcfTu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_6ZgrNtE0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_1gvcfkul_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_zp1IPytk_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_bGRYcfTu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_q1Bc3CRe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_F0wdYKvN, 0, m, &cVar_F0wdYKvN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WezEXe2P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_1gvcfkul_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_zp1IPytk_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_bGRYcfTu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_HRCxULDU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_1gvcfkul_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_zp1IPytk_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_bGRYcfTu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_xHMqwC7p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_1gvcfkul_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_zp1IPytk_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_bGRYcfTu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_u9pbQUj3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_3wF0Pmdv, 0, m, &cVar_3wF0Pmdv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lIs1nYny_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_fWpGrJQV, 0, m, &cVar_fWpGrJQV_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_VzKBosDs, 0, m, &cVar_VzKBosDs_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_FPrOgSj7, 0, m, &cVar_FPrOgSj7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_yAEZ5NAK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_q1Bc3CRe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3ANxTvYQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_1gvcfkul_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_zp1IPytk_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_bGRYcfTu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_fFidIty5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_Ree85Zjj_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_QlB7Lmm1_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_O2ZyY2Nj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_t6gZfpn3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_Ree85Zjj_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_QlB7Lmm1_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_O2ZyY2Nj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_dn0KMGsQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XrOkVY1P, 0, m, &cVar_XrOkVY1P_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_RXfKuZ3Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_Ree85Zjj_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_QlB7Lmm1_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_O2ZyY2Nj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_JI4S5NXN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_Ree85Zjj_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_QlB7Lmm1_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_O2ZyY2Nj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_DLt8If60_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_Ree85Zjj_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_QlB7Lmm1_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_O2ZyY2Nj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_YpjCcU3X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_2lkPAudV, 0, m, &cVar_2lkPAudV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mVoQnVaL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_YaEk4EjA, 0, m, &cVar_YaEk4EjA_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_beHC6D9R, 0, m, &cVar_beHC6D9R_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_pGmUEVAf, 0, m, &cVar_pGmUEVAf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rVPdSqGx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_dn0KMGsQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mL3Cj0yW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_Ree85Zjj_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_QlB7Lmm1_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_O2ZyY2Nj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_SK3R5y5E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_TQynuUxf, 0, m, &cVar_TQynuUxf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cY2frkBr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_NjS3mhDX_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_FzxVxfgI_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_363w0UvM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_915RPNk9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_ag59sBKb, 0, m, &cVar_ag59sBKb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wW8wz26k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_1gvcfkul_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_zp1IPytk_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_bGRYcfTu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Jr5dCnvI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_YdPIfgoO, 0, m, &cVar_YdPIfgoO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_IBAxtpDw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_Ree85Zjj_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_QlB7Lmm1_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_O2ZyY2Nj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cReceive_U6hWXIBI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WsKrn2hM_sendMessage(_c, 0, m);
  cMsg_Qv7A7StH_sendMessage(_c, 0, m);
  cMsg_2jHbEu4K_sendMessage(_c, 0, m);
  cMsg_36eWTSDP_sendMessage(_c, 0, m);
  cMsg_5DLDBZ1f_sendMessage(_c, 0, m);
  cMsg_fS2V1A19_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_RxJjPI2z, 0, m, &cVar_RxJjPI2z_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_y9qLVKml, 0, m, &cVar_y9qLVKml_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_N37D4UJl, 0, m, &cVar_N37D4UJl_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_upquHCo0, 0, m, &cVar_upquHCo0_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_yQDk3Mz6, 0, m, &cVar_yQDk3Mz6_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Zb9knsvJ, 0, m, &cVar_Zb9knsvJ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_liKVdMJ5, 0, m, &cVar_liKVdMJ5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ilhCIivW, 0, m, &cVar_ilhCIivW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0O2EmVWg, 0, m, &cVar_0O2EmVWg_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Wt3XN8n0, 0, m, &cVar_Wt3XN8n0_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_PQWoDFsm, 0, m, &cVar_PQWoDFsm_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_rpFWZSET, 0, m, &cVar_rpFWZSET_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_kT3t7Lp8, 0, m, &cVar_kT3t7Lp8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_bS78F0D1, 0, m, &cVar_bS78F0D1_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ZfFa73wI, 0, m, &cVar_ZfFa73wI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0OWC80Ih, 0, m, &cVar_0OWC80Ih_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_C4rwO80C, 0, m, &cVar_C4rwO80C_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_muLLWIrF, 0, m, &cVar_muLLWIrF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_St2dqy6q, 0, m, &cVar_St2dqy6q_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6Igd03oL, 0, m, &cVar_6Igd03oL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_R6hjSGv6, 0, m, &cVar_R6hjSGv6_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_hVLM6RAA, 0, m, &cVar_hVLM6RAA_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_AHwUWgMU, 0, m, &cVar_AHwUWgMU_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_i9EJm2mP, 0, m, &cVar_i9EJm2mP_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_cLWTceW3, 0, m, &cVar_cLWTceW3_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_3TDJBqy8, 0, m, &cVar_3TDJBqy8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_BN7QuS2U, 0, m, &cVar_BN7QuS2U_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ICVtV6kh, 0, m, &cVar_ICVtV6kh_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_65a1NuXo, 0, m, &cVar_65a1NuXo_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_CkEzV85r, 0, m, &cVar_CkEzV85r_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_4NR9La5c, 0, m, &cVar_4NR9La5c_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_RFyIMaCL, 0, m, &cVar_RFyIMaCL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_8njYz1CI, 0, m, &cVar_8njYz1CI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0xBlM5zL, 0, m, &cVar_0xBlM5zL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_sGAr1xaR, 0, m, &cVar_sGAr1xaR_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ransgAHx, 0, m, &cVar_ransgAHx_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_8NbY07DF, 0, m, &cVar_8NbY07DF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_3j0McVlx, 0, m, &cVar_3j0McVlx_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_RY8HOqIe, 0, m, &cVar_RY8HOqIe_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_o1djFV8E, 0, m, &cVar_o1djFV8E_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_MkzEypdd, 0, m, &cVar_MkzEypdd_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_igJnpcI1, 0, m, &cVar_igJnpcI1_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Op1P6H2G, 0, m, &cVar_Op1P6H2G_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_sISJbFDo, 0, m, &cVar_sISJbFDo_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_daVytTZQ, 0, m, &cVar_daVytTZQ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ocYHFT03, 0, m, &cVar_ocYHFT03_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GcjXpOrx, 0, m, &cVar_GcjXpOrx_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_3bIYDQfC, 0, m, &cVar_3bIYDQfC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_v5k5IrVW, 0, m, &cVar_v5k5IrVW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_iHZgW33S, 0, m, &cVar_iHZgW33S_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Gqa0s6mI, 0, m, &cVar_Gqa0s6mI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_qcj7rJBd, 0, m, &cVar_qcj7rJBd_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_IAXDoqcv, 0, m, &cVar_IAXDoqcv_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_qYw5Nnzz, 0, m, &cVar_qYw5Nnzz_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JRyrMC2q, 0, m, &cVar_JRyrMC2q_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Jy9Wtnoi, 0, m, &cVar_Jy9Wtnoi_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_YWtgzD15, 0, m, &cVar_YWtgzD15_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_QwkJng3y, 0, m, &cVar_QwkJng3y_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Guyrg9pv, 0, m, &cVar_Guyrg9pv_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_MUEpMTPQ, 0, m, &cVar_MUEpMTPQ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_eT6dLPOC, 0, m, &cVar_eT6dLPOC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_To6n0WAG_sendMessage);
  cMsg_Za2A9Ddf_sendMessage(_c, 0, m);
  cMsg_ojUlhOTz_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_I51ecPJv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BeanKCbZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_QNgpaDoJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cvHbHbu1, 0, m, &cVar_cvHbHbu1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_doCU1GYt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_o3KKLi0y, 0, m, &cVar_o3KKLi0y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Fap6GwVD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MTv7inTU, 0, m, &cVar_MTv7inTU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Bb8sFIG7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_y9qLVKml, 0, m, &cVar_y9qLVKml_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_2FMrOZW0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Bi6iiFjY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lYXiZWNr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_AO0uA7EH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lOFp85pm_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Dxd8ROY3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YzUVVxuO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ExSIrTpz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_b6x7AZCZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WXedu33J_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yXjCeI3a_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZLqamN98_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YdVx4wgh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_dSid2viX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NtsdZEI9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BMPIKoye_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YAKJ6V8W_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DKBj3IQA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_vYApon8e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_y5gtpmHR, HV_BINOP_MULTIPLY, 0, m, &cBinop_y5gtpmHR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_AznsxMEA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_xCWTkSJw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_RRWpvt8K_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_pCbbjBCn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_soTwuT0r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_ATxnuyN3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Kk78ZmhZ_sendMessage);
  cMsg_YyPgO0hE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_U8o876ZB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_D7ntjWDR, HV_BINOP_MULTIPLY, 0, m, &cBinop_D7ntjWDR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_4OzZx5km_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_MWbwCWgt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_T6xaByfw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zbKvJBzQ, HV_BINOP_MULTIPLY, 1, m, &cBinop_zbKvJBzQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_vuAcTzs4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_gZ34L8yw_sendMessage);
  cMsg_d3idHCjF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_MbShK3Jg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_j1nXY9qV, HV_BINOP_MULTIPLY, 0, m, &cBinop_j1nXY9qV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_qCZ3LnLw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_InC23i0r_sendMessage(_c, 0, m);
  cMsg_1IWfEKZU_sendMessage(_c, 0, m);
  cMsg_oK3TIwXa_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_dDPRE2uh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_h5yQydY7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Zccd2GR2_sendMessage);
  cMsg_xe7MurNZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_f1GQgFBT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yQDk3Mz6, 0, m, &cVar_yQDk3Mz6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_OrBgqcBI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YD90RdvO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mvvSdUVk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_yKCKSDcS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CmuoZJQI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fHTGhf7B_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FuMK0CRB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8y3PA2BG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_IflMUPkz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nSHxesGV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jfv86nq5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gdosaFdc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1nnUCPwN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_gvcO9erG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9zxeTRuC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zNf8aIoK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_duGWxrug_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5LgViJpn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_vhWqxrK7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Qmn1gKH4, HV_BINOP_MULTIPLY, 0, m, &cBinop_Qmn1gKH4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_UhSfu2si_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_xayPXJjL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_PZMaizyq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_bDBGgkyX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_jQGGLyj5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_JWz9yoNO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_zJxDx5ho_sendMessage);
  cMsg_9SP3cA2h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_vIECjzOA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fQU9GOUK, HV_BINOP_MULTIPLY, 0, m, &cBinop_fQU9GOUK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_6KdsW7Jr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_BTYmbXHq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_rWlf5vQr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lXf5AGCg, HV_BINOP_MULTIPLY, 1, m, &cBinop_lXf5AGCg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_UzTjglYL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_6R6IQPyN_sendMessage);
  cMsg_KrIQg34M_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_gnLtuPT4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hEfTzeR8, HV_BINOP_MULTIPLY, 0, m, &cBinop_hEfTzeR8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_6sFcpR4Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RjnCJkgX_sendMessage(_c, 0, m);
  cMsg_8mixVEX3_sendMessage(_c, 0, m);
  cMsg_IsUnVujL_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_aqh5ck1t_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_7AJY4W4C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_QyQgCTJG_sendMessage);
  cMsg_WjuMZUrS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_P82mhwD7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Fun23bOA, 0, m, &cVar_Fun23bOA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_8WJjmUQF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ql3VXeBD, 0, m, &cVar_ql3VXeBD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_50t1Xz8i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_32mPIaFF, 0, m, &cVar_32mPIaFF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_n2Mrx2Kq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kvRmVjGG, 0, m, &cVar_kvRmVjGG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_NbQAwzCd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2yCKe9az, 0, m, &cVar_2yCKe9az_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_ByB7zVJ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9j99Ghpc, 0, m, &cVar_9j99Ghpc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_rusBlF5D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_ZQLpevCN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_RoY7vguA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_GUfDXyDj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_PUNdC6Uf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dyWy1nMu, 0, m, &cVar_dyWy1nMu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_DsaQeoGc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dCQwsTkt, 0, m, &cVar_dCQwsTkt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_4KqSILvi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_xw3OMi1H_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_7qdUOggm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_5rgB0dIr_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YeJI5FJE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EhL4YPh8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_ZlS4WCJh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_gJdquK7H_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_7RyotKV8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_ib5oMwEu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8Pco7q6e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_ij3cSz4B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fQwSNugO, 0, m, &cVar_fQwSNugO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_6kiHIAtu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pffCTxAk, 0, m, &cVar_pffCTxAk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_fudxfYZI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_T6NG8tjR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_RfK2KCgj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ee5RW5Rx_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TuytQeKe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nfNSYGLn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_US12jSWc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7qr7ORWg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_qtR90Amm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_oKGQeHE7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hVY88Nws_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_eWAGIg2L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_2M7OTfXE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_3G5jmUUB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1Wj7EdcT, 0, m, &cVar_1Wj7EdcT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_GwBr1cEL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_orhaUeuv, 0, m, &cVar_orhaUeuv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_NEXuz19N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_O7Wg5Rc5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_2nhWJ6cV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_90RDzwKp_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7PI0WKym_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3ppSYQ1O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_pRGGr1jS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_YjrRuTuc_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_oELMLbl0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_F4QLsFC2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SODjgOjB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_t44ahREf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VoOOqu1O, 0, m, &cVar_VoOOqu1O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_aUNCouzS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KeGyhv4R, 0, m, &cVar_KeGyhv4R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_CunywCnR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_c31lNgcE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_HNXbsGFM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_jUyJmEiP_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yzCEaojy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sRCr4es1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_zgvPvukY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_8mZXiCES_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_vgINHIoR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_AxH5hjcr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xGSFrGcv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_nkm9FP5Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FlhZNHv1, 0, m, &cVar_FlhZNHv1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_PYPmgIOS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3wF0Pmdv, 0, m, &cVar_3wF0Pmdv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_q3LzBSCI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fWpGrJQV, 0, m, &cVar_fWpGrJQV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Zv4VVjXc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VzKBosDs, 0, m, &cVar_VzKBosDs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_QR96lDdv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FPrOgSj7, 0, m, &cVar_FPrOgSj7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_dUn7liFH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_q1Bc3CRe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_zizwtY1l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_PxmB7ZT1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Qiq47Gw9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RwgEjkOv, 0, m, &cVar_RwgEjkOv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_YiEHmaPo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NTFz56sC, 0, m, &cVar_NTFz56sC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_TJ2oI67R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_WqamFWsC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_LT9lWEcg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_mRFAYg93_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vth1XmYc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3EVnw8Hr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Cyp69SMj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_YhWiKH4M_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_YUh0Pt1D_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_gqctyWap_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bI4tUomy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_DPFxHZcx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_W06qEWHs, 0, m, &cVar_W06qEWHs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_OGlqaYd9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3ZTpcMVi, 0, m, &cVar_3ZTpcMVi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_08skz0q5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_ySYdkyhe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_xcYFfEzd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_0rI97Ont_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XERsYdTV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ORWLjfSt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_3HF70q1F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_lqJSk0Va_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_vg9t8Hsc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_4wjopuE6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_80wtPJeH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_LBuDmBGb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Y8115dMv, 0, m, &cVar_Y8115dMv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_HadPXkV1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2lkPAudV, 0, m, &cVar_2lkPAudV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_2bDh0MPN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YaEk4EjA, 0, m, &cVar_YaEk4EjA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_SjaYnRHq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_beHC6D9R, 0, m, &cVar_beHC6D9R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_SYW6z7VX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pGmUEVAf, 0, m, &cVar_pGmUEVAf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Zrp8JO95_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_dn0KMGsQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_xXRoyqup_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TQynuUxf, 0, m, &cVar_TQynuUxf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_LUvkT0de_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ag59sBKb, 0, m, &cVar_ag59sBKb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Ol9S7Dos_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YdPIfgoO, 0, m, &cVar_YdPIfgoO_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_M3NGLR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13, Bf14, Bf15, Bf16, Bf17, Bf18, Bf19, Bf20;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_HjFfRX4M, VOf(Bf0));
    __hv_line_f(&sLine_erOim5mk, VOf(Bf1));
    __hv_line_f(&sLine_gUvg6R0R, VOf(Bf2));
    __hv_line_f(&sLine_oKnTNpOI, VOf(Bf3));
    __hv_line_f(&sLine_gyukU4Rh, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_OPnR55gE, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_TBOA38JT, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_fJoztNsE, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_RcuSswvW, VOf(Bf1));
    __hv_line_f(&sLine_FxeXEShO, VOf(Bf0));
    __hv_line_f(&sLine_MiVFOheF, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_8vBSWwRl, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_zt1p5iHv, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_18VZOHeW, VOf(Bf5));
    __hv_line_f(&sLine_OYGndzVP, VOf(Bf1));
    __hv_line_f(&sLine_G19O8Em8, VOf(Bf2));
    __hv_line_f(&sLine_UdPyVjxh, VOf(Bf4));
    __hv_line_f(&sLine_KakaJMOi, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_9oXISXIY, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_s1aud8vu, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_zMjyTr0u, VOf(Bf6));
    __hv_line_f(&sLine_v1KOckVX, VOf(Bf2));
    __hv_line_f(&sLine_KUugnaus, VOf(Bf1));
    __hv_line_f(&sLine_nSPTYtSm, VOf(Bf5));
    __hv_line_f(&sLine_dbTiADvR, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_OiDDohUf, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_6WlMSqI9, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_In1qSAwl, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_d6TooCRm, VOf(Bf2));
    __hv_line_f(&sLine_enFHH8Ay, VOf(Bf6));
    __hv_line_f(&sLine_mmsOHDsg, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_y2ZniFMu, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_QyaYwI9l, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_a5QhekHt, VOf(Bf8));
    __hv_line_f(&sLine_VUIuS4Kl, VOf(Bf2));
    __hv_line_f(&sLine_kwZsL6j3, VOf(Bf1));
    __hv_line_f(&sLine_B6RArmUb, VOf(Bf7));
    __hv_line_f(&sLine_x982265M, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_h1PjSk1K, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_0O7FLgGr, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_Pvzq1i7E, VIf(Bf0));
    __hv_varwrite_f(&sVarf_UVlLWLd2, VIf(Bf6));
    __hv_varwrite_f(&sVarf_e4IAnbz8, VIf(Bf4));
    __hv_varwrite_f(&sVarf_iElnrNAd, VIf(Bf7));
    __hv_varread_f(&sVarf_uXvfj1A6, VOf(Bf7));
    __hv_varread_f(&sVarf_cz82yjW2, VOf(Bf4));
    __hv_varread_f(&sVarf_WYqbcQYo, VOf(Bf6));
    __hv_varread_f(&sVarf_lg6hUpyh, VOf(Bf0));
    __hv_varread_f(&sVarf_IC61yVjh, VOf(Bf9));
    __hv_varread_f(&sVarf_122RJAsU, VOf(Bf1));
    __hv_line_f(&sLine_mNqHcONZ, VOf(Bf2));
    __hv_line_f(&sLine_LeACA5HU, VOf(Bf8));
    __hv_mul_f(VIf(Bf0), VIf(Bf8), VOf(Bf0));
    __hv_fma_f(VIf(Bf6), VIf(Bf2), VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf9), VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varwrite_f(&sVarf_WYqbcQYo, VIf(Bf7));
    __hv_varwrite_f(&sVarf_IC61yVjh, VIf(Bf4));
    __hv_varread_f(&sVarf_6j3EdCKl, VOf(Bf2));
    __hv_varread_f(&sVarf_kIa2IZfR, VOf(Bf9));
    __hv_varread_f(&sVarf_DchI4b8Q, VOf(Bf1));
    __hv_varread_f(&sVarf_QSj9xJUH, VOf(Bf6));
    __hv_varread_f(&sVarf_mb8GlB6H, VOf(Bf10));
    __hv_varread_f(&sVarf_ZCenT6BT, VOf(Bf11));
    __hv_varread_f(&sVarf_MUGqaw7Z, VOf(Bf12));
    __hv_varwrite_f(&sVarf_tEVugyOd, VIf(Bf7));
    __hv_varread_f(&sVarf_EjwrN4VQ, VOf(Bf13));
    __hv_line_f(&sLine_eyT46bQz, VOf(Bf14));
    __hv_mul_f(VIf(Bf13), VIf(Bf14), VOf(Bf14));
    __hv_varread_f(&sVarf_eY9U4W5M, VOf(Bf15));
    __hv_line_f(&sLine_HL8pyuNd, VOf(Bf16));
    __hv_mul_f(VIf(Bf15), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_zdSwyD4X, VOf(Bf14));
    __hv_line_f(&sLine_U4Bn7H0Q, VOf(Bf17));
    __hv_mul_f(VIf(Bf14), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_varwrite_f(&sVarf_QSj9xJUH, VIf(Bf17));
    __hv_varread_f(&sVarf_tEVugyOd, VOf(Bf17));
    __hv_line_f(&sLine_WXuza0tC, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_ktSmrdrI, VOf(Bf18));
    __hv_mul_f(VIf(Bf14), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_HDXkQlm1, VOf(Bf16));
    __hv_mul_f(VIf(Bf15), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_mb8GlB6H, VIf(Bf16));
    __hv_line_f(&sLine_CVghcKNl, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_bvlrJsRr, VOf(Bf18));
    __hv_mul_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_7gPIUr73, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_ZCenT6BT, VIf(Bf16));
    __hv_line_f(&sLine_VnXXFnXr, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_wfdR3Vg4, VOf(Bf17));
    __hv_mul_f(VIf(Bf15), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_line_f(&sLine_jduQ8tSo, VOf(Bf16));
    __hv_mul_f(VIf(Bf13), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_MUGqaw7Z, VIf(Bf16));
    __hv_varwrite_f(&sVarf_EjwrN4VQ, VIf(Bf2));
    __hv_varwrite_f(&sVarf_eY9U4W5M, VIf(Bf9));
    __hv_varwrite_f(&sVarf_zdSwyD4X, VIf(Bf1));
    sEnv_process(this, &sEnv_amdktgx2, VIf(Bf6), &sEnv_amdktgx2_sendMessage);
    sEnv_process(this, &sEnv_uvsNytTE, VIf(Bf7), &sEnv_uvsNytTE_sendMessage);
    __hv_line_f(&sLine_rhrcSe5m, VOf(Bf7));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf7), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf7), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf7), VOf(Bf7));
    __hv_exp_f(VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_o6KUdQVW, VOf(Bf6));
    __hv_mul_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_1eiigbFo, VOf(Bf7));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf7), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf7), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf7), VOf(Bf7));
    __hv_exp_f(VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_um2c0TaC, VOf(Bf6));
    __hv_line_f(&sLine_8LL4rMpR, VOf(Bf1));
    __hv_var_k_f(VOf(Bf9), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf1), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf6), VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf6));
    __hv_sub_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_sub_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf6), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_6j3EdCKl, VIf(Bf9));
    __hv_varwrite_f(&sVarf_um2c0TaC, VIf(Bf10));
    __hv_varwrite_f(&sVarf_62tEhfAI, VIf(Bf11));
    __hv_varwrite_f(&sVarf_j6micVRX, VIf(Bf12));
    __hv_varread_f(&sVarf_j6micVRX, VOf(Bf12));
    __hv_line_f(&sLine_wxLaUmLU, VOf(Bf11));
    __hv_mul_f(VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf12), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf11), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_mul_f(VIf(Bf11), VIf(Bf11), VOf(Bf12));
    __hv_var_k_f(VOf(Bf10), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf12), VIf(Bf10), VOf(Bf9));
    __hv_var_k_f(VOf(Bf6), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf12), VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_div_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_DchI4b8Q, VIf(Bf10));
    __hv_varread_f(&sVarf_62tEhfAI, VOf(Bf10));
    __hv_line_f(&sLine_xPrjmNv9, VOf(Bf11));
    __hv_var_k_f(VOf(Bf9), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf10), VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf11), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_floor_f(VIf(Bf11), VOf(Bf9));
    __hv_sub_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf11), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_abs_f(VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf9), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf11), VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_neg_f(VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_kIa2IZfR, VIf(Bf10));
    __hv_varwrite_f(&sVarf_lg6hUpyh, VIf(Bf7));
    __hv_varread_f(&sVarf_SM8bNeGB, VOf(Bf7));
    __hv_varread_f(&sVarf_awUk6R91, VOf(Bf10));
    __hv_varread_f(&sVarf_RHsmceRG, VOf(Bf9));
    __hv_varread_f(&sVarf_mHXLDHqS, VOf(Bf11));
    __hv_varread_f(&sVarf_ZVAdvZUu, VOf(Bf6));
    __hv_varread_f(&sVarf_FrzqzW66, VOf(Bf12));
    __hv_varread_f(&sVarf_gvfn8o4d, VOf(Bf1));
    __hv_varwrite_f(&sVarf_OjU9AZkw, VIf(Bf4));
    __hv_varread_f(&sVarf_SlAcvj4A, VOf(Bf2));
    __hv_line_f(&sLine_c5ICqQdL, VOf(Bf16));
    __hv_mul_f(VIf(Bf2), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_9T8f2Sbr, VOf(Bf17));
    __hv_line_f(&sLine_cdk1A4sU, VOf(Bf13));
    __hv_mul_f(VIf(Bf17), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf16), VIf(Bf13), VOf(Bf13));
    __hv_varread_f(&sVarf_BBlBgvq9, VOf(Bf16));
    __hv_line_f(&sLine_4qyWwiDQ, VOf(Bf15));
    __hv_mul_f(VIf(Bf16), VIf(Bf15), VOf(Bf15));
    __hv_add_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_varwrite_f(&sVarf_mHXLDHqS, VIf(Bf15));
    __hv_varread_f(&sVarf_OjU9AZkw, VOf(Bf15));
    __hv_line_f(&sLine_ERkRCuVM, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_b5GAwSZW, VOf(Bf18));
    __hv_mul_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_1tS8Hsl8, VOf(Bf13));
    __hv_mul_f(VIf(Bf17), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf18), VIf(Bf13), VOf(Bf13));
    __hv_varwrite_f(&sVarf_ZVAdvZUu, VIf(Bf13));
    __hv_line_f(&sLine_u3uNDQuc, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_qypLIBho, VOf(Bf18));
    __hv_mul_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_UAiVrkEi, VOf(Bf13));
    __hv_mul_f(VIf(Bf16), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf18), VIf(Bf13), VOf(Bf13));
    __hv_varwrite_f(&sVarf_FrzqzW66, VIf(Bf13));
    __hv_line_f(&sLine_ZHXcpn88, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_lhpJiZEn, VOf(Bf15));
    __hv_mul_f(VIf(Bf17), VIf(Bf15), VOf(Bf15));
    __hv_add_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_line_f(&sLine_9e1fxvuk, VOf(Bf13));
    __hv_mul_f(VIf(Bf2), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_varwrite_f(&sVarf_gvfn8o4d, VIf(Bf13));
    __hv_varwrite_f(&sVarf_SlAcvj4A, VIf(Bf7));
    __hv_varwrite_f(&sVarf_9T8f2Sbr, VIf(Bf10));
    __hv_varwrite_f(&sVarf_BBlBgvq9, VIf(Bf9));
    sEnv_process(this, &sEnv_YDtP158m, VIf(Bf11), &sEnv_YDtP158m_sendMessage);
    sEnv_process(this, &sEnv_oG6Qdp2Z, VIf(Bf4), &sEnv_oG6Qdp2Z_sendMessage);
    __hv_line_f(&sLine_rt3ISCkG, VOf(Bf4));
    __hv_var_k_f(VOf(Bf9), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf9), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf11), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_lnuvZCQq, VOf(Bf11));
    __hv_mul_f(VIf(Bf4), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_8NW95XIy, VOf(Bf4));
    __hv_var_k_f(VOf(Bf9), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf9), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf11), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_Wi6MaFz3, VOf(Bf11));
    __hv_line_f(&sLine_M3RnsdTT, VOf(Bf9));
    __hv_var_k_f(VOf(Bf10), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf9), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf11), VIf(Bf10), VIf(Bf9), VOf(Bf9));
    __hv_floor_f(VIf(Bf9), VOf(Bf11));
    __hv_sub_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_sub_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_div_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_SM8bNeGB, VIf(Bf10));
    __hv_varwrite_f(&sVarf_Wi6MaFz3, VIf(Bf6));
    __hv_varwrite_f(&sVarf_7zvc7LdT, VIf(Bf12));
    __hv_varwrite_f(&sVarf_tWZyaVxh, VIf(Bf1));
    __hv_varread_f(&sVarf_tWZyaVxh, VOf(Bf1));
    __hv_line_f(&sLine_RobXwJdN, VOf(Bf12));
    __hv_mul_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf1), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf12), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf12), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_mul_f(VIf(Bf12), VIf(Bf12), VOf(Bf1));
    __hv_var_k_f(VOf(Bf6), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf6), VOf(Bf10));
    __hv_var_k_f(VOf(Bf11), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf1), VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf12), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_RHsmceRG, VIf(Bf6));
    __hv_varread_f(&sVarf_7zvc7LdT, VOf(Bf6));
    __hv_line_f(&sLine_rjIKolWT, VOf(Bf12));
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf12), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_floor_f(VIf(Bf12), VOf(Bf10));
    __hv_sub_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf12), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_abs_f(VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf10), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf6), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf12), VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_neg_f(VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_awUk6R91, VIf(Bf6));
    __hv_varwrite_f(&sVarf_122RJAsU, VIf(Bf4));
    __hv_varwrite_f(&sVarf_GQBvnmii, VIf(Bf0));
    __hv_varread_f(&sVarf_Pvzq1i7E, VOf(Bf0));
    __hv_varread_f(&sVarf_UVlLWLd2, VOf(Bf4));
    __hv_varread_f(&sVarf_IgO6Posg, VOf(Bf6));
    __hv_varread_f(&sVarf_r2IS216a, VOf(Bf10));
    __hv_varread_f(&sVarf_YWbRSXFN, VOf(Bf12));
    __hv_varread_f(&sVarf_UXbVcAZ7, VOf(Bf11));
    __hv_line_f(&sLine_E0V5JFk1, VOf(Bf1));
    __hv_line_f(&sLine_b18mzmUe, VOf(Bf9));
    __hv_mul_f(VIf(Bf10), VIf(Bf9), VOf(Bf10));
    __hv_fma_f(VIf(Bf6), VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf12), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_IgO6Posg, VIf(Bf0));
    __hv_varwrite_f(&sVarf_YWbRSXFN, VIf(Bf4));
    __hv_varread_f(&sVarf_Y8aU4Klg, VOf(Bf1));
    __hv_varread_f(&sVarf_Oaw4bgwk, VOf(Bf12));
    __hv_varread_f(&sVarf_CgrAanzg, VOf(Bf11));
    __hv_varread_f(&sVarf_QHGg9z2i, VOf(Bf6));
    __hv_varread_f(&sVarf_N1hKjL6g, VOf(Bf7));
    __hv_varread_f(&sVarf_Bo0jHK22, VOf(Bf13));
    __hv_varread_f(&sVarf_Nw7Nec79, VOf(Bf15));
    __hv_varwrite_f(&sVarf_sVgz0dqs, VIf(Bf0));
    __hv_varread_f(&sVarf_fJijlF2g, VOf(Bf2));
    __hv_line_f(&sLine_1XCzkdz0, VOf(Bf17));
    __hv_mul_f(VIf(Bf2), VIf(Bf17), VOf(Bf17));
    __hv_varread_f(&sVarf_Q1gUamxc, VOf(Bf18));
    __hv_line_f(&sLine_20oX5RVM, VOf(Bf16));
    __hv_mul_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_kCEgrUQU, VOf(Bf17));
    __hv_line_f(&sLine_Mmd2kNS9, VOf(Bf14));
    __hv_mul_f(VIf(Bf17), VIf(Bf14), VOf(Bf14));
    __hv_add_f(VIf(Bf16), VIf(Bf14), VOf(Bf14));
    __hv_varwrite_f(&sVarf_QHGg9z2i, VIf(Bf14));
    __hv_varread_f(&sVarf_sVgz0dqs, VOf(Bf14));
    __hv_line_f(&sLine_BzWpBC0W, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_H5UbUhca, VOf(Bf19));
    __hv_mul_f(VIf(Bf17), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_cnpt15z6, VOf(Bf16));
    __hv_mul_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_N1hKjL6g, VIf(Bf16));
    __hv_line_f(&sLine_NvDWlxMv, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_sO3YwkWJ, VOf(Bf19));
    __hv_mul_f(VIf(Bf2), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_ApMk57IA, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_Bo0jHK22, VIf(Bf16));
    __hv_line_f(&sLine_73Y8FIew, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_A2KmQ5Ep, VOf(Bf14));
    __hv_mul_f(VIf(Bf18), VIf(Bf14), VOf(Bf14));
    __hv_add_f(VIf(Bf16), VIf(Bf14), VOf(Bf14));
    __hv_line_f(&sLine_Hl5iayna, VOf(Bf16));
    __hv_mul_f(VIf(Bf2), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_Nw7Nec79, VIf(Bf16));
    __hv_varwrite_f(&sVarf_fJijlF2g, VIf(Bf1));
    __hv_varwrite_f(&sVarf_Q1gUamxc, VIf(Bf12));
    __hv_varwrite_f(&sVarf_kCEgrUQU, VIf(Bf11));
    sEnv_process(this, &sEnv_RZCH8jAL, VIf(Bf6), &sEnv_RZCH8jAL_sendMessage);
    sEnv_process(this, &sEnv_bj8QzG7b, VIf(Bf0), &sEnv_bj8QzG7b_sendMessage);
    __hv_line_f(&sLine_FA5b1MXg, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_6r47bCT1, VOf(Bf6));
    __hv_mul_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_oL5q1K2N, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_6ZoLpx1M, VOf(Bf6));
    __hv_line_f(&sLine_KmK1fSNj, VOf(Bf11));
    __hv_var_k_f(VOf(Bf12), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf11), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf6), VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_floor_f(VIf(Bf11), VOf(Bf6));
    __hv_sub_f(VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_sub_f(VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf6), VIf(Bf12), VOf(Bf12));
    __hv_varwrite_f(&sVarf_Y8aU4Klg, VIf(Bf12));
    __hv_varwrite_f(&sVarf_6ZoLpx1M, VIf(Bf7));
    __hv_varwrite_f(&sVarf_3n2lZGHB, VIf(Bf13));
    __hv_varwrite_f(&sVarf_Ve5sCf1k, VIf(Bf15));
    __hv_varread_f(&sVarf_Ve5sCf1k, VOf(Bf15));
    __hv_line_f(&sLine_fXGk3TNG, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf15), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf13), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_mul_f(VIf(Bf13), VIf(Bf13), VOf(Bf15));
    __hv_var_k_f(VOf(Bf7), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf15), VIf(Bf7), VOf(Bf12));
    __hv_var_k_f(VOf(Bf6), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf15), VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_div_f(VIf(Bf12), VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf13), VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_CgrAanzg, VIf(Bf7));
    __hv_varread_f(&sVarf_3n2lZGHB, VOf(Bf7));
    __hv_line_f(&sLine_4vtZuQ7f, VOf(Bf13));
    __hv_var_k_f(VOf(Bf12), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf7), VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf13), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_floor_f(VIf(Bf13), VOf(Bf12));
    __hv_sub_f(VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf13), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_abs_f(VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf12), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf7), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf13), VIf(Bf12), VIf(Bf7), VOf(Bf7));
    __hv_neg_f(VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_Oaw4bgwk, VIf(Bf7));
    __hv_varwrite_f(&sVarf_r2IS216a, VIf(Bf0));
    __hv_varread_f(&sVarf_sRgFkv5T, VOf(Bf0));
    __hv_varread_f(&sVarf_mN7fyC4T, VOf(Bf7));
    __hv_varread_f(&sVarf_jInsfRIg, VOf(Bf12));
    __hv_varread_f(&sVarf_txtrwkDv, VOf(Bf13));
    __hv_varread_f(&sVarf_610hNP6S, VOf(Bf6));
    __hv_varread_f(&sVarf_jNhb9iWN, VOf(Bf15));
    __hv_varread_f(&sVarf_ljvrZE1W, VOf(Bf11));
    __hv_varwrite_f(&sVarf_XUBg8UGC, VIf(Bf4));
    __hv_varread_f(&sVarf_kmDfT0Gg, VOf(Bf1));
    __hv_line_f(&sLine_67M3E6wP, VOf(Bf16));
    __hv_mul_f(VIf(Bf1), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_q5oyUhUM, VOf(Bf14));
    __hv_line_f(&sLine_iSIE0oz8, VOf(Bf2));
    __hv_mul_f(VIf(Bf14), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf16), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_TtzSUtDm, VOf(Bf16));
    __hv_line_f(&sLine_DfYr3m1d, VOf(Bf18));
    __hv_mul_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_varwrite_f(&sVarf_txtrwkDv, VIf(Bf18));
    __hv_varread_f(&sVarf_XUBg8UGC, VOf(Bf18));
    __hv_line_f(&sLine_bUZA1afd, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_0BHFvKMK, VOf(Bf19));
    __hv_mul_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf2), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_LK60hgXP, VOf(Bf2));
    __hv_mul_f(VIf(Bf14), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf19), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_610hNP6S, VIf(Bf2));
    __hv_line_f(&sLine_Qy0ZIMpy, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_VOURrgbZ, VOf(Bf19));
    __hv_mul_f(VIf(Bf1), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf2), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_AJnmZVbY, VOf(Bf2));
    __hv_mul_f(VIf(Bf16), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf19), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_jNhb9iWN, VIf(Bf2));
    __hv_line_f(&sLine_zkX03kpk, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_6Nf0eLXa, VOf(Bf18));
    __hv_mul_f(VIf(Bf14), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_uNZINdA4, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_ljvrZE1W, VIf(Bf2));
    __hv_varwrite_f(&sVarf_kmDfT0Gg, VIf(Bf0));
    __hv_varwrite_f(&sVarf_q5oyUhUM, VIf(Bf7));
    __hv_varwrite_f(&sVarf_TtzSUtDm, VIf(Bf12));
    sEnv_process(this, &sEnv_VWLEd1QS, VIf(Bf13), &sEnv_VWLEd1QS_sendMessage);
    sEnv_process(this, &sEnv_ikRhLRMF, VIf(Bf4), &sEnv_ikRhLRMF_sendMessage);
    __hv_line_f(&sLine_IrBLfNLc, VOf(Bf4));
    __hv_var_k_f(VOf(Bf12), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf12), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf13), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_5NCcLyqi, VOf(Bf13));
    __hv_mul_f(VIf(Bf4), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_khdOAqc2, VOf(Bf4));
    __hv_var_k_f(VOf(Bf12), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf12), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf13), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_XNaw3i3M, VOf(Bf13));
    __hv_line_f(&sLine_HqOCtpVt, VOf(Bf12));
    __hv_var_k_f(VOf(Bf7), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf12), VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf12), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf13), VIf(Bf7), VIf(Bf12), VOf(Bf12));
    __hv_floor_f(VIf(Bf12), VOf(Bf13));
    __hv_sub_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_sub_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_div_f(VIf(Bf13), VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_sRgFkv5T, VIf(Bf7));
    __hv_varwrite_f(&sVarf_XNaw3i3M, VIf(Bf6));
    __hv_varwrite_f(&sVarf_gv5uLZsn, VIf(Bf15));
    __hv_varwrite_f(&sVarf_EDRxtw3a, VIf(Bf11));
    __hv_varread_f(&sVarf_EDRxtw3a, VOf(Bf11));
    __hv_line_f(&sLine_n4hu2Je3, VOf(Bf15));
    __hv_mul_f(VIf(Bf11), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf11), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf15), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf15), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf11), VIf(Bf15), VOf(Bf15));
    __hv_mul_f(VIf(Bf15), VIf(Bf15), VOf(Bf11));
    __hv_var_k_f(VOf(Bf6), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf11), VIf(Bf6), VOf(Bf7));
    __hv_var_k_f(VOf(Bf13), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf11), VIf(Bf13), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf15), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_jInsfRIg, VIf(Bf6));
    __hv_varread_f(&sVarf_gv5uLZsn, VOf(Bf6));
    __hv_line_f(&sLine_NakVpx3o, VOf(Bf15));
    __hv_var_k_f(VOf(Bf7), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf15), VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf15), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf7), VIf(Bf15), VOf(Bf15));
    __hv_floor_f(VIf(Bf15), VOf(Bf7));
    __hv_sub_f(VIf(Bf15), VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf15), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf7), VIf(Bf15), VOf(Bf15));
    __hv_abs_f(VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf7), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf6), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf15), VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_neg_f(VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_mN7fyC4T, VIf(Bf6));
    __hv_varwrite_f(&sVarf_UXbVcAZ7, VIf(Bf4));
    __hv_varwrite_f(&sVarf_yc0JGL44, VIf(Bf10));
    __hv_varread_f(&sVarf_e4IAnbz8, VOf(Bf10));
    __hv_varread_f(&sVarf_iElnrNAd, VOf(Bf4));
    __hv_varread_f(&sVarf_Kco0lFdi, VOf(Bf6));
    __hv_varread_f(&sVarf_SxYkAiug, VOf(Bf7));
    __hv_varread_f(&sVarf_qKPFqEFq, VOf(Bf15));
    __hv_varread_f(&sVarf_LaogSr1T, VOf(Bf13));
    __hv_line_f(&sLine_fBBJoQcB, VOf(Bf11));
    __hv_line_f(&sLine_X8kZHPkM, VOf(Bf12));
    __hv_mul_f(VIf(Bf7), VIf(Bf12), VOf(Bf7));
    __hv_fma_f(VIf(Bf6), VIf(Bf11), VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf15), VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_varwrite_f(&sVarf_Kco0lFdi, VIf(Bf10));
    __hv_varwrite_f(&sVarf_qKPFqEFq, VIf(Bf4));
    __hv_varread_f(&sVarf_GLAjq61z, VOf(Bf11));
    __hv_varread_f(&sVarf_zdpvex1N, VOf(Bf15));
    __hv_varread_f(&sVarf_bjYu5KBS, VOf(Bf13));
    __hv_varread_f(&sVarf_U1JapjJP, VOf(Bf6));
    __hv_varread_f(&sVarf_aK5PlBhK, VOf(Bf0));
    __hv_varread_f(&sVarf_vhkGoaze, VOf(Bf2));
    __hv_varread_f(&sVarf_HfsC0abw, VOf(Bf18));
    __hv_varwrite_f(&sVarf_PMCgu5ce, VIf(Bf10));
    __hv_varread_f(&sVarf_GBWBaTc5, VOf(Bf1));
    __hv_line_f(&sLine_AiFyovRL, VOf(Bf14));
    __hv_mul_f(VIf(Bf1), VIf(Bf14), VOf(Bf14));
    __hv_varread_f(&sVarf_Hd4EWwIW, VOf(Bf19));
    __hv_line_f(&sLine_ZOv2MMg6, VOf(Bf16));
    __hv_mul_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_xpoHSZKi, VOf(Bf14));
    __hv_line_f(&sLine_eXWrgpTt, VOf(Bf17));
    __hv_mul_f(VIf(Bf14), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_varwrite_f(&sVarf_U1JapjJP, VIf(Bf17));
    __hv_varread_f(&sVarf_PMCgu5ce, VOf(Bf17));
    __hv_line_f(&sLine_RcQs6LOx, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_klQHZ4J5, VOf(Bf20));
    __hv_mul_f(VIf(Bf14), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf16), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_YK7QtwsW, VOf(Bf16));
    __hv_mul_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf20), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_aK5PlBhK, VIf(Bf16));
    __hv_line_f(&sLine_c1x18Lyx, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_WsP5El7I, VOf(Bf20));
    __hv_mul_f(VIf(Bf1), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf16), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_BpqGwC6Q, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf20), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_vhkGoaze, VIf(Bf16));
    __hv_line_f(&sLine_9h26dRM0, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_Zfab4kx2, VOf(Bf17));
    __hv_mul_f(VIf(Bf19), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_line_f(&sLine_sHQr4Y7K, VOf(Bf16));
    __hv_mul_f(VIf(Bf1), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_HfsC0abw, VIf(Bf16));
    __hv_varwrite_f(&sVarf_GBWBaTc5, VIf(Bf11));
    __hv_varwrite_f(&sVarf_Hd4EWwIW, VIf(Bf15));
    __hv_varwrite_f(&sVarf_xpoHSZKi, VIf(Bf13));
    sEnv_process(this, &sEnv_Uja3rtBC, VIf(Bf6), &sEnv_Uja3rtBC_sendMessage);
    sEnv_process(this, &sEnv_9YT4CYSZ, VIf(Bf10), &sEnv_9YT4CYSZ_sendMessage);
    __hv_line_f(&sLine_eDdP3Ui4, VOf(Bf10));
    __hv_var_k_f(VOf(Bf13), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf10), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf10), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf13), VIf(Bf10), VOf(Bf10));
    __hv_exp_f(VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_8JJbkCBp, VOf(Bf6));
    __hv_mul_f(VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_OpwcPXeP, VOf(Bf10));
    __hv_var_k_f(VOf(Bf13), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf10), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf10), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf13), VIf(Bf10), VOf(Bf10));
    __hv_exp_f(VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_GvpSjrlB, VOf(Bf6));
    __hv_line_f(&sLine_4TRTDGaC, VOf(Bf13));
    __hv_var_k_f(VOf(Bf15), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf13), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf6), VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_floor_f(VIf(Bf13), VOf(Bf6));
    __hv_sub_f(VIf(Bf13), VIf(Bf6), VOf(Bf6));
    __hv_sub_f(VIf(Bf13), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf6), VIf(Bf15), VOf(Bf15));
    __hv_varwrite_f(&sVarf_GLAjq61z, VIf(Bf15));
    __hv_varwrite_f(&sVarf_GvpSjrlB, VIf(Bf0));
    __hv_varwrite_f(&sVarf_Sh3y841K, VIf(Bf2));
    __hv_varwrite_f(&sVarf_YsPRFXyA, VIf(Bf18));
    __hv_varread_f(&sVarf_YsPRFXyA, VOf(Bf18));
    __hv_line_f(&sLine_Fqqz2Xvr, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf18), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_var_k_f(VOf(Bf2), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf2), VOf(Bf18));
    __hv_var_k_f(VOf(Bf0), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf18), VIf(Bf0), VOf(Bf15));
    __hv_var_k_f(VOf(Bf6), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf18), VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_div_f(VIf(Bf15), VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf2), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_bjYu5KBS, VIf(Bf0));
    __hv_varread_f(&sVarf_Sh3y841K, VOf(Bf0));
    __hv_line_f(&sLine_PFVF3uxl, VOf(Bf2));
    __hv_var_k_f(VOf(Bf15), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf0), VIf(Bf2), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf2), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf15));
    __hv_sub_f(VIf(Bf2), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf15), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf0), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf2), VIf(Bf15), VIf(Bf0), VOf(Bf0));
    __hv_neg_f(VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_zdpvex1N, VIf(Bf0));
    __hv_varwrite_f(&sVarf_SxYkAiug, VIf(Bf10));
    __hv_varread_f(&sVarf_lixSEiRi, VOf(Bf10));
    __hv_varread_f(&sVarf_Dn1h6csY, VOf(Bf0));
    __hv_varread_f(&sVarf_bUezrHWW, VOf(Bf15));
    __hv_varread_f(&sVarf_5uVw0TNf, VOf(Bf2));
    __hv_varread_f(&sVarf_xnUqLccN, VOf(Bf6));
    __hv_varread_f(&sVarf_rW2mxb9u, VOf(Bf18));
    __hv_varread_f(&sVarf_5c94DJOJ, VOf(Bf13));
    __hv_varwrite_f(&sVarf_HbabM7Af, VIf(Bf4));
    __hv_varread_f(&sVarf_yUpclSml, VOf(Bf11));
    __hv_line_f(&sLine_mERTw4es, VOf(Bf16));
    __hv_mul_f(VIf(Bf11), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_feALdfBV, VOf(Bf17));
    __hv_line_f(&sLine_aW5zsayP, VOf(Bf1));
    __hv_mul_f(VIf(Bf17), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf16), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_jIMaE2Fs, VOf(Bf16));
    __hv_line_f(&sLine_bl4zBN47, VOf(Bf19));
    __hv_mul_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf1), VIf(Bf19), VOf(Bf19));
    __hv_varwrite_f(&sVarf_5uVw0TNf, VIf(Bf19));
    __hv_varread_f(&sVarf_HbabM7Af, VOf(Bf19));
    __hv_line_f(&sLine_K2mW0Yy1, VOf(Bf1));
    __hv_mul_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_ujwkCfHM, VOf(Bf20));
    __hv_mul_f(VIf(Bf16), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf1), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_oxW5DE8f, VOf(Bf1));
    __hv_mul_f(VIf(Bf17), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf20), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_xnUqLccN, VIf(Bf1));
    __hv_line_f(&sLine_32XgHKmY, VOf(Bf1));
    __hv_mul_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_Yn97wxJX, VOf(Bf20));
    __hv_mul_f(VIf(Bf11), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf1), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_D7JQgWmw, VOf(Bf1));
    __hv_mul_f(VIf(Bf16), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf20), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_rW2mxb9u, VIf(Bf1));
    __hv_line_f(&sLine_E2cG6c6O, VOf(Bf1));
    __hv_mul_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_W2hipR6s, VOf(Bf19));
    __hv_mul_f(VIf(Bf17), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf1), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_GO7UIQlw, VOf(Bf1));
    __hv_mul_f(VIf(Bf11), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_5c94DJOJ, VIf(Bf1));
    __hv_varwrite_f(&sVarf_yUpclSml, VIf(Bf10));
    __hv_varwrite_f(&sVarf_feALdfBV, VIf(Bf0));
    __hv_varwrite_f(&sVarf_jIMaE2Fs, VIf(Bf15));
    sEnv_process(this, &sEnv_i5GMNo5M, VIf(Bf2), &sEnv_i5GMNo5M_sendMessage);
    sEnv_process(this, &sEnv_nQo2j2mt, VIf(Bf4), &sEnv_nQo2j2mt_sendMessage);
    __hv_line_f(&sLine_LvVDuBiv, VOf(Bf4));
    __hv_var_k_f(VOf(Bf15), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf15), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_X6A4In9K, VOf(Bf2));
    __hv_mul_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_8Q1IobaF, VOf(Bf4));
    __hv_var_k_f(VOf(Bf15), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf15), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_6DZSm15z, VOf(Bf2));
    __hv_line_f(&sLine_efGcVWp6, VOf(Bf15));
    __hv_var_k_f(VOf(Bf0), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf15), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf15), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf2), VIf(Bf0), VIf(Bf15), VOf(Bf15));
    __hv_floor_f(VIf(Bf15), VOf(Bf2));
    __hv_sub_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_div_f(VIf(Bf2), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_lixSEiRi, VIf(Bf0));
    __hv_varwrite_f(&sVarf_6DZSm15z, VIf(Bf6));
    __hv_varwrite_f(&sVarf_QPQhhNij, VIf(Bf18));
    __hv_varwrite_f(&sVarf_w0R4Pmyp, VIf(Bf13));
    __hv_varread_f(&sVarf_w0R4Pmyp, VOf(Bf13));
    __hv_line_f(&sLine_Kj529jJK, VOf(Bf18));
    __hv_mul_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_var_k_f(VOf(Bf13), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf18), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf18), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_mul_f(VIf(Bf18), VIf(Bf18), VOf(Bf13));
    __hv_var_k_f(VOf(Bf6), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf13), VIf(Bf6), VOf(Bf0));
    __hv_var_k_f(VOf(Bf2), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf13), VIf(Bf2), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf18), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_bUezrHWW, VIf(Bf6));
    __hv_varread_f(&sVarf_QPQhhNij, VOf(Bf6));
    __hv_line_f(&sLine_cTf1YjyK, VOf(Bf18));
    __hv_var_k_f(VOf(Bf0), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf18), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf18), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf0), VIf(Bf18), VOf(Bf18));
    __hv_floor_f(VIf(Bf18), VOf(Bf0));
    __hv_sub_f(VIf(Bf18), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf18), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf18), VOf(Bf18));
    __hv_abs_f(VIf(Bf18), VOf(Bf18));
    __hv_var_k_f(VOf(Bf0), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf6), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf18), VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_neg_f(VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_Dn1h6csY, VIf(Bf6));
    __hv_varwrite_f(&sVarf_LaogSr1T, VIf(Bf4));
    __hv_varwrite_f(&sVarf_jgPfvMcf, VIf(Bf7));
    __hv_varwrite_f(&sVarf_PMXLHMjj, VIf(Bf8));
    __hv_varwrite_f(&sVarf_G1AyLc84, VIf(Bf9));
    __hv_varwrite_f(&sVarf_xP8AqX87, VIf(Bf12));
    __hv_varwrite_f(&sVarf_uXvfj1A6, VIf(Bf3));
    __hv_varwrite_f(&sVarf_cz82yjW2, VIf(Bf5));
    __hv_varread_f(&sVarf_GQBvnmii, VOf(Bf5));
    __hv_varread_f(&sVarf_yc0JGL44, VOf(Bf3));
    __hv_varread_f(&sVarf_jgPfvMcf, VOf(Bf12));
    __hv_add_f(VIf(Bf3), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf5), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf12), VIf(O0), VOf(O0));
    __hv_varread_f(&sVarf_PMXLHMjj, VOf(Bf12));
    __hv_varread_f(&sVarf_G1AyLc84, VOf(Bf5));
    __hv_varread_f(&sVarf_xP8AqX87, VOf(Bf3));
    __hv_add_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf12), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_M3NGLR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_M3NGLR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
